@@ -19,8 +19,9 @@ import org.eclipse.swtbot.swt.finder.widgets.SWTBotTable;
 public class TableAppearsCondition implements ICondition {
 
 	private SWTBot bot;
-	
-	public boolean test() throws Exception {
+
+	@Override
+	public boolean test() {
 		try {
 			SWTBotTable table = bot.table();
 			// table available
@@ -34,10 +35,12 @@ public class TableAppearsCondition implements ICondition {
 		return false;
 	}
 
+	@Override
 	public void init(SWTBot bot) {
 		this.bot = bot;
 	}
 
+	@Override
 	public String getFailureMessage() {
 		return null;
 	}
