@@ -11,10 +11,8 @@
  *******************************************************************************/ 
 package org.eclipse.linuxtools.internal.gcov.launch;
 
-import org.eclipse.core.runtime.CoreException;
 import org.eclipse.debug.core.ILaunchConfigurationType;
 import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;
-import org.eclipse.linuxtools.gcov.launch.GcovLaunchPlugin;
 import org.eclipse.linuxtools.profiling.launch.ProfileLaunchShortcut;
 
 public class GcovLaunchShortcut extends ProfileLaunchShortcut {
@@ -22,7 +20,7 @@ public class GcovLaunchShortcut extends ProfileLaunchShortcut {
 
 	@Override
 	protected void setDefaultProfileAttributes(
-			ILaunchConfigurationWorkingCopy wc) throws CoreException {
+			ILaunchConfigurationWorkingCopy wc) {
 	}
 
 	/**
