@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2011-2012 Ericsson, Ecole Polytechnique de Montreal and others
+ * Copyright (c) 2011, 2013 Ericsson, Ecole Polytechnique de Montreal and others
  *
  * All rights reserved. This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License v1.0 which
@@ -12,6 +12,7 @@
 
 package org.eclipse.linuxtools.internal.ctf.core.event.metadata.exceptions;
 
+
 /**
  * <b><u>ParseException</u></b>
  */
@@ -20,7 +21,7 @@ public class ParseException extends Exception {
     private static final long serialVersionUID = 7901917601459652080L;
 
     /**
-     * Enoty constructor
+     * Empty constructor
      */
     public ParseException() {
         super();
@@ -35,4 +36,11 @@ public class ParseException extends Exception {
         super(message);
     }
 
+    /**
+     * Copy constructor
+     * @param e the exception to throw
+     */
+    public ParseException(Exception e) {
+        super(e);
+    }
 }
