@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012 Ericsson
+ * Copyright (c) 2012, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -12,26 +12,15 @@
 
 package org.eclipse.linuxtools.lttng2.kernel.core.tests;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 /**
- * <b><u>AllTests</u></b>
- * <p>
+ * Runner for the lttng2.kernel unit tests.
  */
-public class AllTests {
-
-    /**
-     * @return The test suite
-     */
-    public static Test suite() {
-        TestSuite suite = new TestSuite(AllTests.class.getName());
-        // $JUnit-BEGIN$
-
-        // Plug-in
-        suite.addTestSuite(ActivatorTest.class);
-
-        // $JUnit-END$
-        return suite;
-    }
-}
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+    ActivatorTest.class,
+    org.eclipse.linuxtools.lttng2.kernel.core.tests.stateprovider.TestAll.class
+})
+public class AllTests { }
