@@ -1,5 +1,5 @@
 /**********************************************************************
- * Copyright (c) 2012 Ericsson
+ * Copyright (c) 2012, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -159,92 +159,57 @@ public class EnableKernelEventComposite extends Composite implements IEnableKern
     // ------------------------------------------------------------------------
     // Acessors
     // ------------------------------------------------------------------------
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#isTracpoints()
-     */
+
     @Override
     public boolean isTracepoints() {
         return fIsTracepoints;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#isAllTracePoints()
-     */
     @Override
     public boolean isAllTracePoints() {
         return fIsAllTracepoints;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#isSysCalls()
-     */
     @Override
     public boolean isSysCalls() {
         return fIsSysCalls;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#isAllSysCalls()
-     */
     @Override
     public boolean isAllSysCalls() {
         return fIsSysCalls;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#getEventNames()
-     */
     @Override
     public List<String> getEventNames() {
         return new ArrayList<String>(fSelectedEvents);
     }
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#isDynamicProbe()
-     */
+
     @Override
     public boolean isDynamicProbe() {
         return fIsDynamicProbe;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#getProbeName()
-     */
     @Override
     public String getProbeName() {
         return fProbeString;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#getProbeEventName()
-     */
     @Override
     public String getProbeEventName() {
         return fProbeEventName;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#isDynamicFunctionProbe()
-     */
     @Override
     public boolean isDynamicFunctionProbe() {
         return fIsDynamicFunctionProbe;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#getFunctionEventName()
-     */
     @Override
     public String getFunctionEventName() {
         return fFunctionEventName;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.internal.lttng2.ui.views.control.dialogs.IEnableKernelEvents#getFunction()
-     */
     @Override
     public String getFunction() {
         return fFunctionString;
@@ -253,6 +218,7 @@ public class EnableKernelEventComposite extends Composite implements IEnableKern
     // ------------------------------------------------------------------------
     // Operations
     // ------------------------------------------------------------------------
+
     /**
      * Creates the composite content
      */
@@ -303,7 +269,9 @@ public class EnableKernelEventComposite extends Composite implements IEnableKern
 
         if (fIsDynamicProbe) {
             String temp = fProbeEventNameText.getText();
-            if (!temp.matches("^[\\s]{0,}$") && !temp.matches("^[a-zA-Z0-9\\-\\_]{1,}$")) { //$NON-NLS-1$ //$NON-NLS-2$
+            if (temp.isEmpty() ||
+                fProbeText.getText().matches("\\s*") || //$NON-NLS-1$
+                (!temp.matches("^[\\s]{0,}$") && !temp.matches("^[a-zA-Z0-9\\-\\_]{1,}$"))) { //$NON-NLS-1$ //$NON-NLS-2$
                 MessageDialog.openError(getShell(),
                         Messages.TraceControl_EnableEventsDialogTitle,
                         Messages.TraceControl_InvalidProbeNameError + " (" + temp + ") \n");  //$NON-NLS-1$ //$NON-NLS-2$
@@ -311,11 +279,9 @@ public class EnableKernelEventComposite extends Composite implements IEnableKern
                 return false;
             }
 
-            if(!fProbeText.getText().matches("\\s*")) { //$NON-NLS-1$
-                fProbeEventName = temp;
-                // fProbeString will be validated by lttng-tools
-                fProbeString = fProbeText.getText();
-            }
+            fProbeEventName = temp;
+            // fProbeString will be validated by lttng-tools
+            fProbeString = fProbeText.getText();
         }
 
         // initialize function string
@@ -323,7 +289,9 @@ public class EnableKernelEventComposite extends Composite implements IEnableKern
         fFunctionString = null;
         if (fIsDynamicFunctionProbe) {
             String functionTemp = fFunctionEventNameText.getText();
-            if (!functionTemp.matches("^[\\s]{0,}$") && !functionTemp.matches("^[a-zA-Z0-9\\-\\_]{1,}$")) { //$NON-NLS-1$ //$NON-NLS-2$
+            if (functionTemp.isEmpty() ||
+                functionTemp.matches("\\s*") || //$NON-NLS-1$
+                (!functionTemp.matches("^[\\s]{0,}$") && !functionTemp.matches("^[a-zA-Z0-9\\-\\_]{1,}$"))) { //$NON-NLS-1$ //$NON-NLS-2$
                 MessageDialog.openError(getShell(),
                         Messages.TraceControl_EnableEventsDialogTitle,
                         Messages.TraceControl_InvalidProbeNameError + " (" + functionTemp + ") \n");  //$NON-NLS-1$ //$NON-NLS-2$
@@ -331,11 +299,9 @@ public class EnableKernelEventComposite extends Composite implements IEnableKern
                 return false;
             }
 
-            if(!fFunctionText.getText().matches("\\s*")) { //$NON-NLS-1$
-                fFunctionEventName = functionTemp;
-                // fFunctionString will be validated by lttng-tools
-                fFunctionString = fFunctionText.getText();
-            }
+            fFunctionEventName = functionTemp;
+            // fFunctionString will be validated by lttng-tools
+            fFunctionString = fFunctionText.getText();
         }
 
         return true;
@@ -571,7 +537,7 @@ public class EnableKernelEventComposite extends Composite implements IEnableKern
     /**
      * Content provider for the tracepoints tree.
      */
-    final static public class KernelContentProvider extends TraceControlContentProvider {
+    public static final class KernelContentProvider extends TraceControlContentProvider {
         @Override
         public Object[] getChildren(Object parentElement) {
             if (parentElement instanceof TraceProviderGroup) {
@@ -588,7 +554,7 @@ public class EnableKernelEventComposite extends Composite implements IEnableKern
     /**
      * Content label for the tracepoints tree.
      */
-    final static public class KernelLabelProvider extends TraceControlLabelProvider {
+    public static final class KernelLabelProvider extends TraceControlLabelProvider {
         @Override
         public Image getImage(Object element) {
             return null;
@@ -605,7 +571,7 @@ public class EnableKernelEventComposite extends Composite implements IEnableKern
     /**
      * Check state listener for the tracepoints tree.
      */
-    final public class KernelCheckListener implements ICheckStateListener {
+    public final class KernelCheckListener implements ICheckStateListener {
         @Override
         public void checkStateChanged(CheckStateChangedEvent event) {
           if (event.getChecked()) {
