@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2012 Ericsson
+ * Copyright (c) 2009, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -9,94 +9,80 @@
  * Contributors:
  *   Francois Chouinard - Initial API and implementation
  *   Francois Chouinard - Adjusted for new Event Model
+ *   Alexandre Montplaisir - Port to JUnit4
+ *   Patrick Tasse - Updated for negative value formatting
  *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.core.tests.event;
 
-import junit.framework.TestCase;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
-import org.eclipse.linuxtools.tmf.core.event.ITmfTimestamp;
-import org.eclipse.linuxtools.tmf.core.event.TmfTimestamp;
+import java.text.DateFormat;
+import java.text.SimpleDateFormat;
+import java.util.Date;
+
+import org.eclipse.linuxtools.tmf.core.timestamp.ITmfTimestamp;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimestamp;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimestampFormat;
+import org.junit.Test;
 
 /**
  * Test suite for the TmfTimestamp class.
  */
-@SuppressWarnings("nls")
-public class TmfTimestampTest extends TestCase {
+@SuppressWarnings("javadoc")
+public class TmfTimestampTest {
 
     // ------------------------------------------------------------------------
     // Variables
     // ------------------------------------------------------------------------
 
     private final ITmfTimestamp ts0 = new TmfTimestamp();
-    private final ITmfTimestamp ts1 = new TmfTimestamp(12345);
+    private final ITmfTimestamp ts1 = new TmfTimestamp(12345,  0);
     private final ITmfTimestamp ts2 = new TmfTimestamp(12345, -1);
-    private final ITmfTimestamp ts3 = new TmfTimestamp(12345, 2, 5);
-
-    // ------------------------------------------------------------------------
-    // Housekeping
-    // ------------------------------------------------------------------------
-
-    /**
-     * @param name the test name
-     */
-    public TmfTimestampTest(final String name) {
-        super(name);
-    }
-
-    @Override
-    protected void setUp() throws Exception {
-        super.setUp();
-    }
-
-    @Override
-    protected void tearDown() throws Exception {
-        super.tearDown();
-    }
+    private final ITmfTimestamp ts3 = new TmfTimestamp(12345,  2, 5);
+    private final ITmfTimestamp ts4 = new TmfTimestamp(12345, -3, 0);
+    private final ITmfTimestamp ts5 = new TmfTimestamp(12345, -6, 0);
+    private final ITmfTimestamp ts6 = new TmfTimestamp(12345, -9, 0);
+    private final ITmfTimestamp ts7 = new TmfTimestamp(-12345, -3, 0);
+    private final ITmfTimestamp ts8 = new TmfTimestamp(-12345, -6, 0);
+    private final ITmfTimestamp ts9 = new TmfTimestamp(-12345, -9, 0);
 
     // ------------------------------------------------------------------------
     // Constructors
     // ------------------------------------------------------------------------
 
-    /**
-     *
-     */
+    @Test
     public void testDefaultConstructor() {
         assertEquals("getValue", 0, ts0.getValue());
         assertEquals("getscale", 0, ts0.getScale());
         assertEquals("getPrecision", 0, ts0.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testValueConstructor() {
         assertEquals("getValue", 12345, ts1.getValue());
         assertEquals("getscale", 0, ts1.getScale());
         assertEquals("getPrecision", 0, ts1.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testValueScaleConstructor() {
         assertEquals("getValue", 12345, ts2.getValue());
         assertEquals("getscale", -1, ts2.getScale());
         assertEquals("getPrecision", 0, ts2.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testFullConstructor() {
         assertEquals("getValue", 12345, ts3.getValue());
         assertEquals("getscale", 2, ts3.getScale());
         assertEquals("getPrecision", 5, ts3.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCopyConstructor() {
         final ITmfTimestamp ts = new TmfTimestamp(12345, 2, 5);
         final ITmfTimestamp copy = new TmfTimestamp(ts);
@@ -110,9 +96,7 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", 5, copy.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCopyNullConstructor() {
         try {
             new TmfTimestamp(null);
@@ -121,9 +105,7 @@ public class TmfTimestampTest extends TestCase {
         }
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCopyConstructorBigBang() {
         final ITmfTimestamp ts = new TmfTimestamp(TmfTimestamp.BIG_BANG);
         assertEquals("getValue", TmfTimestamp.BIG_BANG.getValue(), ts.getValue());
@@ -131,9 +113,7 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", TmfTimestamp.BIG_BANG.getPrecision(), ts.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCopyConstructorBigCrunch() {
         final ITmfTimestamp ts = new TmfTimestamp(TmfTimestamp.BIG_CRUNCH);
         assertEquals("getValue", TmfTimestamp.BIG_CRUNCH.getValue(), ts.getValue());
@@ -141,9 +121,7 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", TmfTimestamp.BIG_CRUNCH.getPrecision(), ts.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCopyConstructorZero() {
         final ITmfTimestamp ts = new TmfTimestamp(TmfTimestamp.ZERO);
         assertEquals("getValue", TmfTimestamp.ZERO.getValue(), ts.getValue());
@@ -151,57 +129,11 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", TmfTimestamp.ZERO.getPrecision(), ts.getPrecision());
     }
 
-    // ------------------------------------------------------------------------
-    // clone
-    // ------------------------------------------------------------------------
-
-    private static class MyTimestamp extends TmfTimestamp {
-
-        @Override
-        public boolean equals(final Object other) {
-            return super.equals(other);
-        }
-
-        @Override
-        public MyTimestamp clone() {
-            return (MyTimestamp) super.clone();
-        }
-    }
-
-    /**
-     *
-     */
-    public void testClone() {
-        final ITmfTimestamp clone = ts0.clone();
-
-        assertTrue("clone", ts0.clone().equals(ts0));
-        assertTrue("clone", clone.clone().equals(clone));
-
-        assertEquals("clone", clone, ts0);
-        assertEquals("clone", ts0, clone);
-    }
-
-    /**
-     *
-     */
-    public void testClone2() {
-        final MyTimestamp timestamp = new MyTimestamp();
-        final MyTimestamp clone = timestamp.clone();
-
-        assertTrue("clone", timestamp.clone().equals(timestamp));
-        assertTrue("clone", clone.clone().equals(clone));
-
-        assertEquals("clone", clone, timestamp);
-        assertEquals("clone", timestamp, clone);
-    }
-
     // ------------------------------------------------------------------------
     // hashCode
     // ------------------------------------------------------------------------
 
-    /**
-     *
-     */
+    @Test
     public void testHashCode() {
         final ITmfTimestamp ts0copy = new TmfTimestamp(ts0);
         final ITmfTimestamp ts1copy = new TmfTimestamp(ts1);
@@ -218,9 +150,7 @@ public class TmfTimestampTest extends TestCase {
     // equals
     // ------------------------------------------------------------------------
 
-    /**
-     *
-     */
+    @Test
     public void testEqualsReflexivity() {
         assertTrue("equals", ts0.equals(ts0));
         assertTrue("equals", ts1.equals(ts1));
@@ -229,9 +159,7 @@ public class TmfTimestampTest extends TestCase {
         assertTrue("equals", !ts1.equals(ts0));
     }
 
-    /**
-     *
-     */
+    @Test
     public void testEqualsSymmetry() {
         final ITmfTimestamp ts0copy = new TmfTimestamp(ts0);
         assertTrue("equals", ts0.equals(ts0copy));
@@ -246,9 +174,7 @@ public class TmfTimestampTest extends TestCase {
         assertTrue("equals", ts2copy.equals(ts2));
     }
 
-    /**
-     *
-     */
+    @Test
     public void testEqualsTransivity() {
         final ITmfTimestamp ts0copy1 = new TmfTimestamp(ts0);
         final ITmfTimestamp ts0copy2 = new TmfTimestamp(ts0copy1);
@@ -269,17 +195,13 @@ public class TmfTimestampTest extends TestCase {
         assertTrue("equals", ts2.equals(ts2copy2));
     }
 
-    /**
-     *
-     */
+    @Test
     public void testEqualsNull() {
         assertTrue("equals", !ts0.equals(null));
         assertTrue("equals", !ts1.equals(null));
     }
 
-    /**
-     *
-     */
+    @Test
     public void testEqualsNonTimestamp() {
         assertFalse("equals", ts0.equals(ts0.toString()));
     }
@@ -288,23 +210,50 @@ public class TmfTimestampTest extends TestCase {
     // toString
     // ------------------------------------------------------------------------
 
-    /**
-     *
-     */
-    public void testToString() {
-        assertEquals("toString", "TmfTimestamp [fValue=0, fScale=0, fPrecision=0]", ts0.toString());
-        assertEquals("toString", "TmfTimestamp [fValue=12345, fScale=0, fPrecision=0]", ts1.toString());
-        assertEquals("toString", "TmfTimestamp [fValue=12345, fScale=-1, fPrecision=0]", ts2.toString());
-        assertEquals("toString", "TmfTimestamp [fValue=12345, fScale=2, fPrecision=5]", ts3.toString());
+    @Test
+    public void testToStringDefault() {
+        DateFormat df = new SimpleDateFormat("HH:mm:ss.SSS");
+        Date d0 = new Date((long) (ts0.getValue() * Math.pow(10, ts0.getScale() + 3)));
+        Date d1 = new Date((long) (ts1.getValue() * Math.pow(10, ts1.getScale() + 3)));
+        Date d2 = new Date((long) (ts2.getValue() * Math.pow(10, ts2.getScale() + 3)));
+        Date d3 = new Date((long) (ts3.getValue() * Math.pow(10, ts3.getScale() + 3)));
+        Date d4 = new Date((long) (ts4.getValue() * Math.pow(10, ts4.getScale() + 3)));
+        Date d5 = new Date((long) (ts5.getValue() * Math.pow(10, ts5.getScale() + 3)));
+        Date d6 = new Date((long) (ts6.getValue() * Math.pow(10, ts6.getScale() + 3)));
+        Date d7 = new Date((long) (ts7.getValue() * Math.pow(10, ts7.getScale() + 3)));
+        Date d8 = new Date((long) (ts8.getValue() * Math.pow(10, ts8.getScale() + 3)) - 1);
+        Date d9 = new Date((long) (ts9.getValue() * Math.pow(10, ts9.getScale() + 3)) - 1);
+        assertEquals("toString", df.format(d0) + " 000 000", ts0.toString());
+        assertEquals("toString", df.format(d1) + " 000 000", ts1.toString());
+        assertEquals("toString", df.format(d2) + " 000 000", ts2.toString());
+        assertEquals("toString", df.format(d3) + " 000 000", ts3.toString());
+        assertEquals("toString", df.format(d4) + " 000 000", ts4.toString());
+        assertEquals("toString", df.format(d5) + " 345 000", ts5.toString());
+        assertEquals("toString", df.format(d6) + " 012 345", ts6.toString());
+        assertEquals("toString", df.format(d7) + " 000 000", ts7.toString());
+        assertEquals("toString", df.format(d8) + " 655 000", ts8.toString());
+        assertEquals("toString", df.format(d9) + " 987 655", ts9.toString());
+    }
+
+    @Test
+    public void testToStringInterval() {
+        assertEquals("toString", "000.000 000 000", ts0.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
+        assertEquals("toString", "12345.000 000 000", ts1.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
+        assertEquals("toString", "1234.500 000 000", ts2.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
+        assertEquals("toString", "1234500.000 000 000", ts3.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
+        assertEquals("toString", "012.345 000 000", ts4.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
+        assertEquals("toString", "000.012 345 000", ts5.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
+        assertEquals("toString", "000.000 012 345", ts6.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
+        assertEquals("toString", "-012.345 000 000", ts7.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
+        assertEquals("toString", "-000.012 345 000", ts8.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
+        assertEquals("toString", "-000.000 012 345", ts9.toString(TmfTimestampFormat.getDefaulIntervalFormat()));
     }
 
     // ------------------------------------------------------------------------
     // normalize
     // ------------------------------------------------------------------------
 
-    /**
-     *
-     */
+    @Test
     public void testNormalizeOffset() {
         ITmfTimestamp ts = ts0.normalize(0, 0);
         assertEquals("getValue", 0, ts.getValue());
@@ -327,11 +276,9 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", 0, ts.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testNormalizeOffsetLowerLimits() {
-        final ITmfTimestamp ref = new TmfTimestamp(Long.MIN_VALUE + 5);
+        final ITmfTimestamp ref = new TmfTimestamp(Long.MIN_VALUE + 5, 0);
 
         ITmfTimestamp ts = ref.normalize(-4, 0);
         assertEquals("getValue", Long.MIN_VALUE + 1, ts.getValue());
@@ -349,11 +296,9 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", 0, ts.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testNormalizeOffsetUpperLimits() {
-        final ITmfTimestamp ref = new TmfTimestamp(Long.MAX_VALUE - 5);
+        final ITmfTimestamp ref = new TmfTimestamp(Long.MAX_VALUE - 5, 0);
 
         ITmfTimestamp ts = ref.normalize(4, 0);
         assertEquals("getValue", Long.MAX_VALUE - 1, ts.getValue());
@@ -371,9 +316,7 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", 0, ts.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testNormalizeScale() {
         ITmfTimestamp ts = ts0.normalize(0, 10);
         assertEquals("getValue", 0, ts.getValue());
@@ -386,9 +329,7 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", 0, ts.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testNormalizedScaleLimits() {
         final int MAX_SCALE_DIFF = 19;
 
@@ -419,9 +360,7 @@ public class TmfTimestampTest extends TestCase {
         }
     }
 
-    /**
-     *
-     */
+    @Test
     public void testNormalizeOffsetAndScaleTrivial() {
         final ITmfTimestamp ts = ts0.normalize(0, 0);
         assertEquals("getValue", 0, ts.getValue());
@@ -429,9 +368,7 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", 0, ts.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testNormalizeOffsetAndScale() {
         final int SCALE = 12;
 
@@ -456,9 +393,7 @@ public class TmfTimestampTest extends TestCase {
         assertEquals("getPrecision", 0, ts.getPrecision());
     }
 
-    /**
-     *
-     */
+    @Test
     public void testNormalizeOffsetAndScale2() {
         int SCALE = 2;
         ITmfTimestamp ts = ts1.normalize(0, SCALE);
@@ -487,34 +422,29 @@ public class TmfTimestampTest extends TestCase {
     // compareTo
     // ------------------------------------------------------------------------
 
-    /**
-     *
-     */
-    @SuppressWarnings("hiding")
+    @Test
     public void testBasicCompareTo() {
-        final ITmfTimestamp ts1 = new TmfTimestamp(900, 0, 50);
-        final ITmfTimestamp ts2 = new TmfTimestamp(1000, 0, 50);
-        final ITmfTimestamp ts3 = new TmfTimestamp(1100, 0, 50);
-        final ITmfTimestamp ts4 = new TmfTimestamp(1000, 0, 75);
+        final ITmfTimestamp t1 = new TmfTimestamp(900, 0, 50);
+        final ITmfTimestamp t2 = new TmfTimestamp(1000, 0, 50);
+        final ITmfTimestamp t3 = new TmfTimestamp(1100, 0, 50);
+        final ITmfTimestamp t4 = new TmfTimestamp(1000, 0, 75);
 
-        assertTrue(ts1.compareTo(ts1) == 0);
+        assertTrue(t1.compareTo(t1) == 0);
 
-        assertTrue("CompareTo", ts1.compareTo(ts2) < 0);
-        assertTrue("CompareTo", ts1.compareTo(ts3) < 0);
-        assertTrue("CompareTo", ts1.compareTo(ts4) < 0);
+        assertTrue("CompareTo", t1.compareTo(t2) < 0);
+        assertTrue("CompareTo", t1.compareTo(t3) < 0);
+        assertTrue("CompareTo", t1.compareTo(t4) < 0);
 
-        assertTrue("CompareTo", ts2.compareTo(ts1) > 0);
-        assertTrue("CompareTo", ts2.compareTo(ts3) < 0);
-        assertTrue("CompareTo", ts2.compareTo(ts4) == 0);
+        assertTrue("CompareTo", t2.compareTo(t1) > 0);
+        assertTrue("CompareTo", t2.compareTo(t3) < 0);
+        assertTrue("CompareTo", t2.compareTo(t4) == 0);
 
-        assertTrue("CompareTo", ts3.compareTo(ts1) > 0);
-        assertTrue("CompareTo", ts3.compareTo(ts2) > 0);
-        assertTrue("CompareTo", ts3.compareTo(ts4) > 0);
+        assertTrue("CompareTo", t3.compareTo(t1) > 0);
+        assertTrue("CompareTo", t3.compareTo(t2) > 0);
+        assertTrue("CompareTo", t3.compareTo(t4) > 0);
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCompareToCornerCases1() {
         final ITmfTimestamp ts0a = new TmfTimestamp(ts0);
         final ITmfTimestamp ts0b = new TmfTimestamp(ts0.getValue(), ts0.getScale() + 1);
@@ -528,9 +458,7 @@ public class TmfTimestampTest extends TestCase {
         assertTrue("compareTo", ts0.compareTo(ts0d, false) == -1);
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCompareToCornerCases2() {
         final ITmfTimestamp ts0a = new TmfTimestamp(Long.MAX_VALUE, Integer.MAX_VALUE - 1);
         final ITmfTimestamp ts0b = new TmfTimestamp(0, Integer.MAX_VALUE);
@@ -546,9 +474,7 @@ public class TmfTimestampTest extends TestCase {
         assertTrue("compareTo", ts0c.compareTo(ts0b, false) == 1);
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCompareToCornerCases3() {
         final ITmfTimestamp ts0a = new TmfTimestamp(Long.MIN_VALUE, Integer.MAX_VALUE - 1);
         final ITmfTimestamp ts0b = new TmfTimestamp(0, Integer.MAX_VALUE);
@@ -564,119 +490,103 @@ public class TmfTimestampTest extends TestCase {
         assertTrue("compareTo", ts0c.compareTo(ts0b, false) == -1);
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCompareToCornerCases4() {
         assertTrue("compareTo", ts0.compareTo(null, false) == 1);
         assertTrue("compareTo", ts0.compareTo(null, true) == 1);
     }
 
-    /**
-     *
-     */
-    @SuppressWarnings("hiding")
+    @Test
     public void testCompareToSameScale() {
-        final ITmfTimestamp ts1 = new TmfTimestamp(900, 0, 50);
-        final ITmfTimestamp ts2 = new TmfTimestamp(1000, 0, 50);
-        final ITmfTimestamp ts3 = new TmfTimestamp(1100, 0, 50);
-        final ITmfTimestamp ts4 = new TmfTimestamp(1000, 0, 75);
+        final ITmfTimestamp t1 = new TmfTimestamp(900, 0, 50);
+        final ITmfTimestamp t2 = new TmfTimestamp(1000, 0, 50);
+        final ITmfTimestamp t3 = new TmfTimestamp(1100, 0, 50);
+        final ITmfTimestamp t4 = new TmfTimestamp(1000, 0, 75);
 
-        assertTrue(ts1.compareTo(ts1, false) == 0);
+        assertTrue(t1.compareTo(t1, false) == 0);
 
-        assertTrue("CompareTo", ts1.compareTo(ts2, false) < 0);
-        assertTrue("CompareTo", ts1.compareTo(ts3, false) < 0);
-        assertTrue("CompareTo", ts1.compareTo(ts4, false) < 0);
+        assertTrue("CompareTo", t1.compareTo(t2, false) < 0);
+        assertTrue("CompareTo", t1.compareTo(t3, false) < 0);
+        assertTrue("CompareTo", t1.compareTo(t4, false) < 0);
 
-        assertTrue("CompareTo", ts2.compareTo(ts1, false) > 0);
-        assertTrue("CompareTo", ts2.compareTo(ts3, false) < 0);
-        assertTrue("CompareTo", ts2.compareTo(ts4, false) == 0);
+        assertTrue("CompareTo", t2.compareTo(t1, false) > 0);
+        assertTrue("CompareTo", t2.compareTo(t3, false) < 0);
+        assertTrue("CompareTo", t2.compareTo(t4, false) == 0);
 
-        assertTrue("CompareTo", ts3.compareTo(ts1, false) > 0);
-        assertTrue("CompareTo", ts3.compareTo(ts2, false) > 0);
-        assertTrue("CompareTo", ts3.compareTo(ts4, false) > 0);
+        assertTrue("CompareTo", t3.compareTo(t1, false) > 0);
+        assertTrue("CompareTo", t3.compareTo(t2, false) > 0);
+        assertTrue("CompareTo", t3.compareTo(t4, false) > 0);
     }
 
-    /**
-     *
-     */
-    @SuppressWarnings("hiding")
+    @Test
     public void testCompareToDifferentScale() {
-        final ITmfTimestamp ts1 = new TmfTimestamp(9000, -1, 50);
-        final ITmfTimestamp ts2 = new TmfTimestamp(1000, 0, 50);
-        final ITmfTimestamp ts3 = new TmfTimestamp(110, 1, 50);
-        final ITmfTimestamp ts4 = new TmfTimestamp(1, 3, 75);
+        final ITmfTimestamp t1 = new TmfTimestamp(9000, -1, 50);
+        final ITmfTimestamp t2 = new TmfTimestamp(1000, 0, 50);
+        final ITmfTimestamp t3 = new TmfTimestamp(110, 1, 50);
+        final ITmfTimestamp t4 = new TmfTimestamp(1, 3, 75);
 
-        assertTrue("CompareTo", ts1.compareTo(ts1, false) == 0);
+        assertTrue("CompareTo", t1.compareTo(t1, false) == 0);
 
-        assertTrue("CompareTo", ts1.compareTo(ts2, false) < 0);
-        assertTrue("CompareTo", ts1.compareTo(ts3, false) < 0);
-        assertTrue("CompareTo", ts1.compareTo(ts4, false) < 0);
+        assertTrue("CompareTo", t1.compareTo(t2, false) < 0);
+        assertTrue("CompareTo", t1.compareTo(t3, false) < 0);
+        assertTrue("CompareTo", t1.compareTo(t4, false) < 0);
 
-        assertTrue("CompareTo", ts2.compareTo(ts1, false) > 0);
-        assertTrue("CompareTo", ts2.compareTo(ts3, false) < 0);
-        assertTrue("CompareTo", ts2.compareTo(ts4, false) == 0);
+        assertTrue("CompareTo", t2.compareTo(t1, false) > 0);
+        assertTrue("CompareTo", t2.compareTo(t3, false) < 0);
+        assertTrue("CompareTo", t2.compareTo(t4, false) == 0);
 
-        assertTrue("CompareTo", ts3.compareTo(ts1, false) > 0);
-        assertTrue("CompareTo", ts3.compareTo(ts2, false) > 0);
-        assertTrue("CompareTo", ts3.compareTo(ts4, false) > 0);
+        assertTrue("CompareTo", t3.compareTo(t1, false) > 0);
+        assertTrue("CompareTo", t3.compareTo(t2, false) > 0);
+        assertTrue("CompareTo", t3.compareTo(t4, false) > 0);
     }
 
-    /**
-     *
-     */
-    @SuppressWarnings("hiding")
+    @Test
     public void testCompareToWithinPrecision() {
-        final ITmfTimestamp ts1 = new TmfTimestamp(900, 0, 50);
-        final ITmfTimestamp ts2 = new TmfTimestamp(1000, 0, 50);
-        final ITmfTimestamp ts3 = new TmfTimestamp(1100, 0, 50);
-        final ITmfTimestamp ts4 = new TmfTimestamp(1000, 0, 75);
+        final ITmfTimestamp t1 = new TmfTimestamp(900, 0, 50);
+        final ITmfTimestamp t2 = new TmfTimestamp(1000, 0, 50);
+        final ITmfTimestamp t3 = new TmfTimestamp(1100, 0, 50);
+        final ITmfTimestamp t4 = new TmfTimestamp(1000, 0, 75);
 
-        assertTrue("CompareTo", ts1.compareTo(ts1, true) == 0);
+        assertTrue("CompareTo", t1.compareTo(t1, true) == 0);
 
-        assertTrue("CompareTo", ts1.compareTo(ts2, true) == 0);
-        assertTrue("CompareTo", ts1.compareTo(ts3, true) < 0);
-        assertTrue("CompareTo", ts1.compareTo(ts4, true) == 0);
+        assertTrue("CompareTo", t1.compareTo(t2, true) == 0);
+        assertTrue("CompareTo", t1.compareTo(t3, true) < 0);
+        assertTrue("CompareTo", t1.compareTo(t4, true) == 0);
 
-        assertTrue("CompareTo", ts2.compareTo(ts1, true) == 0);
-        assertTrue("CompareTo", ts2.compareTo(ts3, true) == 0);
-        assertTrue("CompareTo", ts2.compareTo(ts4, true) == 0);
+        assertTrue("CompareTo", t2.compareTo(t1, true) == 0);
+        assertTrue("CompareTo", t2.compareTo(t3, true) == 0);
+        assertTrue("CompareTo", t2.compareTo(t4, true) == 0);
 
-        assertTrue("CompareTo", ts3.compareTo(ts1, true) > 0);
-        assertTrue("CompareTo", ts3.compareTo(ts2, true) == 0);
-        assertTrue("CompareTo", ts3.compareTo(ts4, true) == 0);
+        assertTrue("CompareTo", t3.compareTo(t1, true) > 0);
+        assertTrue("CompareTo", t3.compareTo(t2, true) == 0);
+        assertTrue("CompareTo", t3.compareTo(t4, true) == 0);
     }
 
-    /**
-     *
-     */
-    @SuppressWarnings("hiding")
+    @Test
     public void testCompareToLargeScale1() {
-        final ITmfTimestamp ts1 = new TmfTimestamp(-1, 100);
-        final ITmfTimestamp ts2 = new TmfTimestamp(-1000, -100);
-        final ITmfTimestamp ts3 = new TmfTimestamp(1, 100);
-        final ITmfTimestamp ts4 = new TmfTimestamp(1000, -100);
+        final ITmfTimestamp t1 = new TmfTimestamp(-1, 100);
+        final ITmfTimestamp t2 = new TmfTimestamp(-1000, -100);
+        final ITmfTimestamp t3 = new TmfTimestamp(1, 100);
+        final ITmfTimestamp t4 = new TmfTimestamp(1000, -100);
 
-        assertTrue("CompareTo", ts1.compareTo(ts2, false) < 0);
-        assertTrue("CompareTo", ts1.compareTo(ts3, false) < 0);
-        assertTrue("CompareTo", ts1.compareTo(ts4, false) < 0);
+        assertTrue("CompareTo", t1.compareTo(t2, false) < 0);
+        assertTrue("CompareTo", t1.compareTo(t3, false) < 0);
+        assertTrue("CompareTo", t1.compareTo(t4, false) < 0);
 
-        assertTrue("CompareTo", ts2.compareTo(ts1, false) > 0);
-        assertTrue("CompareTo", ts2.compareTo(ts3, false) < 0);
-        assertTrue("CompareTo", ts2.compareTo(ts4, false) < 0);
+        assertTrue("CompareTo", t2.compareTo(t1, false) > 0);
+        assertTrue("CompareTo", t2.compareTo(t3, false) < 0);
+        assertTrue("CompareTo", t2.compareTo(t4, false) < 0);
 
-        assertTrue("CompareTo", ts3.compareTo(ts1, false) > 0);
-        assertTrue("CompareTo", ts3.compareTo(ts2, false) > 0);
-        assertTrue("CompareTo", ts3.compareTo(ts4, false) > 0);
+        assertTrue("CompareTo", t3.compareTo(t1, false) > 0);
+        assertTrue("CompareTo", t3.compareTo(t2, false) > 0);
+        assertTrue("CompareTo", t3.compareTo(t4, false) > 0);
 
-        assertTrue("CompareTo", ts4.compareTo(ts1, false) > 0);
-        assertTrue("CompareTo", ts4.compareTo(ts2, false) > 0);
-        assertTrue("CompareTo", ts4.compareTo(ts3, false) < 0);
+        assertTrue("CompareTo", t4.compareTo(t1, false) > 0);
+        assertTrue("CompareTo", t4.compareTo(t2, false) > 0);
+        assertTrue("CompareTo", t4.compareTo(t3, false) < 0);
     }
 
-    /**
-     *
-     */
+    @Test
     public void testCompareToLargeScale2() {
         final ITmfTimestamp ts0a = new TmfTimestamp(0, Integer.MAX_VALUE);
         final ITmfTimestamp ts0b = new TmfTimestamp(1, Integer.MAX_VALUE);
@@ -692,74 +602,71 @@ public class TmfTimestampTest extends TestCase {
     // getDelta
     // ------------------------------------------------------------------------
 
-    /**
-     *
-     */
-    @SuppressWarnings("hiding")
+    @Test
     public void testDelta() {
         // Delta for same scale and precision (delta > 0)
-        ITmfTimestamp ts0 = new TmfTimestamp(10, 9);
-        ITmfTimestamp ts1 = new TmfTimestamp(5, 9);
+        ITmfTimestamp t0 = new TmfTimestamp(10, 9);
+        ITmfTimestamp t1 = new TmfTimestamp(5, 9);
         ITmfTimestamp exp = new TmfTimestamp(5, 9);
 
-        ITmfTimestamp delta = ts0.getDelta(ts1);
+        ITmfTimestamp delta = t0.getDelta(t1);
         assertEquals("getDelta", 0, delta.compareTo(exp, false));
 
         // Delta for same scale and precision (delta < 0)
-        ts0 = new TmfTimestamp(5, 9);
-        ts1 = new TmfTimestamp(10, 9);
+        t0 = new TmfTimestamp(5, 9);
+        t1 = new TmfTimestamp(10, 9);
         exp = new TmfTimestamp(-5, 9);
 
-        delta = ts0.getDelta(ts1);
+        delta = t0.getDelta(t1);
         assertEquals("getDelta", 0, delta.compareTo(exp, false));
 
         // Delta for different scale and same precision (delta > 0)
-        ts0 = new TmfTimestamp(5, 9);
-        ts1 = new TmfTimestamp(10, 8);
+        t0 = new TmfTimestamp(5, 9);
+        t1 = new TmfTimestamp(10, 8);
         exp = new TmfTimestamp(4, 9);
 
-        delta = ts0.getDelta(ts1);
+        delta = t0.getDelta(t1);
         assertEquals("getDelta", 0, delta.compareTo(exp, false));
 
         // Delta for different scale and same precision (delta > 0)
-        ts0 = new TmfTimestamp(5, 9);
-        ts1 = new TmfTimestamp(10, 7);
+        t0 = new TmfTimestamp(5, 9);
+        t1 = new TmfTimestamp(10, 7);
         exp = new TmfTimestamp(5, 9);
 
-        delta = ts0.getDelta(ts1);
+        delta = t0.getDelta(t1);
         assertEquals("getDelta", 0, delta.compareTo(exp, false));
 
         // Delta for different scale and same precision
-        ts0 = new TmfTimestamp(10, 9);
-        ts1 = new TmfTimestamp(5, 8);
+        t0 = new TmfTimestamp(10, 9);
+        t1 = new TmfTimestamp(5, 8);
         exp = new TmfTimestamp(10, 9);
 
-        delta = ts0.getDelta(ts1);
+        delta = t0.getDelta(t1);
         assertEquals("getDelta", 0, delta.compareTo(exp, false));
 
         // Delta for same scale and different precision
-        ts0 = new TmfTimestamp(10, 9, 1);
-        ts1 = new TmfTimestamp(5, 9, 2);
+        t0 = new TmfTimestamp(10, 9, 1);
+        t1 = new TmfTimestamp(5, 9, 2);
         exp = new TmfTimestamp(5, 9, 3);
 
-        delta = ts0.getDelta(ts1);
+        delta = t0.getDelta(t1);
         assertEquals("getDelta", 0, delta.compareTo(exp, true));
         assertEquals("precision", 3, delta.getPrecision());
 
         // Delta for same scale and different precision
-        ts0 = new TmfTimestamp(5, 9, 2);
-        ts1 = new TmfTimestamp(10, 9, 1);
+        t0 = new TmfTimestamp(5, 9, 2);
+        t1 = new TmfTimestamp(10, 9, 1);
         exp = new TmfTimestamp(-5, 9, 3);
 
-        delta = ts0.getDelta(ts1);
+        delta = t0.getDelta(t1);
         assertEquals("getDelta", 0, delta.compareTo(exp, true));
         assertEquals("precision", 3, delta.getPrecision());
 
         // Delta for different scale and different precision
-        ts0 = new TmfTimestamp(5, 9, 2);
-        ts1 = new TmfTimestamp(10, 8, 1);
+        t0 = new TmfTimestamp(5, 9, 2);
+        t1 = new TmfTimestamp(10, 8, 1);
         exp = new TmfTimestamp(4, 9, 3);
-        delta = ts0.getDelta(ts1);
+        delta = t0.getDelta(t1);
         assertEquals("getDelta", 0, delta.compareTo(exp, true));
         assertEquals("precision", 2, delta.getPrecision());
     }
