@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012 Ericsson
+ * Copyright (c) 2012, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -13,7 +13,6 @@
 package org.eclipse.linuxtools.tmf.tests.stubs.trace;
 
 import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
-import org.eclipse.linuxtools.tmf.core.event.TmfEvent;
 import org.eclipse.linuxtools.tmf.core.trace.ITmfTrace;
 import org.eclipse.linuxtools.tmf.core.trace.TmfExperiment;
 
@@ -24,10 +23,10 @@ import org.eclipse.linuxtools.tmf.core.trace.TmfExperiment;
  * <p>
  */
 @SuppressWarnings("javadoc")
-public class TmfExperimentStub<T extends ITmfEvent> extends TmfExperiment<TmfEvent> {
+public class TmfExperimentStub extends TmfExperiment {
 
-    public TmfExperimentStub(String name, ITmfTrace<TmfEvent>[] traces, int blockSize) {
-        super(TmfEvent.class, name, traces, blockSize);
+    public TmfExperimentStub(String name, ITmfTrace[] traces, int blockSize) {
+        super(ITmfEvent.class, name, traces, blockSize);
         setIndexer(new TmfIndexerStub(this, blockSize));
     }
 
