@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2010 Ericsson
+ * Copyright (c) 2009, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -12,28 +12,26 @@
 
 package org.eclipse.linuxtools.tmf.core.request;
 
-import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
-import org.eclipse.linuxtools.tmf.core.event.TmfTimeRange;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimeRange;
 
 /**
  * The TMF event request
  *
- * @param <T> The request event type
- *
  * @version 1.0
  * @author Francois Chouinard
  */
-public interface ITmfEventRequest<T extends ITmfEvent> extends ITmfDataRequest<T> {
+public interface ITmfEventRequest extends ITmfDataRequest {
 
     /**
      * @return the requested time range
+     * @since 2.0
      */
-    public TmfTimeRange getRange();
+    TmfTimeRange getRange();
 
     /**
      * this method is called by the event provider to set the index corresponding to the time range start time
      * @param index the start time index
      */
-	public void setStartIndex(int index);
+    void setStartIndex(int index);
 
 }
