@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2010 Ericsson
+ * Copyright (c) 2009, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -14,7 +14,7 @@ package org.eclipse.linuxtools.tmf.core.request;
 
 import java.util.concurrent.CountDownLatch;
 
-import org.eclipse.linuxtools.internal.tmf.core.Tracer;
+import org.eclipse.linuxtools.internal.tmf.core.TmfCoreTracer;
 import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
 
 /**
@@ -67,12 +67,10 @@ import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
  *
  * TODO: Implement request failures (codes, etc...)
  *
- * @param <T> The request data type
- *
  * @version 1.0
  * @author Francois Chouinard
  */
-public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataRequest<T> {
+public abstract class TmfDataRequest implements ITmfDataRequest {
 
     // ------------------------------------------------------------------------
     // Constants
@@ -90,16 +88,26 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
     // Attributes
     // ------------------------------------------------------------------------
 
-    private final Class<T> fDataType;
+    private final Class<? extends ITmfEvent> fDataType;
     private final ExecutionType fExecType;
-    private final int fRequestId; // A unique request ID
-    protected long fIndex; // The index (rank) of the requested event
-    protected int fNbRequested; // The number of requested events (ALL_DATA for all)
-    private final int fBlockSize; // The block size (for BG requests)
-    private int fNbRead; // The number of reads so far
 
-    private CountDownLatch startedLatch = new CountDownLatch(1);
-    private CountDownLatch completedLatch = new CountDownLatch(1);
+    /** A unique request ID */
+    private final int fRequestId;
+
+    /** The index (rank) of the requested event */
+    protected long fIndex;
+
+    /** The number of requested events (ALL_DATA for all) */
+    protected int fNbRequested;
+
+    /** The block size (for BG requests) */
+    private final int fBlockSize;
+
+    /** The number of reads so far */
+    private int fNbRead;
+
+    private final CountDownLatch startedLatch = new CountDownLatch(1);
+    private final CountDownLatch completedLatch = new CountDownLatch(1);
     private boolean fRequestRunning;
     private boolean fRequestCompleted;
     private boolean fRequestFailed;
@@ -122,7 +130,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      *
      * @param dataType the requested data type
      */
-    public TmfDataRequest(Class<T> dataType) {
+    public TmfDataRequest(Class<? extends ITmfEvent> dataType) {
         this(dataType, 0, ALL_DATA, DEFAULT_BLOCK_SIZE, ExecutionType.FOREGROUND);
     }
 
@@ -133,7 +141,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      * @param dataType the requested data type
      * @param priority the requested execution priority
      */
-    public TmfDataRequest(Class<T> dataType, ExecutionType priority) {
+    public TmfDataRequest(Class<? extends ITmfEvent> dataType, ExecutionType priority) {
         this(dataType, 0, ALL_DATA, DEFAULT_BLOCK_SIZE, priority);
     }
 
@@ -144,7 +152,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      * @param dataType the requested data type
      * @param index the index of the first event to retrieve
      */
-    public TmfDataRequest(Class<T> dataType, long index) {
+    public TmfDataRequest(Class<? extends ITmfEvent> dataType, long index) {
         this(dataType, index, ALL_DATA, DEFAULT_BLOCK_SIZE, ExecutionType.FOREGROUND);
     }
 
@@ -156,7 +164,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      * @param index the index of the first event to retrieve
      * @param priority the requested execution priority
      */
-    public TmfDataRequest(Class<T> dataType, long index, ExecutionType priority) {
+    public TmfDataRequest(Class<? extends ITmfEvent> dataType, long index, ExecutionType priority) {
         this(dataType, index, ALL_DATA, DEFAULT_BLOCK_SIZE, priority);
     }
 
@@ -168,7 +176,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      * @param index the index of the first event to retrieve
      * @param nbRequested the number of events requested
      */
-    public TmfDataRequest(Class<T> dataType, long index, int nbRequested) {
+    public TmfDataRequest(Class<? extends ITmfEvent> dataType, long index, int nbRequested) {
         this(dataType, index, nbRequested, DEFAULT_BLOCK_SIZE, ExecutionType.FOREGROUND);
     }
 
@@ -181,7 +189,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      * @param nbRequested the number of events requested
      * @param priority the requested execution priority
      */
-    public TmfDataRequest(Class<T> dataType, long index, int nbRequested, ExecutionType priority) {
+    public TmfDataRequest(Class<? extends ITmfEvent> dataType, long index, int nbRequested, ExecutionType priority) {
         this(dataType, index, nbRequested, DEFAULT_BLOCK_SIZE, priority);
     }
 
@@ -194,7 +202,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      * @param nbRequested the number of events requested
      * @param blockSize the number of events per block
      */
-    public TmfDataRequest(Class<T> dataType, long index, int nbRequested, int blockSize) {
+    public TmfDataRequest(Class<? extends ITmfEvent> dataType, long index, int nbRequested, int blockSize) {
         this(dataType, index, nbRequested, blockSize, ExecutionType.FOREGROUND);
     }
 
@@ -208,7 +216,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      * @param blockSize the number of events per block
      * @param priority the requested execution priority
      */
-    public TmfDataRequest(Class<T> dataType, long index, int nbRequested, int blockSize, ExecutionType priority) {
+    public TmfDataRequest(Class<? extends ITmfEvent> dataType, long index, int nbRequested, int blockSize, ExecutionType priority) {
         fRequestId = fRequestNumber++;
         fDataType = dataType;
         fIndex = index;
@@ -222,7 +230,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
         fRequestFailed = false;
         fRequestCanceled = false;
 
-        if (!(this instanceof ITmfEventRequest) && Tracer.isRequestTraced()) {
+        if (!(this instanceof ITmfEventRequest) && TmfCoreTracer.isRequestTraced()) {
             String type = getClass().getName();
             type = type.substring(type.lastIndexOf('.') + 1);
             @SuppressWarnings("nls")
@@ -230,18 +238,10 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
                     + (getExecType() == ITmfDataRequest.ExecutionType.BACKGROUND ? "(BG)" : "(FG)")
                     + " Type=" + type + " Index=" + getIndex() + " NbReq=" + getNbRequested()
                     + " DataType=" + getDataType().getSimpleName();
-            Tracer.traceRequest(this, message);
+            TmfCoreTracer.traceRequest(this, message);
         }
     }
 
-    /**
-     * Copy constructor
-     */
-    @SuppressWarnings("unused")
-    private TmfDataRequest(TmfDataRequest<T> other) {
-        this(null, 0, ALL_DATA, DEFAULT_BLOCK_SIZE);
-    }
-
     // ------------------------------------------------------------------------
     // Accessors
     // ------------------------------------------------------------------------
@@ -330,7 +330,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      * @return the requested data type
      */
     @Override
-    public Class<T> getDataType() {
+    public Class<? extends ITmfEvent> getDataType() {
         return fDataType;
     }
 
@@ -368,7 +368,7 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
      * @param data a piece of data
      */
     @Override
-    public void handleData(T data) {
+    public void handleData(ITmfEvent data) {
         if (data != null) {
             fNbRead++;
         }
@@ -376,9 +376,8 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
 
     @Override
     public void handleStarted() {
-        if (Tracer.isRequestTraced())
-         {
-            Tracer.traceRequest(this, "STARTED"); //$NON-NLS-1$
+        if (TmfCoreTracer.isRequestTraced()) {
+            TmfCoreTracer.traceRequest(this, "STARTED"); //$NON-NLS-1$
         }
     }
 
@@ -408,33 +407,29 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
         } else {
             handleSuccess();
         }
-        if (Tracer.isRequestTraced())
-         {
-            Tracer.traceRequest(this, "COMPLETED (" + fNbRead + " events read)"); //$NON-NLS-1$ //$NON-NLS-2$
+        if (TmfCoreTracer.isRequestTraced()) {
+            TmfCoreTracer.traceRequest(this, "COMPLETED (" + fNbRead + " events read)"); //$NON-NLS-1$ //$NON-NLS-2$
         }
     }
 
     @Override
     public void handleSuccess() {
-        if (Tracer.isRequestTraced())
-         {
-            Tracer.traceRequest(this, "SUCCEEDED"); //$NON-NLS-1$
+        if (TmfCoreTracer.isRequestTraced()) {
+            TmfCoreTracer.traceRequest(this, "SUCCEEDED"); //$NON-NLS-1$
         }
     }
 
     @Override
     public void handleFailure() {
-        if (Tracer.isRequestTraced())
-         {
-            Tracer.traceRequest(this, "FAILED"); //$NON-NLS-1$
+        if (TmfCoreTracer.isRequestTraced()) {
+            TmfCoreTracer.traceRequest(this, "FAILED"); //$NON-NLS-1$
         }
     }
 
     @Override
     public void handleCancel() {
-        if (Tracer.isRequestTraced())
-         {
-            Tracer.traceRequest(this, "CANCELLED"); //$NON-NLS-1$
+        if (TmfCoreTracer.isRequestTraced()) {
+            TmfCoreTracer.traceRequest(this, "CANCELLED"); //$NON-NLS-1$
         }
     }
 
@@ -530,8 +525,8 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
 
     @Override
     public boolean equals(Object other) {
-        if (other instanceof TmfDataRequest<?>) {
-            TmfDataRequest<?> request = (TmfDataRequest<?>) other;
+        if (other instanceof TmfDataRequest) {
+            TmfDataRequest request = (TmfDataRequest) other;
             return (request.fDataType == fDataType) && (request.fIndex == fIndex)
                     && (request.fNbRequested == fNbRequested);
         }
@@ -541,7 +536,12 @@ public abstract class TmfDataRequest<T extends ITmfEvent> implements ITmfDataReq
     @Override
     @SuppressWarnings("nls")
     public String toString() {
-        return "[TmfDataRequest(" + fRequestId + "," + fDataType.getSimpleName() + "," + fIndex + "," + fNbRequested
-                + "," + getBlockSize() + ")]";
+        String name = getClass().getName();
+        int dot = name.lastIndexOf('.');
+        if (dot >= 0) {
+            name = name.substring(dot + 1);
+        }
+        return "[" + name + "(" + fRequestId + "," + fDataType.getSimpleName()+ "," + getExecType()
+                + "," + fIndex + "," + fNbRequested + "," + getBlockSize() + ")]";
     }
 }
