@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012 Ericsson
+ * Copyright (c) 2012, 2013 Ericsson
  * Copyright (c) 2010, 2011 École Polytechnique de Montréal
  * Copyright (c) 2010, 2011 Alexandre Montplaisir <alexandre.montplaisir@gmail.com>
  *
@@ -23,13 +23,12 @@ final class StringStateValue extends TmfStateValue {
     private final String valueStr;
 
     public StringStateValue(String valueAsString) {
-        assert (valueAsString != null);
         this.valueStr = valueAsString;
     }
 
     @Override
-    public byte getType() {
-        return ITmfStateValue.TYPE_STRING;
+    public Type getType() {
+        return Type.STRING;
     }
 
     @Override
@@ -42,13 +41,17 @@ final class StringStateValue extends TmfStateValue {
         return valueStr;
     }
 
-    @Override
-    public byte[] toByteArray() {
-        return valueStr.getBytes();
-    }
-
     @Override
     public String toString() {
         return valueStr;
     }
+
+    // ------------------------------------------------------------------------
+    // Unboxing methods
+    // ------------------------------------------------------------------------
+
+    @Override
+    public String unboxStr() {
+        return valueStr;
+    }
 }
