@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2010, 2012 Ericsson
+ * Copyright (c) 2009, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -9,22 +9,34 @@
  * Contributors:
  *   Francois Chouinard - Initial API and implementation
  *   Francois Chouinard - Updated as per TMF Trace Model 1.0
+ *   Patrick Tasse - Updated for removal of context clone
  *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.core.trace;
 
 import java.io.File;
+import java.util.Collections;
+import java.util.LinkedHashMap;
+import java.util.Map;
 
 import org.eclipse.core.resources.IResource;
+import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.linuxtools.tmf.core.component.TmfEventProvider;
 import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
-import org.eclipse.linuxtools.tmf.core.event.ITmfTimestamp;
-import org.eclipse.linuxtools.tmf.core.event.TmfTimeRange;
-import org.eclipse.linuxtools.tmf.core.event.TmfTimestamp;
 import org.eclipse.linuxtools.tmf.core.exceptions.TmfTraceException;
 import org.eclipse.linuxtools.tmf.core.request.ITmfDataRequest;
 import org.eclipse.linuxtools.tmf.core.request.ITmfEventRequest;
+import org.eclipse.linuxtools.tmf.core.signal.TmfSignalHandler;
+import org.eclipse.linuxtools.tmf.core.signal.TmfSignalManager;
+import org.eclipse.linuxtools.tmf.core.signal.TmfTraceOpenedSignal;
+import org.eclipse.linuxtools.tmf.core.signal.TmfTraceRangeUpdatedSignal;
+import org.eclipse.linuxtools.tmf.core.statesystem.ITmfStateSystem;
+import org.eclipse.linuxtools.tmf.core.statistics.ITmfStatistics;
+import org.eclipse.linuxtools.tmf.core.statistics.TmfStateStatistics;
+import org.eclipse.linuxtools.tmf.core.timestamp.ITmfTimestamp;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimeRange;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimestamp;
 
 /**
  * Abstract implementation of ITmfTrace.
@@ -36,7 +48,7 @@ import org.eclipse.linuxtools.tmf.core.request.ITmfEventRequest;
  * <li> public double getLocationRatio(ITmfLocation<?> location)
  * <li> public ITmfContext seekEvent(ITmfLocation<?> location)
  * <li> public ITmfContext seekEvent(double ratio)
- * <li> public boolean validate(IProject project, String path)
+ * <li> public IStatus validate(IProject project, String path)
  * </ul>
  * A concrete trace must provide its corresponding parser. A common way to
  * accomplish this is by making the concrete class extend TmfTrace and
@@ -46,8 +58,6 @@ import org.eclipse.linuxtools.tmf.core.request.ITmfEventRequest;
  * TmfCheckpointIndexer (default). In this case, the trace cache size will be
  * used as checkpoint interval.
  *
- * @param <T> The trace event type
- *
  * @version 1.0
  * @author Francois Chouinard
  *
@@ -55,7 +65,7 @@ import org.eclipse.linuxtools.tmf.core.request.ITmfEventRequest;
  * @see ITmfTraceIndexer
  * @see ITmfEventParser
  */
-public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T> implements ITmfTrace<T> {
+public abstract class TmfTrace extends TmfEventProvider implements ITmfTrace {
 
     // ------------------------------------------------------------------------
     // Attributes
@@ -74,17 +84,30 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
     private long fNbEvents = 0;
 
     // The time span of the event stream
-    private ITmfTimestamp fStartTime = TmfTimestamp.BIG_CRUNCH;
+    private ITmfTimestamp fStartTime = TmfTimestamp.BIG_BANG;
     private ITmfTimestamp fEndTime = TmfTimestamp.BIG_BANG;
 
     // The trace streaming interval (0 = no streaming)
     private long fStreamingInterval = 0;
 
     // The trace indexer
-    private ITmfTraceIndexer<ITmfTrace<ITmfEvent>> fIndexer;
+    private ITmfTraceIndexer fIndexer;
 
     // The trace parser
-    private ITmfEventParser<T> fParser;
+    private ITmfEventParser fParser;
+
+    // The trace's statistics
+    private ITmfStatistics fStatistics;
+
+    /**
+     * The collection of state systems that are registered with this trace. Each
+     * sub-class can decide to add its (one or many) state system to this map
+     * during their {@link #buildStateSystem()}.
+     *
+     * @since 2.0
+     */
+    protected final Map<String, ITmfStateSystem> fStateSystems =
+            new LinkedHashMap<String, ITmfStateSystem>();
 
     // ------------------------------------------------------------------------
     // Construction
@@ -98,64 +121,37 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
     }
 
     /**
-     * The standard constructor (non-live trace). Applicable when the trace
-     * implements its own parser and if at checkpoint-based index is OK.
+     * Full constructor.
      *
-     * @param resource the resource associated to the trace
-     * @param type the trace event type
-     * @param path the trace path
-     * @param cacheSize the trace cache size
+     * @param resource
+     *            The resource associated to the trace
+     * @param type
+     *            The type of events that will be read from this trace
+     * @param path
+     *            The path to the trace on the filesystem
+     * @param cacheSize
+     *            The trace cache size. Pass '-1' to use the default specified
+     *            in {@link ITmfTrace#DEFAULT_TRACE_CACHE_SIZE}
+     * @param interval
+     *            The trace streaming interval. You can use '0' for post-mortem
+     *            traces.
+     * @param indexer
+     *            The trace indexer. You can pass 'null' to use a default
+     *            checkpoint indexer.
+     * @param parser
+     *            The trace event parser. Use 'null' if (and only if) the trace
+     *            object itself is also the ITmfEventParser to be used.
      * @throws TmfTraceException
+     *             If something failed during the opening
      */
-    protected TmfTrace(final IResource resource, final Class<T> type, final String path, final int cacheSize) throws TmfTraceException {
-        this(resource, type, path, cacheSize, 0);
-    }
-
-    /**
-     * The standard constructor (live trace). Applicable when the trace
-     * implements its own parser and if at checkpoint-based index is OK.
-     *
-     * @param resource the resource associated to the trace
-     * @param type the trace event type
-     * @param path the trace path
-     * @param cacheSize the trace cache size
-     * @param interval the trace streaming interval
-     * @throws TmfTraceException
-     */
-    protected TmfTrace(final IResource resource, final Class<T> type, final String path, final int cacheSize, final long interval) throws TmfTraceException {
-        this(resource, type, path, cacheSize, interval, null);
-    }
-
-    /**
-     * The 'non-default indexer' constructor. Allows to provide a trace
-     * specific indexer.
-     *
-     * @param resource the resource associated to the trace
-     * @param type the trace event type
-     * @param path the trace path
-     * @param cacheSize the trace cache size
-     * @param indexer the trace indexer
-     * @throws TmfTraceException
-     */
-    protected TmfTrace(final IResource resource, final Class<T> type, final String path, final int cacheSize,
-            final long interval, final ITmfTraceIndexer<?> indexer) throws TmfTraceException {
-        this(resource, type, path, cacheSize, interval, indexer, null);
-    }
-
-    /**
-     * The full constructor where trace specific indexer/parser are provided.
-     *
-     * @param resource the resource associated to the trace
-     * @param type the trace event type
-     * @param path the trace path
-     * @param cacheSize the trace cache size
-     * @param indexer the trace indexer
-     * @param parser the trace event parser
-     * @throws TmfTraceException
-     */
-    @SuppressWarnings({ "unchecked", "rawtypes" })
-    protected TmfTrace(final IResource resource, final Class<T> type, final String path, final int cacheSize,
-            final long interval, final ITmfTraceIndexer<?> indexer, final ITmfEventParser<T> parser) throws TmfTraceException {
+    protected TmfTrace(final IResource resource,
+            final Class<? extends ITmfEvent> type,
+            final String path,
+            final int cacheSize,
+            final long interval,
+            final ITmfTraceIndexer indexer,
+            final ITmfEventParser parser)
+                    throws TmfTraceException {
         super();
         fCacheSize = (cacheSize > 0) ? cacheSize : ITmfTrace.DEFAULT_TRACE_CACHE_SIZE;
         fStreamingInterval = interval;
@@ -170,8 +166,7 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
      * @param trace the original trace
      * @throws TmfTraceException Should not happen usually
      */
-    @SuppressWarnings({ "unchecked", "rawtypes" })
-    public TmfTrace(final TmfTrace<T> trace) throws TmfTraceException {
+    public TmfTrace(final TmfTrace trace) throws TmfTraceException {
         super();
         if (trace == null) {
             throw new IllegalArgumentException();
@@ -187,12 +182,8 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
     // ITmfTrace - Initializers
     // ------------------------------------------------------------------------
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#initTrace(org.eclipse.core.resources.IResource, java.lang.String, java.lang.Class)
-     */
     @Override
-    @SuppressWarnings({ "unchecked", "rawtypes" })
-    public void initTrace(final IResource resource, final String path, final Class<T> type) throws TmfTraceException {
+    public void initTrace(final IResource resource, final String path, final Class<? extends ITmfEvent> type) throws TmfTraceException {
         fIndexer = new TmfCheckpointIndexer(this, fCacheSize);
         initialize(resource, path, type);
     }
@@ -204,10 +195,12 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
      * @param path the trace path
      * @param type the trace event type
      *
-     * @throws TmfTraceException
+     * @throws TmfTraceException If something failed during the initialization
      */
-    @SuppressWarnings("unchecked")
-    protected void initialize(final IResource resource, final String path, final Class<T> type) throws TmfTraceException {
+    protected void initialize(final IResource resource,
+            final String path,
+            final Class<? extends ITmfEvent> type)
+                    throws TmfTraceException {
         if (path == null) {
             throw new TmfTraceException("Invalid trace path"); //$NON-NLS-1$
         }
@@ -221,12 +214,14 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
         }
         if (fParser == null) {
             if (this instanceof ITmfEventParser) {
-                fParser = (ITmfEventParser<T>) this;
+                fParser = (ITmfEventParser) this;
             } else {
                 throw new TmfTraceException("Invalid trace parser"); //$NON-NLS-1$
             }
         }
         super.init(traceName, type);
+        // register as VIP after super.init() because TmfComponent registers to signal manager there
+        TmfSignalManager.registerVIP(this);
     }
 
     /**
@@ -241,23 +236,68 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
     }
 
     /**
-     * Index the trace
-     *
-     * @param waitForCompletion index synchronously (true) or not (false)
+     * @since 2.0
      */
-    protected void indexTrace(boolean waitForCompletion) {
+    @Override
+    public void indexTrace(boolean waitForCompletion) {
         getIndexer().buildIndex(0, TmfTimeRange.ETERNITY, waitForCompletion);
     }
 
+    /**
+     * The default implementation of TmfTrace uses a TmfStatistics back-end.
+     * Override this if you want to specify another type (or none at all).
+     *
+     * @throws TmfTraceException
+     *             If there was a problem setting up the statistics
+     * @since 2.0
+     */
+    protected void buildStatistics() throws TmfTraceException {
+        /*
+         * Initialize the statistics provider, but only if a Resource has been
+         * set (so we don't build it for experiments, for unit tests, etc.)
+         */
+        fStatistics = (fResource == null ? null : new TmfStateStatistics(this) );
+    }
+
+    /**
+     * Build the state system(s) associated with this trace type.
+     *
+     * Suppressing the warning, because the 'throws' will usually happen in
+     * sub-classes.
+     *
+     * @throws TmfTraceException
+     *             If there is a problem during the build
+     * @since 2.0
+     */
+    @SuppressWarnings("unused")
+    protected void buildStateSystem() throws TmfTraceException {
+        /*
+         * Nothing is done in the base implementation, please specify
+         * how/if to register a new state system in derived classes.
+         */
+        return;
+    }
+
     /**
      * Clears the trace
      */
     @Override
     public synchronized void dispose() {
-        // Clean up the index if applicable
+        /* Clean up the index if applicable */
         if (getIndexer() != null) {
             getIndexer().dispose();
         }
+
+        /* Clean up the statistics */
+        if (fStatistics != null) {
+            fStatistics.dispose();
+        }
+
+        /* Clean up the state systems */
+        for (ITmfStateSystem ss : fStateSystems.values()) {
+            ss.dispose();
+        }
+
         super.dispose();
     }
 
@@ -265,41 +305,26 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
     // ITmfTrace - Basic getters
     // ------------------------------------------------------------------------
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#getEventType()
-     */
     @Override
-    public Class<T> getEventType() {
-        return (Class<T>) super.getType();
+    public Class<ITmfEvent> getEventType() {
+        return (Class<ITmfEvent>) super.getType();
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#getResource()
-     */
     @Override
     public IResource getResource() {
         return fResource;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#getPath()
-     */
     @Override
     public String getPath() {
         return fPath;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#getIndexPageSize()
-     */
     @Override
     public int getCacheSize() {
         return fCacheSize;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#getStreamingInterval()
-     */
     @Override
     public long getStreamingInterval() {
         return fStreamingInterval;
@@ -308,55 +333,85 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
     /**
      * @return the trace indexer
      */
-    protected ITmfTraceIndexer<ITmfTrace<ITmfEvent>> getIndexer() {
+    protected ITmfTraceIndexer getIndexer() {
         return fIndexer;
     }
 
     /**
      * @return the trace parser
      */
-    protected ITmfEventParser<T> getParser() {
+    protected ITmfEventParser getParser() {
         return fParser;
     }
 
+    /**
+     * @since 2.0
+     */
+    @Override
+    public ITmfStatistics getStatistics() {
+        return fStatistics;
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public final Map<String, ITmfStateSystem> getStateSystems() {
+        return Collections.unmodifiableMap(fStateSystems);
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public final void registerStateSystem(String id, ITmfStateSystem ss) {
+        fStateSystems.put(id, ss);
+    }
+
     // ------------------------------------------------------------------------
     // ITmfTrace - Trace characteristics getters
     // ------------------------------------------------------------------------
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#getNbEvents()
-     */
     @Override
     public synchronized long getNbEvents() {
         return fNbEvents;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#getTimeRange()
+    /**
+     * @since 2.0
      */
     @Override
     public TmfTimeRange getTimeRange() {
         return new TmfTimeRange(fStartTime, fEndTime);
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#getStartTime()
+    /**
+     * @since 2.0
      */
     @Override
     public ITmfTimestamp getStartTime() {
-        return fStartTime.clone();
+        return fStartTime;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#getEndTime()
+    /**
+     * @since 2.0
      */
     @Override
     public ITmfTimestamp getEndTime() {
-        return fEndTime.clone();
+        return fEndTime;
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public ITmfTimestamp getInitialRangeOffset() {
+        final long DEFAULT_INITIAL_OFFSET_VALUE = (1L * 100 * 1000 * 1000); // .1sec
+        return new TmfTimestamp(DEFAULT_INITIAL_OFFSET_VALUE, ITmfTimestamp.NANOSECOND_SCALE);
     }
 
     // ------------------------------------------------------------------------
-    // Convenience setters/getters
+    // Convenience setters
     // ------------------------------------------------------------------------
 
     /**
@@ -382,28 +437,31 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
      * Update the trace events time range
      *
      * @param range the new time range
+     * @since 2.0
      */
     protected void setTimeRange(final TmfTimeRange range) {
-        fStartTime = range.getStartTime().clone();
-        fEndTime = range.getEndTime().clone();
+        fStartTime = range.getStartTime();
+        fEndTime = range.getEndTime();
     }
 
     /**
      * Update the trace chronologically first event timestamp
      *
      * @param startTime the new first event timestamp
+     * @since 2.0
      */
     protected void setStartTime(final ITmfTimestamp startTime) {
-        fStartTime = startTime.clone();
+        fStartTime = startTime;
     }
 
     /**
      * Update the trace chronologically last event timestamp
      *
      * @param endTime the new last event timestamp
+     * @since 2.0
      */
     protected void setEndTime(final ITmfTimestamp endTime) {
-        fEndTime = endTime.clone();
+        fEndTime = endTime;
     }
 
     /**
@@ -420,7 +478,7 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
      *
      * @param indexer the trace indexer
      */
-    protected void setIndexer(final ITmfTraceIndexer<ITmfTrace<ITmfEvent>> indexer) {
+    protected void setIndexer(final ITmfTraceIndexer indexer) {
         fIndexer = indexer;
     }
 
@@ -429,7 +487,7 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
      *
      * @param parser the new trace parser
      */
-    protected void setParser(final ITmfEventParser<T> parser) {
+    protected void setParser(final ITmfEventParser parser) {
         fParser = parser;
     }
 
@@ -437,15 +495,12 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
     // ITmfTrace - SeekEvent operations (returning a trace context)
     // ------------------------------------------------------------------------
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#seekEvent(long)
-     */
     @Override
     public synchronized ITmfContext seekEvent(final long rank) {
 
         // A rank <= 0 indicates to seek the first event
         if (rank <= 0) {
-            ITmfContext context = seekEvent((ITmfLocation<?>) null);
+            ITmfContext context = seekEvent((ITmfLocation) null);
             context.setRank(0);
             return context;
         }
@@ -464,15 +519,15 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
         return context;
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#seekEvent(org.eclipse.linuxtools.tmf.core.event.ITmfTimestamp)
+    /**
+     * @since 2.0
      */
     @Override
     public synchronized ITmfContext seekEvent(final ITmfTimestamp timestamp) {
 
         // A null timestamp indicates to seek the first event
         if (timestamp == null) {
-            ITmfContext context = seekEvent((ITmfLocation<?>) null);
+            ITmfContext context = seekEvent((ITmfLocation) null);
             context.setRank(0);
             return context;
         }
@@ -481,17 +536,21 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
         ITmfContext context = fIndexer.seekIndex(timestamp);
 
         // And locate the requested event context
-        final ITmfContext nextEventContext = context.clone(); // Must use clone() to get the right subtype...
-        ITmfEvent event = getNext(nextEventContext);
+        ITmfLocation previousLocation = context.getLocation();
+        long previousRank = context.getRank();
+        ITmfEvent event = getNext(context);
         while (event != null && event.getTimestamp().compareTo(timestamp, false) < 0) {
-            context.dispose();
-            context = nextEventContext.clone();
-            event = getNext(nextEventContext);
+            previousLocation = context.getLocation();
+            previousRank = context.getRank();
+            event = getNext(context);
         }
-        nextEventContext.dispose();
         if (event == null) {
             context.setLocation(null);
             context.setRank(ITmfContext.UNKNOWN_RANK);
+        } else {
+            context.dispose();
+            context = seekEvent(previousLocation);
+            context.setRank(previousRank);
         }
         return context;
     }
@@ -500,13 +559,10 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
     // ITmfTrace - Read operations (returning an actual event)
     // ------------------------------------------------------------------------
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.trace.ITmfTrace#readNextEvent(org.eclipse.linuxtools.tmf.core.trace.ITmfContext)
-     */
     @Override
-    public synchronized T getNext(final ITmfContext context) {
+    public synchronized ITmfEvent getNext(final ITmfContext context) {
         // parseEvent() does not update the context
-        final T event = fParser.parseEvent(context);
+        final ITmfEvent event = fParser.parseEvent(context);
         if (event != null) {
             updateAttributes(context, event.getTimestamp());
             context.setLocation(getCurrentLocation());
@@ -531,20 +587,23 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
      *
      * @param context the current trace context
      * @param timestamp the corresponding timestamp
+     * @since 2.0
      */
     protected synchronized void updateAttributes(final ITmfContext context, final ITmfTimestamp timestamp) {
         if (fStartTime.equals(TmfTimestamp.BIG_BANG) || (fStartTime.compareTo(timestamp, false) > 0)) {
-            fStartTime = timestamp.clone();
+            fStartTime = timestamp;
         }
         if (fEndTime.equals(TmfTimestamp.BIG_CRUNCH) || (fEndTime.compareTo(timestamp, false) < 0)) {
-            fEndTime = timestamp.clone();
+            fEndTime = timestamp;
         }
         if (context.hasValidRank()) {
             long rank = context.getRank();
             if (fNbEvents <= rank) {
                 fNbEvents = rank + 1;
             }
-            fIndexer.updateIndex(context, timestamp);
+            if (fIndexer != null) {
+                fIndexer.updateIndex(context, timestamp);
+            }
         }
     }
 
@@ -552,30 +611,115 @@ public abstract class TmfTrace<T extends ITmfEvent> extends TmfEventProvider<T>
     // TmfDataProvider
     // ------------------------------------------------------------------------
 
-    /* (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.core.component.TmfDataProvider#armRequest(org.eclipse.linuxtools.tmf.core.request.ITmfDataRequest)
+    /**
+     * @since 2.0
      */
     @Override
-    protected ITmfContext armRequest(final ITmfDataRequest<T> request) {
-        if ((request instanceof ITmfEventRequest<?>)
-            && !TmfTimestamp.BIG_BANG.equals(((ITmfEventRequest<T>) request).getRange().getStartTime())
+    public synchronized ITmfContext armRequest(final ITmfDataRequest request) {
+        if (executorIsShutdown()) {
+            return null;
+        }
+        if ((request instanceof ITmfEventRequest)
+            && !TmfTimestamp.BIG_BANG.equals(((ITmfEventRequest) request).getRange().getStartTime())
             && (request.getIndex() == 0))
         {
-            final ITmfContext context = seekEvent(((ITmfEventRequest<T>) request).getRange().getStartTime());
-            ((ITmfEventRequest<T>) request).setStartIndex((int) context.getRank());
+            final ITmfContext context = seekEvent(((ITmfEventRequest) request).getRange().getStartTime());
+            ((ITmfEventRequest) request).setStartIndex((int) context.getRank());
             return context;
 
         }
         return seekEvent(request.getIndex());
     }
 
+    // ------------------------------------------------------------------------
+    // Signal handlers
+    // ------------------------------------------------------------------------
+
+    /**
+     * Handler for the Trace Opened signal
+     *
+     * @param signal
+     *            The incoming signal
+     * @since 2.0
+     */
+    @TmfSignalHandler
+    public void traceOpened(TmfTraceOpenedSignal signal) {
+        boolean signalIsForUs = false;
+        for (ITmfTrace trace : TmfTraceManager.getTraceSet(signal.getTrace())) {
+            if (trace == this) {
+                signalIsForUs = true;
+                break;
+            }
+        }
+
+        if (!signalIsForUs) {
+            return;
+        }
+
+        /*
+         * The signal is either for this trace, or for an experiment containing
+         * this trace.
+         */
+        try {
+            buildStatistics();
+            buildStateSystem();
+        } catch (TmfTraceException e) {
+            e.printStackTrace();
+        }
+
+        /* Refresh the project, so it can pick up new files that got created. */
+        try {
+            if (fResource != null) {
+                fResource.getProject().refreshLocal(IResource.DEPTH_INFINITE, null);
+            }
+        } catch (CoreException e) {
+            e.printStackTrace();
+        }
+
+        if (signal.getTrace() == this) {
+            /* Additionally, the signal is directly for this trace. */
+            if (getNbEvents() == 0) {
+                return;
+            }
+
+            /* For a streaming trace, the range updated signal should be sent
+             * by the subclass when a new safe time is determined.
+             */
+            if (getStreamingInterval() > 0) {
+                return;
+            }
+
+            final TmfTimeRange timeRange = new TmfTimeRange(getStartTime(), TmfTimestamp.BIG_CRUNCH);
+            final TmfTraceRangeUpdatedSignal rangeUpdatedsignal = new TmfTraceRangeUpdatedSignal(this, this, timeRange);
+
+            // Broadcast in separate thread to prevent deadlock
+            new Thread() {
+                @Override
+                public void run() {
+                    broadcast(rangeUpdatedsignal);
+                }
+            }.start();
+            return;
+        }
+    }
+
+    /**
+     * Signal handler for the TmfTraceRangeUpdatedSignal signal
+     *
+     * @param signal The incoming signal
+     * @since 2.0
+     */
+    @TmfSignalHandler
+    public void traceRangeUpdated(final TmfTraceRangeUpdatedSignal signal) {
+        if (signal.getTrace() == this) {
+            getIndexer().buildIndex(getNbEvents(), signal.getRange(), false);
+        }
+    }
+
     // ------------------------------------------------------------------------
     // toString
     // ------------------------------------------------------------------------
 
-    /* (non-Javadoc)
-     * @see java.lang.Object#toString()
-     */
     @Override
     @SuppressWarnings("nls")
     public synchronized String toString() {
