@@ -1,8 +1,22 @@
+/*******************************************************************************
+ * Copyright (c) 2012, 2013 Ericsson
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ *******************************************************************************/
+
 package org.eclipse.linuxtools.internal.tmf.ui;
 
 import org.eclipse.osgi.util.NLS;
 
+/**
+ * TMF message bundle
+ */
+@SuppressWarnings("javadoc")
 public class Messages extends NLS {
+
     private static final String BUNDLE_NAME = "org.eclipse.linuxtools.internal.tmf.ui.messages"; //$NON-NLS-1$
 
     public static String ManageCustomParsersDialog_DeleteButtonLabel;
@@ -50,14 +64,21 @@ public class Messages extends NLS {
     public static String CustomXmlTraceDefinition_timestampOutputFormat;
 
     public static String TmfEventsTable_AddBookmarkActionText;
-    public static String TmfEventsTable_AddBookmarkDialogText;
+    public static String TmfEventsTable_AddBookmarkDialogMessage;
     public static String TmfEventsTable_AddBookmarkDialogTitle;
     public static String TmfEventsTable_ApplyPresetFilterMenuName;
     public static String TmfEventsTable_ClearFiltersActionText;
     public static String TmfEventsTable_ContentColumnHeader;
+
+    public static String TmfEventsTable_Export_to_text;
     public static String TmfEventsTable_FilterHint;
     public static String TmfEventsTable_HideRawActionText;
     public static String TmfEventsTable_HideTableActionText;
+    public static String TmfEventsTable_OpenSourceCodeActionText;
+    public static String TmfEventsTable_OpenSourceCodeNotFound;
+    public static String TmfEventsTable_OpenSourceCodeSelectFileDialogTitle;
+    public static String TmfEventsTable_OpenModelActionText;
+    public static String TmfEventsTable_OpenModelUnsupportedURI;
     public static String TmfEventsTable_ReferenceColumnHeader;
     public static String TmfEventsTable_RemoveBookmarkActionText;
     public static String TmfEventsTable_SearchHint;
@@ -80,6 +101,14 @@ public class Messages extends NLS {
     public static String TmfTimeLegend_TRACE_STATES_TITLE;
     public static String TmfTimeLegend_WINDOW_TITLE;
     public static String TmfTimeLegend_StateTypeName;
+    public static String TmfTimeFilterDialog_WINDOW_TITLE;
+    public static String TmfTimeFilterDialog_MESSAGE;
+    public static String TmfTimeFilterDialog_CHECK_ALL;
+    public static String TmfTimeFilterDialog_UNCHECK_ALL;
+    public static String TmfTimeFilterDialog_CHECK_SELECTED;
+    public static String TmfTimeFilterDialog_UNCHECK_SELECTED;
+    public static String TmfTimeFilterDialog_CHECK_SUBTREE;
+    public static String TmfTimeFilterDialog_UNCHECK_SUBTREE;
 
     public static String TmfTimeTipHandler_DURATION;
     public static String TmfTimeTipHandler_TRACE_DATE;
@@ -88,6 +117,9 @@ public class Messages extends NLS {
     public static String TmfTimeTipHandler_TRACE_STATE;
     public static String TmfTimeTipHandler_TRACE_STOP_TIME;
 
+    public static String TmfTimeGraphCombo_FilterActionNameText;
+    public static String TmfTimeGraphCombo_FilterActionToolTipText;
+
     public static String TmfTimeGraphViewer_ResetScaleActionNameText;
     public static String TmfTimeGraphViewer_ResetScaleActionToolTipText;
     public static String TmfTimeGraphViewer_LegendActionNameText;
@@ -104,6 +136,12 @@ public class Messages extends NLS {
     public static String TmfTimeGraphViewer_ZoomInActionToolTipText;
     public static String TmfTimeGraphViewer_ZoomOutActionNameText;
     public static String TmfTimeGraphViewer_ZoomOutActionToolTipText;
+    public static String TmfTimeGraphViewer_HideArrowsActionNameText;
+    public static String TmfTimeGraphViewer_HideArrowsActionToolTipText;
+    public static String TmfTimeGraphViewer_FollowArrowForwardActionNameText;
+    public static String TmfTimeGraphViewer_FollowArrowForwardActionToolTipText;
+    public static String TmfTimeGraphViewer_FollowArrowBackwardActionNameText;
+    public static String TmfTimeGraphViewer_FollowArrowBackwardActionToolTipText;
 
     public static String ColorsView_AddActionToolTipText;
     public static String ColorsView_BackgroundButtonText;
@@ -254,6 +292,17 @@ public class Messages extends NLS {
     public static String TmfView_PinActionNameText;
     public static String TmfView_PinActionToolTipText;
 
+    public static String CallStackView_FunctionColumn;
+    public static String CallStackView_DepthColumn;
+    public static String CallStackView_EntryTimeColumn;
+    public static String CallStackView_ExitTimeColumn;
+    public static String CallStackView_DurationColumn;
+    public static String CallStackView_StackInfoNotAvailable;
+
+    public static String ExportToTextJob_Export_to;
+    public static String ExportToTextJob_Export_trace_to;
+    public static String ExportToTextJob_Unable_to_export_trace;
+
     static {
         // initialize resource bundle
         NLS.initializeMessages(BUNDLE_NAME, Messages.class);
