@@ -1,11 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2010 Ericsson
- * 
+ * Copyright (c) 2010, 2013 Ericsson
+ *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
  * accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
- * 
+ *
  * Contributors:
  *   Patrick Tasse - Initial API and implementation
  *******************************************************************************/
@@ -15,23 +15,30 @@ package org.eclipse.linuxtools.internal.tmf.ui.parsers.custom;
 import org.eclipse.linuxtools.tmf.core.trace.ITmfLocation;
 import org.eclipse.linuxtools.tmf.core.trace.TmfContext;
 
+/**
+ * Trace context for custom XML traces.
+ *
+ * @author Patrick Tassé
+ */
 public class CustomXmlTraceContext extends TmfContext {
 
-    public CustomXmlTraceContext(ITmfLocation<?> location, long rank) {
+    /**
+     * Constructor
+     *
+     * @param location
+     *            The location (in the file) of this context
+     * @param rank
+     *            The rank of the event pointed by this context
+     */
+    public CustomXmlTraceContext(ITmfLocation location, long rank) {
         super(location, rank);
     }
 
-    /* (non-Javadoc)
-     * @see java.lang.Object#hashCode()
-     */
     @Override
     public int hashCode() {
         return super.hashCode();
     }
 
-    /* (non-Javadoc)
-     * @see java.lang.Object#equals(java.lang.Object)
-     */
     @Override
     public boolean equals(Object obj) {
         if (this == obj) {
