@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010 Ericsson
+ * Copyright (c) 2010, 2012 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -28,12 +28,12 @@ public interface ITmfTraceEditor {
      *
      * @return The trace
      */
-    public ITmfTrace<?> getTrace();
+    ITmfTrace getTrace();
 
     /**
      * Get the bookmark file associated to this trace
      *
      * @return The IFile object pointing to the bookmark file
      */
-    public IFile getBookmarksFile();
+    IFile getBookmarksFile();
 }
