@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010 Ericsson
+ * Copyright (c) 2010, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -14,7 +14,6 @@ package org.eclipse.linuxtools.tmf.ui.editors;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
-import java.util.List;
 
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IMarker;
@@ -28,32 +27,38 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.InvalidRegistryObjectException;
+import org.eclipse.core.runtime.ListenerList;
 import org.eclipse.core.runtime.Platform;
+import org.eclipse.jface.action.IStatusLineManager;
+import org.eclipse.jface.util.SafeRunnable;
+import org.eclipse.jface.viewers.ISelection;
+import org.eclipse.jface.viewers.ISelectionChangedListener;
+import org.eclipse.jface.viewers.ISelectionProvider;
+import org.eclipse.jface.viewers.SelectionChangedEvent;
+import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.linuxtools.internal.tmf.ui.Activator;
 import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomEventsTable;
 import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTxtTrace;
 import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTrace;
-import org.eclipse.linuxtools.internal.tmf.ui.project.handlers.Messages;
 import org.eclipse.linuxtools.tmf.core.TmfCommonConstants;
-import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
-import org.eclipse.linuxtools.tmf.core.event.TmfEvent;
-import org.eclipse.linuxtools.tmf.core.event.TmfTimeRange;
-import org.eclipse.linuxtools.tmf.core.exceptions.TmfTraceException;
 import org.eclipse.linuxtools.tmf.core.signal.TmfSignalHandler;
+import org.eclipse.linuxtools.tmf.core.signal.TmfTimestampFormatUpdateSignal;
+import org.eclipse.linuxtools.tmf.core.signal.TmfTraceClosedSignal;
+import org.eclipse.linuxtools.tmf.core.signal.TmfTraceOpenedSignal;
 import org.eclipse.linuxtools.tmf.core.signal.TmfTraceSelectedSignal;
+import org.eclipse.linuxtools.tmf.core.trace.ITmfContext;
 import org.eclipse.linuxtools.tmf.core.trace.ITmfTrace;
 import org.eclipse.linuxtools.tmf.core.trace.TmfExperiment;
 import org.eclipse.linuxtools.tmf.core.trace.TmfTrace;
 import org.eclipse.linuxtools.tmf.ui.project.model.ITmfProjectModelElement;
+import org.eclipse.linuxtools.tmf.ui.project.model.Messages;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfExperimentElement;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfNavigatorContentProvider;
+import org.eclipse.linuxtools.tmf.ui.project.model.TmfOpenTraceHelper;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfProjectElement;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfProjectRegistry;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfTraceElement;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfTraceType;
-import org.eclipse.linuxtools.tmf.ui.signal.TmfTraceClosedSignal;
-import org.eclipse.linuxtools.tmf.ui.signal.TmfTraceOpenedSignal;
-import org.eclipse.linuxtools.tmf.ui.signal.TmfTraceParserUpdatedSignal;
 import org.eclipse.linuxtools.tmf.ui.viewers.events.TmfEventsTable;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
@@ -61,11 +66,14 @@ import org.eclipse.ui.IEditorInput;
 import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.IEditorSite;
 import org.eclipse.ui.IFileEditorInput;
+import org.eclipse.ui.IPartListener;
 import org.eclipse.ui.IPropertyListener;
 import org.eclipse.ui.IReusableEditor;
+import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.PartInitException;
 import org.eclipse.ui.ide.IGotoMarker;
 import org.eclipse.ui.part.FileEditorInput;
+import org.eclipse.ui.views.properties.IPropertySheetPage;
 import org.osgi.framework.Bundle;
 
 /**
@@ -73,17 +81,20 @@ import org.osgi.framework.Bundle;
  *
  * @version 1.0
  * @author Patrick Tasse
+ * @since 2.0
  */
-public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReusableEditor, IPropertyListener, IResourceChangeListener {
+public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReusableEditor, IPropertyListener, IResourceChangeListener, ISelectionProvider, ISelectionChangedListener, IPartListener, IGotoMarker {
 
     /** ID for this class */
     public static final String ID = "org.eclipse.linuxtools.tmf.ui.editors.events"; //$NON-NLS-1$
 
     private TmfEventsTable fEventsTable;
     private IFile fFile;
-    @SuppressWarnings("rawtypes")
     private ITmfTrace fTrace;
     private Composite fParent;
+    private ListenerList fSelectionChangedListeners = new ListenerList();
+    private boolean fTraceSelected;
+    private IMarker fPendingGotoMarker;
 
     @Override
     public void doSave(final IProgressMonitor monitor) {
@@ -93,23 +104,24 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
     public void doSaveAs() {
     }
 
-    @SuppressWarnings({ "unchecked", "rawtypes" })
     @Override
     public void init(final IEditorSite site, IEditorInput input) throws PartInitException {
+        IFileEditorInput fileEditorInput;
         if (input instanceof TmfEditorInput) {
             fFile = ((TmfEditorInput) input).getFile();
             fTrace = ((TmfEditorInput) input).getTrace();
-            input = new FileEditorInput(fFile);
+            /* change the input to a FileEditorInput to allow open handlers to find this editor */
+            fileEditorInput = new FileEditorInput(fFile);
         } else if (input instanceof IFileEditorInput) {
-            fFile = ((IFileEditorInput) input).getFile();
-            if (fFile == null)
-             {
-                throw new PartInitException("Invalid IFileEditorInput: " + input); //$NON-NLS-1$
+            fileEditorInput = (IFileEditorInput) input;
+            fFile = fileEditorInput.getFile();
+            if (fFile == null) {
+                throw new PartInitException("Invalid IFileEditorInput: " + fileEditorInput); //$NON-NLS-1$
             }
             try {
                 final String traceTypeId = fFile.getPersistentProperty(TmfCommonConstants.TRACETYPE);
                 if (traceTypeId == null) {
-                    throw new PartInitException(Messages.OpenTraceHandler_NoTraceType);
+                    throw new PartInitException(Messages.TmfOpenTraceHelper_NoTraceType);
                 }
                 if (traceTypeId.equals(TmfExperiment.class.getCanonicalName())) {
                     // Special case: experiment bookmark resource
@@ -117,45 +129,17 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
                     ncp.getChildren(fFile.getProject()); // force the model to be populated
                     final TmfProjectElement project = TmfProjectRegistry.getProject(fFile.getProject());
                     if (project == null) {
-                        throw new PartInitException(Messages.OpenExperimentHandler_NoTraceType);
+                        throw new PartInitException(Messages.TmfOpenTraceHelper_NoTraceType);
                     }
                     for (final ITmfProjectModelElement projectElement : project.getExperimentsFolder().getChildren()) {
                         final String traceName = fFile.getParent().getName();
                         if (projectElement.getName().equals(traceName)) {
                             final TmfExperimentElement experimentElement = (TmfExperimentElement) projectElement;
-                            // Instantiate the experiment's traces
-                            final List<TmfTraceElement> traceEntries = experimentElement.getTraces();
-                            final int nbTraces = traceEntries.size();
-                            int cacheSize = Integer.MAX_VALUE;
-                            final ITmfTrace<?>[] traces = new ITmfTrace[nbTraces];
-                            for (int i = 0; i < nbTraces; i++) {
-                                final TmfTraceElement traceElement = traceEntries.get(i);
-                                final ITmfTrace trace = traceElement.instantiateTrace();
-                                final ITmfEvent traceEvent = traceElement.instantiateEvent();
-                                if ((trace == null) || (traceEvent == null)) {
-                                    for (int j = 0; j < i; j++) {
-                                        traces[j].dispose();
-                                    }
-                                    throw new PartInitException(Messages.OpenExperimentHandler_NoTraceType);
-                                }
-                                try {
-                                    trace.initTrace(traceElement.getResource(), traceElement.getLocation().getPath(), traceEvent.getClass());
-                                } catch (final TmfTraceException e) {
-                                }
-                                cacheSize = Math.min(cacheSize, trace.getCacheSize());
-                                traces[i] = trace;
-                            }
-                            final TmfExperiment experiment = new TmfExperiment(ITmfEvent.class, experimentElement.getName(), traces, cacheSize) {
-                                @Override
-                                public void initTrace(IResource resource, String path, Class type) {
-                                    super.initTrace(resource, path, type);
-                                    getIndexer().buildIndex(getNbEvents(), TmfTimeRange.ETERNITY, false);
-                                }
-                            };
-                            experiment.setBookmarksFile(fFile);
-                            fTrace = experiment;
-                            experiment.initTrace(null, null, null);
-                            break;
+                            setPartName(experimentElement.getName());
+                            super.setSite(site);
+                            super.setInput(fileEditorInput);
+                            TmfOpenTraceHelper.reopenExperimentFromElement(experimentElement, this);
+                            return;
                         }
                     }
                 } else if (traceTypeId.equals(TmfTrace.class.getCanonicalName())) {
@@ -167,18 +151,11 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
                         final String traceName = fFile.getParent().getName();
                         if (projectElement.getName().equals(traceName)) {
                             final TmfTraceElement traceElement = (TmfTraceElement) projectElement;
-                            // Instantiate the trace
-                            final ITmfTrace trace = traceElement.instantiateTrace();
-                            final ITmfEvent traceEvent = traceElement.instantiateEvent();
-                            if ((trace == null) || (traceEvent == null)) {
-                                throw new PartInitException(Messages.OpenTraceHandler_NoTraceType);
-                            }
-                            try {
-                                trace.initTrace(traceElement.getResource(), traceElement.getLocation().getPath(), traceEvent.getClass());
-                            } catch (final TmfTraceException e) {
-                            }
-                            fTrace = trace;
-                            break;
+                            setPartName(traceElement.getName());
+                            super.setSite(site);
+                            super.setInput(fileEditorInput);
+                            TmfOpenTraceHelper.reopenTraceFromElement(traceElement, this);
+                            return;
                         }
                     }
                 } else {
@@ -188,36 +165,29 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
                     for (final ITmfProjectModelElement projectElement : project.getTracesFolder().getChildren()) {
                         if (projectElement.getResource().equals(fFile)) {
                             final TmfTraceElement traceElement = (TmfTraceElement) projectElement;
-                            // Instantiate the trace
-                            final ITmfTrace trace = traceElement.instantiateTrace();
-                            final ITmfEvent traceEvent = traceElement.instantiateEvent();
-                            if ((trace == null) || (traceEvent == null)) {
-                                throw new PartInitException(Messages.OpenTraceHandler_NoTraceType);
-                            }
-                            try {
-                                trace.initTrace(traceElement.getResource(), traceElement.getLocation().getPath(), traceEvent.getClass());
-                            } catch (final TmfTraceException e) {
-                            }
-                            fTrace = trace;
-                            break;
+                            setPartName(traceElement.getName());
+                            super.setSite(site);
+                            super.setInput(fileEditorInput);
+                            TmfOpenTraceHelper.reopenTraceFromElement(traceElement, this);
+                            return;
                         }
                     }
                 }
+            } catch (final PartInitException e) {
+                throw e;
             } catch (final InvalidRegistryObjectException e) {
                 Activator.getDefault().logError("Error initializing TmfEventsEditor", e); //$NON-NLS-1$
             } catch (final CoreException e) {
                 Activator.getDefault().logError("Error initializing TmfEventsEditor", e); //$NON-NLS-1$
             }
-        }
-        else {
+        } else {
             throw new PartInitException("Invalid IEditorInput: " + input.getClass()); //$NON-NLS-1$
         }
-        if (fTrace == null)
-         {
+        if (fTrace == null) {
             throw new PartInitException("Invalid IEditorInput: " + fFile.getName()); //$NON-NLS-1$
         }
         super.setSite(site);
-        super.setInput(input);
+        super.setInput(fileEditorInput);
     }
 
     @Override
@@ -238,19 +208,35 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
 
     @Override
     public void propertyChanged(final Object source, final int propId) {
-        if (propId == IEditorPart.PROP_INPUT) {
+        if (propId == IEditorPart.PROP_INPUT && getEditorInput() instanceof TmfEditorInput) {
             broadcast(new TmfTraceClosedSignal(this, fTrace));
+            fTraceSelected = false;
             fFile = ((TmfEditorInput) getEditorInput()).getFile();
             fTrace = ((TmfEditorInput) getEditorInput()).getTrace();
+            /* change the input to a FileEditorInput to allow open handlers to find this editor */
             super.setInput(new FileEditorInput(fFile));
             fEventsTable.dispose();
             if (fTrace != null) {
+                setPartName(fTrace.getName());
                 fEventsTable = createEventsTable(fParent, fTrace.getCacheSize());
+                fEventsTable.addSelectionChangedListener(this);
                 fEventsTable.setTrace(fTrace, true);
                 fEventsTable.refreshBookmarks(fFile);
-                broadcast(new TmfTraceOpenedSignal(this, fTrace, fFile, fEventsTable));
+                if (fPendingGotoMarker != null) {
+                    fEventsTable.gotoMarker(fPendingGotoMarker);
+                    fPendingGotoMarker = null;
+                }
+
+                /* ensure start time is set */
+                final ITmfContext context = fTrace.seekEvent(0);
+                fTrace.getNext(context);
+                context.dispose();
+
+                broadcast(new TmfTraceOpenedSignal(this, fTrace, fFile));
             } else {
+                setPartName(getEditorInput().getName());
                 fEventsTable = new TmfEventsTable(fParent, 0);
+                fEventsTable.addSelectionChangedListener(this);
             }
             fParent.layout();
         }
@@ -262,19 +248,36 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
         if (fTrace != null) {
             setPartName(fTrace.getName());
             fEventsTable = createEventsTable(parent, fTrace.getCacheSize());
+            fEventsTable.addSelectionChangedListener(this);
             fEventsTable.setTrace(fTrace, true);
             fEventsTable.refreshBookmarks(fFile);
-            broadcast(new TmfTraceOpenedSignal(this, fTrace, fFile, fEventsTable));
+
+            /* ensure start time is set */
+            final ITmfContext context = fTrace.seekEvent(0);
+            fTrace.getNext(context);
+            context.dispose();
+
+            broadcast(new TmfTraceOpenedSignal(this, fTrace, fFile));
         } else {
-            setPartName(getEditorInput().getName());
             fEventsTable = new TmfEventsTable(parent, 0);
+            fEventsTable.addSelectionChangedListener(this);
         }
+        IStatusLineManager statusLineManager = getEditorSite().getActionBars().getStatusLineManager();
+        fEventsTable.setStatusLineManager(statusLineManager);
         addPropertyListener(this);
         ResourcesPlugin.getWorkspace().addResourceChangeListener(this, IResourceChangeEvent.POST_CHANGE);
+        // we need to wrap the ISelectionProvider interface in the editor because
+        // the events table can be replaced later while the selection changed listener
+        // is only added once by the platform to the selection provider set here
+        getSite().setSelectionProvider(this);
+        getSite().getPage().addPartListener(this);
     }
 
     @Override
     public void dispose() {
+        if (getSite() != null) {
+            getSite().getPage().removePartListener(this);
+        }
         ResourcesPlugin.getWorkspace().removeResourceChangeListener(this);
         removePropertyListener(this);
         if (fTrace != null) {
@@ -286,6 +289,13 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
         super.dispose();
     }
 
+    /**
+     * Create the events table
+     *
+     * @param parent the parent composite
+     * @param cacheSize the cache size
+     * @return an events table instance
+     */
     protected TmfEventsTable createEventsTable(final Composite parent, final int cacheSize) {
         TmfEventsTable eventsTable = getEventsTable(parent, cacheSize);
         if (eventsTable == null) {
@@ -296,7 +306,7 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
 
     private TmfEventsTable getEventsTable(final Composite parent, final int cacheSize) {
         if (fTrace instanceof TmfExperiment) {
-            return getExperimentEventsTable((TmfExperiment<?>) fTrace, parent, cacheSize);
+            return getExperimentEventsTable((TmfExperiment) fTrace, parent, cacheSize);
         }
         TmfEventsTable eventsTable = null;
         try {
@@ -367,12 +377,12 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
      * @return an events table of the appropriate type
      */
     private static TmfEventsTable getExperimentEventsTable(
-            final TmfExperiment<?> experiment, final Composite parent,
+            final TmfExperiment experiment, final Composite parent,
             final int cacheSize) {
         TmfEventsTable eventsTable = null;
         String commonTraceType = null;
         try {
-            for (final ITmfTrace<?> trace : experiment.getTraces()) {
+            for (final ITmfTrace trace : experiment.getTraces()) {
                 final IResource resource = trace.getResource();
                 if (resource == null) {
                     return null;
@@ -434,7 +444,7 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
     }
 
     @Override
-    public ITmfTrace<?> getTrace() {
+    public ITmfTrace getTrace() {
         return fTrace;
     }
 
@@ -446,20 +456,33 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
     @Override
     public void setFocus() {
         fEventsTable.setFocus();
-        if (fTrace != null) {
-            broadcast(new TmfTraceSelectedSignal(this, fTrace));
-        }
     }
 
     @Override
-    @SuppressWarnings("rawtypes")
     public Object getAdapter(final Class adapter) {
         if (IGotoMarker.class.equals(adapter)) {
+            if (fTrace == null || fEventsTable == null) {
+                return this;
+            }
             return fEventsTable;
+        } else if (IPropertySheetPage.class.equals(adapter)) {
+            return new UnsortedPropertySheetPage();
         }
         return super.getAdapter(adapter);
     }
 
+    /**
+     * @since 2.1
+     */
+    @Override
+    public void gotoMarker(IMarker marker) {
+        if (fTrace == null || fEventsTable == null) {
+            fPendingGotoMarker = marker;
+        } else {
+            fEventsTable.gotoMarker(marker);
+        }
+    }
+
     @Override
     public void resourceChanged(final IResourceChangeEvent event) {
         for (final IMarkerDelta delta : event.findMarkerDeltas(IMarker.BOOKMARK, false)) {
@@ -484,6 +507,132 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
         }
     }
 
+    // ------------------------------------------------------------------------
+    // ISelectionProvider
+    // ------------------------------------------------------------------------
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public void addSelectionChangedListener(ISelectionChangedListener listener) {
+        fSelectionChangedListeners.add(listener);
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public ISelection getSelection() {
+        if (fEventsTable == null) {
+            return StructuredSelection.EMPTY;
+        }
+        return fEventsTable.getSelection();
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public void removeSelectionChangedListener(ISelectionChangedListener listener) {
+        fSelectionChangedListeners.remove(listener);
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public void setSelection(ISelection selection) {
+        // not implemented
+    }
+
+    /**
+     * Notifies any selection changed listeners that the viewer's selection has changed.
+     * Only listeners registered at the time this method is called are notified.
+     *
+     * @param event a selection changed event
+     *
+     * @see ISelectionChangedListener#selectionChanged
+     * @since 2.0
+     */
+    protected void fireSelectionChanged(final SelectionChangedEvent event) {
+        Object[] listeners = fSelectionChangedListeners.getListeners();
+        for (int i = 0; i < listeners.length; ++i) {
+            final ISelectionChangedListener l = (ISelectionChangedListener) listeners[i];
+            SafeRunnable.run(new SafeRunnable() {
+                @Override
+                public void run() {
+                    l.selectionChanged(event);
+                }
+            });
+        }
+    }
+
+    // ------------------------------------------------------------------------
+    // ISelectionChangedListener
+    // ------------------------------------------------------------------------
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public void selectionChanged(SelectionChangedEvent event) {
+        fireSelectionChanged(event);
+    }
+
+    // ------------------------------------------------------------------------
+    // IPartListener
+    // ------------------------------------------------------------------------
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public void partActivated(IWorkbenchPart part) {
+        if (part == this && fTrace != null) {
+            if (fTraceSelected) {
+                return;
+            }
+            fTraceSelected = true;
+            broadcast(new TmfTraceSelectedSignal(this, fTrace));
+        }
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public void partBroughtToTop(IWorkbenchPart part) {
+        if (part == this && fTrace != null) {
+            if (fTraceSelected) {
+                return;
+            }
+            fTraceSelected = true;
+            broadcast(new TmfTraceSelectedSignal(this, fTrace));
+        }
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public void partClosed(IWorkbenchPart part) {
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public void partDeactivated(IWorkbenchPart part) {
+    }
+
+    /**
+     * @since 2.0
+     */
+    @Override
+    public void partOpened(IWorkbenchPart part) {
+    }
+
     // ------------------------------------------------------------------------
     // Global commands
     // ------------------------------------------------------------------------
@@ -500,50 +649,6 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
     // Signal handlers
     // ------------------------------------------------------------------------
 
-    /**
-     * Handler for the Trace Parser Updated signal
-     *
-     * @param signal The incoming signal
-     */
-    @SuppressWarnings("unchecked")
-    @TmfSignalHandler
-    public void traceParserUpdated(final TmfTraceParserUpdatedSignal signal) {
-        if (signal.getTraceResource().equals(fFile)) {
-            broadcast(new TmfTraceClosedSignal(this, fTrace));
-            try {
-                fTrace.getName();
-                fTrace = null;
-                final String traceTypeId = fFile.getPersistentProperty(TmfCommonConstants.TRACETYPE);
-                if (traceTypeId != null) {
-                    for (final IConfigurationElement ce : TmfTraceType.getTypeElements()) {
-                        if (traceTypeId.equals(ce.getAttribute(TmfTraceType.ID_ATTR))) {
-                            fTrace = (ITmfTrace<?>) ce.createExecutableExtension(TmfTraceType.TRACE_TYPE_ATTR);
-                            final ITmfEvent event = (TmfEvent) ce.createExecutableExtension(TmfTraceType.EVENT_TYPE_ATTR);
-                            final String path = fFile.getLocationURI().getPath();
-                            fTrace.initTrace(null, path, event.getClass());
-                            break;
-                        }
-                    }
-                }
-            } catch (final InvalidRegistryObjectException e) {
-                Activator.getDefault().logError("Error handling signal TmfTraceParserUpdatedSignal", e); //$NON-NLS-1$
-            } catch (final TmfTraceException e) {
-                Activator.getDefault().logError("Error handling signal TmfTraceParserUpdatedSignal", e); //$NON-NLS-1$
-            } catch (final CoreException e) {
-                Activator.getDefault().logError("Error handling signal TmfTraceParserUpdatedSignal", e); //$NON-NLS-1$
-            }
-            fEventsTable.dispose();
-            if (fTrace != null) {
-                fEventsTable = createEventsTable(fParent, fTrace.getCacheSize());
-                fEventsTable.setTrace(fTrace, true);
-                broadcast(new TmfTraceOpenedSignal(this, fTrace, fFile, fEventsTable));
-            } else {
-                fEventsTable = new TmfEventsTable(fParent, 0);
-            }
-            fParent.layout();
-        }
-    }
-
     /**
      * Handler for the Trace Selected signal
      *
@@ -551,8 +656,25 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
      */
     @TmfSignalHandler
     public void traceSelected(final TmfTraceSelectedSignal signal) {
-        if ((signal.getSource() != this) && signal.getTrace().equals(fTrace)) {
-            getSite().getPage().bringToTop(this);
+        if ((signal.getSource() != this)) {
+            if (signal.getTrace().equals(fTrace)) {
+                getSite().getPage().bringToTop(this);
+            } else {
+                fTraceSelected = false;
+            }
+        }
+    }
+
+    /**
+     * Update the display to use the updated timestamp format
+     *
+     * @param signal the incoming signal
+     * @since 2.0
+     */
+    @TmfSignalHandler
+    public void timestampFormatUpdated(TmfTimestampFormatUpdateSignal signal) {
+        if (fEventsTable != null) {
+            fEventsTable.refresh();
         }
     }
 
