@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2011, 2012 Ericsson
+ * Copyright (c) 2010, 2013 Ericsson, École Polytechnique de Montréal
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -9,19 +9,30 @@
  * Contributors:
  *   Francois Chouinard - Initial API and implementation
  *   Bernd Hufmann - Added supplementary files handling
+ *   Geneviève Bastien - Moved supplementary files handling to parent class,
+ *                       added code to copy trace
+ *   Patrick Tasse - Close editors to release resources
+ *   Jean-Christian Kouame - added trace properties to be shown into
+ *                           the properties view
  *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.ui.project.model;
 
+import java.io.ByteArrayInputStream;
+import java.io.InputStream;
 import java.util.Arrays;
 import java.util.HashMap;
+import java.util.LinkedList;
+import java.util.List;
 import java.util.Map;
 
+import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IFolder;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IConfigurationElement;
-import org.eclipse.core.runtime.NullProgressMonitor;
+import org.eclipse.core.runtime.IPath;
+import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.linuxtools.internal.tmf.ui.Activator;
 import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTxtEvent;
@@ -33,21 +44,31 @@ import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTraceDefin
 import org.eclipse.linuxtools.tmf.core.TmfCommonConstants;
 import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
 import org.eclipse.linuxtools.tmf.core.trace.ITmfTrace;
+import org.eclipse.linuxtools.tmf.core.trace.ITmfTraceProperties;
+import org.eclipse.linuxtools.tmf.core.trace.TmfTrace;
+import org.eclipse.linuxtools.tmf.core.trace.TmfTraceManager;
 import org.eclipse.linuxtools.tmf.ui.editors.TmfEventsEditor;
+import org.eclipse.linuxtools.tmf.ui.properties.ReadOnlyTextPropertyDescriptor;
 import org.eclipse.ui.IActionFilter;
+import org.eclipse.ui.IEditorReference;
+import org.eclipse.ui.IWorkbench;
+import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.PartInitException;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.part.FileEditorInput;
 import org.eclipse.ui.views.properties.IPropertyDescriptor;
 import org.eclipse.ui.views.properties.IPropertySource2;
-import org.eclipse.ui.views.properties.TextPropertyDescriptor;
 
 /**
- * Implementation of trace model element representing a trace. It provides methods to instantiate
- * <code>ITmfTrace</code> and <code>ITmfEvent</code> as well as editor ID from the trace type
- * extension definition.
+ * Implementation of trace model element representing a trace. It provides
+ * methods to instantiate <code>ITmfTrace</code> and <code>ITmfEvent</code> as
+ * well as editor ID from the trace type extension definition.
  *
  * @version 1.0
  * @author Francois Chouinard
  */
-public class TmfTraceElement extends TmfProjectModelElement implements IActionFilter, IPropertySource2 {
+public class TmfTraceElement extends TmfWithFolderElement implements IActionFilter, IPropertySource2 {
 
     // ------------------------------------------------------------------------
     // Constants
@@ -64,30 +85,33 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     public static final String IS_LINKED = "isLinked"; //$NON-NLS-1$
 
     // Property View stuff
-    private static final String sfInfoCategory = "Info"; //$NON-NLS-1$
-    private static final String sfName = "name"; //$NON-NLS-1$
-    private static final String sfPath = "path"; //$NON-NLS-1$
-    private static final String sfLocation = "location"; //$NON-NLS-1$
-    private static final String sfEventType = "type"; //$NON-NLS-1$
-    private static final String sfIsLinked = "linked"; //$NON-NLS-1$
+    private static final String sfResourcePropertiesCategory = Messages.TmfTraceElement_ResourceProperties;
+    private static final String sfName = Messages.TmfTraceElement_Name;
+    private static final String sfPath = Messages.TmfTraceElement_Path;
+    private static final String sfLocation = Messages.TmfTraceElement_Location;
+    private static final String sfEventType = Messages.TmfTraceElement_EventType;
+    private static final String sfIsLinked = Messages.TmfTraceElement_IsLinked;
+    private static final String sfTracePropertiesCategory = Messages.TmfTraceElement_TraceProperties;
 
-    private static final TextPropertyDescriptor sfNameDescriptor = new TextPropertyDescriptor(sfName, sfName);
-    private static final TextPropertyDescriptor sfPathDescriptor = new TextPropertyDescriptor(sfPath, sfPath);
-    private static final TextPropertyDescriptor sfLocationDescriptor = new TextPropertyDescriptor(sfLocation, sfLocation);
-    private static final TextPropertyDescriptor sfTypeDescriptor = new TextPropertyDescriptor(sfEventType, sfEventType);
-    private static final TextPropertyDescriptor sfIsLinkedDescriptor = new TextPropertyDescriptor(sfIsLinked, sfIsLinked);
+    private static final ReadOnlyTextPropertyDescriptor sfNameDescriptor = new ReadOnlyTextPropertyDescriptor(sfName, sfName);
+    private static final ReadOnlyTextPropertyDescriptor sfPathDescriptor = new ReadOnlyTextPropertyDescriptor(sfPath, sfPath);
+    private static final ReadOnlyTextPropertyDescriptor sfLocationDescriptor = new ReadOnlyTextPropertyDescriptor(sfLocation, sfLocation);
+    private static final ReadOnlyTextPropertyDescriptor sfTypeDescriptor = new ReadOnlyTextPropertyDescriptor(sfEventType, sfEventType);
+    private static final ReadOnlyTextPropertyDescriptor sfIsLinkedDescriptor = new ReadOnlyTextPropertyDescriptor(sfIsLinked, sfIsLinked);
 
     private static final IPropertyDescriptor[] sfDescriptors = { sfNameDescriptor, sfPathDescriptor, sfLocationDescriptor,
             sfTypeDescriptor, sfIsLinkedDescriptor };
 
     static {
-        sfNameDescriptor.setCategory(sfInfoCategory);
-        sfPathDescriptor.setCategory(sfInfoCategory);
-        sfLocationDescriptor.setCategory(sfInfoCategory);
-        sfTypeDescriptor.setCategory(sfInfoCategory);
-        sfIsLinkedDescriptor.setCategory(sfInfoCategory);
+        sfNameDescriptor.setCategory(sfResourcePropertiesCategory);
+        sfPathDescriptor.setCategory(sfResourcePropertiesCategory);
+        sfLocationDescriptor.setCategory(sfResourcePropertiesCategory);
+        sfTypeDescriptor.setCategory(sfResourcePropertiesCategory);
+        sfIsLinkedDescriptor.setCategory(sfResourcePropertiesCategory);
     }
-    
+
+    private static final String BOOKMARKS_HIDDEN_FILE = ".bookmarks"; //$NON-NLS-1$
+
     // ------------------------------------------------------------------------
     // Attributes
     // ------------------------------------------------------------------------
@@ -99,12 +123,14 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     // Static initialization
     // ------------------------------------------------------------------------
 
-    // The mapping of available trace type IDs to their corresponding configuration element
+    // The mapping of available trace type IDs to their corresponding
+    // configuration element
     private static final Map<String, IConfigurationElement> sfTraceTypeAttributes = new HashMap<String, IConfigurationElement>();
     private static final Map<String, IConfigurationElement> sfTraceCategories = new HashMap<String, IConfigurationElement>();
 
     /**
-     *  Initialize statically at startup by getting extensions from the platform extension registry.
+     * Initialize statically at startup by getting extensions from the platform
+     * extension registry.
      */
     public static void init() {
         IConfigurationElement[] config = Platform.getExtensionRegistry().getConfigurationElementsFor(TmfTraceType.TMF_TRACE_TYPE_ID);
@@ -124,21 +150,28 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     // Constructors
     // ------------------------------------------------------------------------
     /**
-     * Constructor.
-     * Creates trace model element under the trace folder.
-     * @param name The name of trace
-     * @param trace The trace resource.
-     * @param parent The parent element (trace folder)
+     * Constructor. Creates trace model element under the trace folder.
+     *
+     * @param name
+     *            The name of trace
+     * @param trace
+     *            The trace resource.
+     * @param parent
+     *            The parent element (trace folder)
      */
     public TmfTraceElement(String name, IResource trace, TmfTraceFolder parent) {
         this(name, trace, (TmfProjectModelElement) parent);
     }
+
     /**
-     * Constructor.
-     * Creates trace model element under the experiment folder.
-     * @param name The name of trace
-     * @param trace The trace resource.
-     * @param parent The parent element (experiment folder)
+     * Constructor. Creates trace model element under the experiment folder.
+     *
+     * @param name
+     *            The name of trace
+     * @param trace
+     *            The trace resource.
+     * @param parent
+     *            The parent element (experiment folder)
      */
     public TmfTraceElement(String name, IResource trace, TmfExperimentElement parent) {
         this(name, trace, (TmfProjectModelElement) parent);
@@ -155,6 +188,7 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     // ------------------------------------------------------------------------
     /**
      * Returns the trace type ID.
+     *
      * @return trace type ID.
      */
     public String getTraceType() {
@@ -162,8 +196,8 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     }
 
     /**
-     * Refreshes the trace type filed by reading the trace type persistent property of the resource
-     * referenece.
+     * Refreshes the trace type filed by reading the trace type persistent
+     * property of the resource referenece.
      */
     public void refreshTraceType() {
         try {
@@ -174,11 +208,12 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     }
 
     /**
-     * Instantiate a <code>ITmfTrace</code> object based on the trace type and the corresponding extension.
+     * Instantiate a <code>ITmfTrace</code> object based on the trace type and
+     * the corresponding extension.
      *
      * @return the <code>ITmfTrace</code> or <code>null</code> for an error
      */
-    public ITmfTrace<?> instantiateTrace() {
+    public ITmfTrace instantiateTrace() {
         try {
 
             // make sure that supplementary folder exists
@@ -200,7 +235,10 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
                     }
                 }
                 IConfigurationElement ce = sfTraceTypeAttributes.get(fTraceTypeId);
-                ITmfTrace<?> trace = (ITmfTrace<?>) ce.createExecutableExtension(TmfTraceType.TRACE_TYPE_ATTR);
+                if (ce == null) {
+                    return null;
+                }
+                ITmfTrace trace = (ITmfTrace) ce.createExecutableExtension(TmfTraceType.TRACE_TYPE_ATTR);
                 return trace;
             }
         } catch (CoreException e) {
@@ -210,7 +248,8 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     }
 
     /**
-     * Instantiate a <code>ITmfEvent</code> object based on the trace type and the corresponding extension.
+     * Instantiate a <code>ITmfEvent</code> object based on the trace type and
+     * the corresponding extension.
      *
      * @return the <code>ITmfEvent</code> or <code>null</code> for an error
      */
@@ -232,6 +271,9 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
                     }
                 }
                 IConfigurationElement ce = sfTraceTypeAttributes.get(fTraceTypeId);
+                if (ce == null) {
+                    return null;
+                }
                 ITmfEvent event = (ITmfEvent) ce.createExecutableExtension(TmfTraceType.EVENT_TYPE_ATTR);
                 return event;
             }
@@ -243,6 +285,7 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
 
     /**
      * Returns the optional editor ID from the trace type extension.
+     *
      * @return the editor ID or <code>null</code> if not defined.
      */
     public String getEditorId() {
@@ -263,15 +306,65 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     }
 
     /**
-     * Returns the <code>TmfTraceElement</code> located under the <code>TmfTracesFolder</code>.
-     * 
-     * @return <code>this</code> if this element is under the <code>TmfTracesFolder</code> 
-     *         else the corresponding <code>TmfTraceElement</code> if this element is under 
+     * Returns the file resource used to store bookmarks after creating it if
+     * necessary. If the trace resource is a file, it is returned directly. If
+     * the trace resource is a folder, a linked file is returned. The file will
+     * be created if it does not exist.
+     *
+     * @return the bookmarks file
+     * @throws CoreException
+     *             if the bookmarks file cannot be created
+     * @since 2.0
+     */
+    public IFile createBookmarksFile() throws CoreException {
+        IFile file = getBookmarksFile();
+        if (fResource instanceof IFolder) {
+            if (!file.exists()) {
+                final IFile bookmarksFile = getProject().getTracesFolder().getResource().getFile(BOOKMARKS_HIDDEN_FILE);
+                if (!bookmarksFile.exists()) {
+                    final InputStream source = new ByteArrayInputStream(new byte[0]);
+                    bookmarksFile.create(source, true, null);
+                }
+                bookmarksFile.setHidden(true);
+                file.createLink(bookmarksFile.getLocation(), IResource.REPLACE, null);
+                file.setHidden(true);
+                file.setPersistentProperty(TmfCommonConstants.TRACETYPE, TmfTrace.class.getCanonicalName());
+            }
+        }
+        return file;
+    }
+
+    /**
+     * Returns the file resource used to store bookmarks. The file may not
+     * exist.
+     *
+     * @return the bookmarks file
+     * @since 2.0
+     */
+    public IFile getBookmarksFile() {
+        IFile file = null;
+        if (fResource instanceof IFile) {
+            file = (IFile) fResource;
+        } else if (fResource instanceof IFolder) {
+            final IFolder folder = (IFolder) fResource;
+            file = folder.getFile(getName() + '_');
+        }
+        return file;
+    }
+
+    /**
+     * Returns the <code>TmfTraceElement</code> located under the
+     * <code>TmfTracesFolder</code>.
+     *
+     * @return <code>this</code> if this element is under the
+     *         <code>TmfTracesFolder</code> else the corresponding
+     *         <code>TmfTraceElement</code> if this element is under
      *         <code>TmfExperimentElement</code>.
      */
     public TmfTraceElement getElementUnderTraceFolder() {
 
-        // If trace is under an experiment, return original trace from the traces folder
+        // If trace is under an experiment, return original trace from the
+        // traces folder
         if (getParent() instanceof TmfExperimentElement) {
             for (TmfTraceElement aTrace : getProject().getTracesFolder().getTraces()) {
                 if (aTrace.getName().equals(getName())) {
@@ -281,146 +374,6 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
         }
         return this;
     }
-    
-    /**
-     * Deletes the trace specific supplementary folder.
-     */
-    public void deleteSupplementaryFolder() {
-        IFolder supplFolder = getTraceSupplementaryFolder(fResource.getName());
-        if (supplFolder.exists()) {
-            try {
-                supplFolder.delete(true, new NullProgressMonitor());
-            } catch (CoreException e) {
-                Activator.getDefault().logError("Error deleting supplementary folder " + supplFolder, e); //$NON-NLS-1$
-            }
-        }
-    }
-
-    /**
-     * Renames the trace specific supplementary folder according to the new trace name.
-     * 
-     * @param newTraceName The new trace name 
-     */
-    public void renameSupplementaryFolder(String newTraceName) {
-        IFolder oldSupplFolder = getTraceSupplementaryFolder(fResource.getName());
-        IFolder newSupplFolder =  getTraceSupplementaryFolder(newTraceName);
-
-        // Rename supplementary folder
-        if (oldSupplFolder.exists()) {
-            try {
-                oldSupplFolder.move(newSupplFolder.getFullPath(), true, new NullProgressMonitor());
-            } catch (CoreException e) {
-                Activator.getDefault().logError("Error renaming supplementary folder " + oldSupplFolder, e); //$NON-NLS-1$
-            }
-        }
-    }
-
-    /**
-     * Copies the trace specific supplementary folder to the new trace name.
-     * 
-     * @param newTraceName The new trace name 
-     */
-    public void copySupplementaryFolder(String newTraceName) {
-        IFolder oldSupplFolder = getTraceSupplementaryFolder(fResource.getName());
-        IFolder newSupplFolder = getTraceSupplementaryFolder(newTraceName);
-
-        // copy supplementary folder
-        if (oldSupplFolder.exists()) {
-            try {
-                oldSupplFolder.copy(newSupplFolder.getFullPath(), true, new NullProgressMonitor());
-            } catch (CoreException e) {
-                Activator.getDefault().logError("Error renaming supplementary folder " + oldSupplFolder, e); //$NON-NLS-1$
-            }
-        }
-    }
-
-    /**
-     * Copies the trace specific supplementary folder a new folder.
-     * 
-     * @param destination The destination folder to copy to. 
-     */
-    public void copySupplementaryFolder(IFolder destination) {
-        IFolder oldSupplFolder = getTraceSupplementaryFolder(fResource.getName());
-
-        // copy supplementary folder
-        if (oldSupplFolder.exists()) {
-            try {
-                oldSupplFolder.copy(destination.getFullPath(), true, new NullProgressMonitor());
-            } catch (CoreException e) {
-                Activator.getDefault().logError("Error copying supplementary folder " + oldSupplFolder, e); //$NON-NLS-1$
-            }
-        }
-    }
-
-    
-    /**
-     * Refreshes the trace specific supplementary folder information. It creates the folder if not exists.
-     * It sets the persistence property of the trace resource  
-     */
-    public void refreshSupplementaryFolder() {
-        createSupplementaryDirectory();
-    }
-
-    /**
-     * Checks if supplementary resource exist or not.
-     *  
-     * @return <code>true</code> if one or more files are under the trace supplementary folder
-     */
-    public boolean hasSupplementaryResources() {
-        IResource[] resources = getSupplementaryResources();
-        return (resources.length > 0);
-    }
-    
-    /**
-     * Returns the supplementary resources under the trace supplementary folder.
-     *  
-     * @return array of resources under the trace supplementary folder.
-     */
-    public IResource[] getSupplementaryResources() {
-        IFolder supplFolder = getTraceSupplementaryFolder(fResource.getName());
-        if (supplFolder.exists()) {
-            try {
-                return supplFolder.members();
-            } catch (CoreException e) {
-                Activator.getDefault().logError("Error deleting supplementary folder " + supplFolder, e); //$NON-NLS-1$
-            }
-        }
-        return new IResource[0];
-    }
-
-    /**
-     * Deletes the given resources.  
-     * 
-     * @param resources array of resources to delete.
-     */
-    public void deleteSupplementaryResources(IResource[] resources) {
-        
-        for (int i = 0; i < resources.length; i++) {
-            try {
-                resources[i].delete(true, new NullProgressMonitor());
-            } catch (CoreException e) {
-                Activator.getDefault().logError("Error deleting supplementary resource " + resources[i], e); //$NON-NLS-1$
-            }
-        }
-    }
-
-    private void createSupplementaryDirectory() {
-        IFolder supplFolder = getTraceSupplementaryFolder(fResource.getName());
-        if (!supplFolder.exists()) {
-            try {
-                supplFolder.create(true, true, new NullProgressMonitor());
-            } catch (CoreException e) {
-                Activator.getDefault().logError("Error creating resource supplementary file " + supplFolder, e); //$NON-NLS-1$
-            }
-        }
-
-        try {
-            fResource.setPersistentProperty(TmfCommonConstants.TRACE_SUPPLEMENTARY_FOLDER, supplFolder.getLocationURI().getPath());
-        } catch (CoreException e) {
-            Activator.getDefault().logError("Error setting persistant property " + TmfCommonConstants.TRACE_SUPPLEMENTARY_FOLDER, e); //$NON-NLS-1$
-        }
-        
-    }
 
     // ------------------------------------------------------------------------
     // IActionFilter
@@ -438,10 +391,7 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     // ------------------------------------------------------------------------
     // TmfTraceElement
     // ------------------------------------------------------------------------
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.project.model.ITmfProjectModelElement#getProject()
-     */
+
     @Override
     public TmfProjectElement getProject() {
         if (getParent() instanceof TmfTraceFolder) {
@@ -462,28 +412,53 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
     // IPropertySource2
     // ------------------------------------------------------------------------
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
-     */
     @Override
     public Object getEditableValue() {
         return null;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
+    /**
+     * Get the trace properties of this traceElement if the corresponding trace
+     * is opened in an editor
+     *
+     * @return a map with the names and values of the trace properties
+     *         respectively as keys and values
      */
+    private Map<String, String> getTraceProperties() {
+        for (ITmfTrace openedTrace : TmfTraceManager.getInstance().getOpenedTraces()) {
+            for (ITmfTrace singleTrace : TmfTraceManager.getTraceSet(openedTrace)) {
+                if (this.getLocation().toString().endsWith(singleTrace.getPath())) {
+                    if (singleTrace instanceof ITmfTraceProperties) {
+                        ITmfTraceProperties traceProperties = (ITmfTraceProperties) singleTrace;
+                        return traceProperties.getTraceProperties();
+                    }
+                }
+            }
+        }
+        return new HashMap<String, String>();
+    }
+
     @Override
     public IPropertyDescriptor[] getPropertyDescriptors() {
-        return (sfDescriptors != null) ? Arrays.copyOf(sfDescriptors, sfDescriptors.length) : null;
+        Map<String, String> traceProperties = getTraceProperties();
+        if (!traceProperties.isEmpty()) {
+            IPropertyDescriptor[] propertyDescriptorArray = new IPropertyDescriptor[traceProperties.size() + sfDescriptors.length];
+            int index = 0;
+            for (Map.Entry<String, String> varName : traceProperties.entrySet()) {
+                ReadOnlyTextPropertyDescriptor descriptor = new ReadOnlyTextPropertyDescriptor(this.getName() + "_" + varName.getKey(), varName.getKey()); //$NON-NLS-1$
+                descriptor.setCategory(sfTracePropertiesCategory);
+                propertyDescriptorArray[index] = descriptor;
+                index++;
+            }
+            for (int i = 0; i < sfDescriptors.length; i++) {
+                propertyDescriptorArray[index] = sfDescriptors[i];
+                index++;
+            }
+            return propertyDescriptorArray;
+        }
+        return Arrays.copyOf(sfDescriptors, sfDescriptors.length);
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
-     */
     @Override
     public Object getPropertyValue(Object id) {
 
@@ -510,6 +485,14 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
             }
         }
 
+        Map<String, String> traceProperties = getTraceProperties();
+        if (id != null && !traceProperties.isEmpty()) {
+            String key = (String) id;
+            key = key.replaceFirst(this.getName() + "_", ""); //$NON-NLS-1$ //$NON-NLS-2$
+            String value = traceProperties.get(key);
+            return value;
+        }
+
         return null;
     }
 
@@ -524,38 +507,132 @@ public class TmfTraceElement extends TmfProjectModelElement implements IActionFi
         return "[no category]"; //$NON-NLS-1$
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
-     */
     @Override
     public void resetPropertyValue(Object id) {
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object, java.lang.Object)
-     */
     @Override
     public void setPropertyValue(Object id, Object value) {
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.ui.views.properties.IPropertySource2#isPropertyResettable(java.lang.Object)
-     */
     @Override
     public boolean isPropertyResettable(Object id) {
         return false;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.ui.views.properties.IPropertySource2#isPropertySet(java.lang.Object)
-     */
     @Override
     public boolean isPropertySet(Object id) {
         return false;
     }
 
+    /**
+     * Copy this trace in the trace folder. No other parameters are mentioned so
+     * the trace is copied in this element's project trace folder
+     *
+     * @param string
+     *            The new trace name
+     * @return the new Resource object
+     * @since 2.0
+     */
+    public TmfTraceElement copy(String string) {
+        TmfTraceFolder folder = this.getProject().getTracesFolder();
+        IResource res = super.copy(string, false);
+        return new TmfTraceElement(string, res, folder);
+    }
+
+    /**
+     * Close opened editors associated with this trace.
+     *
+     * @since 2.0
+     */
+    public void closeEditors() {
+        // Close the trace if open
+        IFile file = getBookmarksFile();
+        FileEditorInput input = new FileEditorInput(file);
+        IWorkbench wb = PlatformUI.getWorkbench();
+        for (IWorkbenchWindow wbWindow : wb.getWorkbenchWindows()) {
+            for (IWorkbenchPage wbPage : wbWindow.getPages()) {
+                for (IEditorReference editorReference : wbPage.getEditorReferences()) {
+                    try {
+                        if (editorReference.getEditorInput().equals(input)) {
+                            wbPage.closeEditor(editorReference.getEditor(false), false);
+                        }
+                    } catch (PartInitException e) {
+                        Activator.getDefault().logError("Error closing editor for trace " + getName(), e); //$NON-NLS-1$
+                    }
+                }
+            }
+        }
+
+        // Close experiments that contain the trace if open
+        if (getParent() instanceof TmfTraceFolder) {
+            TmfExperimentFolder experimentFolder = getProject().getExperimentsFolder();
+            for (ITmfProjectModelElement experiment : experimentFolder.getChildren()) {
+                for (ITmfProjectModelElement child : experiment.getChildren()) {
+                    if (child.getName().equals(getName())) {
+                        ((TmfExperimentElement) experiment).closeEditors();
+                        break;
+                    }
+                }
+            }
+        } else if (getParent() instanceof TmfExperimentElement) {
+            TmfExperimentElement experiment = (TmfExperimentElement) getParent();
+            experiment.closeEditors();
+        }
+    }
+
+    /**
+     * Delete the trace resource, remove it from experiments and delete its
+     * supplementary files
+     *
+     * @param progressMonitor
+     *            a progress monitor, or null if progress reporting is not
+     *            desired
+     *
+     * @throws CoreException
+     *             thrown when IResource.delete fails
+     * @since 2.2
+     */
+    public void delete(IProgressMonitor progressMonitor) throws CoreException {
+        closeEditors();
+
+        IPath path = fResource.getLocation();
+        if (path != null && (getParent() instanceof TmfTraceFolder)) {
+            TmfExperimentFolder experimentFolder = getProject().getExperimentsFolder();
+
+            // Propagate the removal to traces
+            for (ITmfProjectModelElement experiment : experimentFolder.getChildren()) {
+                List<ITmfProjectModelElement> toRemove = new LinkedList<ITmfProjectModelElement>();
+                for (ITmfProjectModelElement child : experiment.getChildren()) {
+                    if (child.getName().equals(getName())) {
+                        toRemove.add(child);
+                    }
+                }
+                for (ITmfProjectModelElement child : toRemove) {
+                    ((TmfExperimentElement) experiment).removeTrace((TmfTraceElement) child);
+                }
+            }
+
+            // Delete supplementary files
+            deleteSupplementaryFolder();
+        }
+
+        // Finally, delete the trace
+        fResource.delete(true, progressMonitor);
+    }
+
+    /**
+     * Get the instantiated trace associated with this element.
+     *
+     * @return The instantiated trace or null if trace is not (yet) available
+     * @since 2.1
+     */
+    public ITmfTrace getTrace() {
+        for (ITmfTrace trace : TmfTraceManager.getInstance().getOpenedTraces()) {
+            if (trace.getResource().equals(getResource())) {
+                return trace;
+            }
+        }
+        return null;
+    }
 }
