@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2012 Ericsson
+ * Copyright (c) 2010, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -41,6 +41,7 @@ import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.Point;
+import org.eclipse.swt.graphics.RGB;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -142,9 +143,6 @@ public class ColorsView extends TmfView {
         super("Colors"); //$NON-NLS-1$
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.ui.part.WorkbenchPart#createPartControl(Composite)
-     */
     @Override
     public void createPartControl(Composite parent) {
         fShell = parent.getShell();
@@ -205,9 +203,6 @@ public class ColorsView extends TmfView {
         fillToolBar();
     }
 
-    /* (non-Javadoc)
-     * @see org.eclipse.ui.part.WorkbenchPart#setFocus()
-     */
     @Override
     public void setFocus() {
         fScrolledComposite.setFocus();
@@ -449,9 +444,12 @@ public class ColorsView extends TmfView {
                     dialog.setRGB(colorSetting.getForegroundRGB());
                     dialog.setText(Messages.ColorsView_ForegroundDialogText);
                     dialog.open();
-                    colorSetting.setForegroundRGB(dialog.getRGB());
-                    ColorSettingsManager.setColorSettings(fColorSettings.toArray(new ColorSetting[0]));
-                    label.setForeground(colorSetting.getForegroundColor());
+                    RGB rgb = dialog.getRGB();
+                    if (rgb != null) {
+                        colorSetting.setForegroundRGB(rgb);
+                        ColorSettingsManager.setColorSettings(fColorSettings.toArray(new ColorSetting[0]));
+                        label.setForeground(colorSetting.getForegroundColor());
+                    }
                 }});
 
             bgButton.addSelectionListener(new SelectionAdapter() {
@@ -463,10 +461,13 @@ public class ColorsView extends TmfView {
                     dialog.setRGB(colorSetting.getBackgroundRGB());
                     dialog.setText(Messages.ColorsView_BackgroundDialogText);
                     dialog.open();
-                    colorSetting.setBackgroundRGB(dialog.getRGB());
-                    ColorSettingsManager.setColorSettings(fColorSettings.toArray(new ColorSetting[0]));
-                    labelComposite.setBackground(colorSetting.getBackgroundColor());
-                    label.setBackground(colorSetting.getBackgroundColor());
+                    RGB rgb = dialog.getRGB();
+                    if (rgb != null) {
+                        colorSetting.setBackgroundRGB(rgb);
+                        ColorSettingsManager.setColorSettings(fColorSettings.toArray(new ColorSetting[0]));
+                        labelComposite.setBackground(colorSetting.getBackgroundColor());
+                        label.setBackground(colorSetting.getBackgroundColor());
+                    }
                 }});
 
             final Button tickButton = new Button(this, SWT.PUSH);
@@ -505,9 +506,12 @@ public class ColorsView extends TmfView {
                     dialog.setRGB(colorSetting.getTickColorRGB());
                     dialog.setText(Messages.TickColorDialog_TickColorDialogTitle);
                     dialog.open();
-                    colorSetting.setTickColorRGB(dialog.getRGB());
-                    ColorSettingsManager.setColorSettings(fColorSettings.toArray(new ColorSetting[0]));
-                    refresh();
+                    RGB rgb = dialog.getRGB();
+                    if (rgb != null) {
+                        colorSetting.setTickColorRGB(rgb);
+                        ColorSettingsManager.setColorSettings(fColorSettings.toArray(new ColorSetting[0]));
+                        refresh();
+                    }
                 }});
 
             final Button filterButton = new Button(this, SWT.PUSH);
