@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2011, 2012 Ericsson
+ * Copyright (c) 2011, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -9,20 +9,34 @@
  * Contributors:
  *   Francois Chouinard - Initial API and implementation
  *   Bernd Hufmann - Changed to updated histogram data model
- *   Francois Chouinard - Initial API and implementation
+ *   Francois Chouinard - Reformat histogram labels on format change
+ *   Patrick Tasse - Support selection range
  *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.ui.views.histogram;
 
+import org.eclipse.linuxtools.tmf.core.signal.TmfSignalHandler;
+import org.eclipse.linuxtools.tmf.core.signal.TmfSignalManager;
+import org.eclipse.linuxtools.tmf.core.signal.TmfTimestampFormatUpdateSignal;
+import org.eclipse.linuxtools.tmf.core.timestamp.ITmfTimestamp;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimestamp;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimestampDelta;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimestampFormat;
 import org.eclipse.linuxtools.tmf.ui.views.TmfView;
+import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ControlEvent;
 import org.eclipse.swt.events.ControlListener;
+import org.eclipse.swt.events.FocusAdapter;
+import org.eclipse.swt.events.FocusEvent;
+import org.eclipse.swt.events.FocusListener;
 import org.eclipse.swt.events.KeyEvent;
 import org.eclipse.swt.events.KeyListener;
 import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.events.MouseListener;
+import org.eclipse.swt.events.MouseMoveListener;
 import org.eclipse.swt.events.MouseTrackListener;
+import org.eclipse.swt.events.MouseWheelListener;
 import org.eclipse.swt.events.PaintEvent;
 import org.eclipse.swt.events.PaintListener;
 import org.eclipse.swt.graphics.Color;
@@ -36,6 +50,7 @@ import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Canvas;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
+import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Text;
 
 /**
@@ -72,10 +87,10 @@ import org.eclipse.swt.widgets.Text;
  * <li>number of events in that time range
  * </ul>
  *
- * @version 1.0
+ * @version 1.1
  * @author Francois Chouinard
  */
-public abstract class Histogram implements ControlListener, PaintListener, KeyListener, MouseListener, MouseTrackListener, IHistogramModelListener {
+public abstract class Histogram implements ControlListener, PaintListener, KeyListener, MouseListener, MouseMoveListener, MouseTrackListener, IHistogramModelListener {
 
     // ------------------------------------------------------------------------
     // Constants
@@ -83,31 +98,48 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
 
     // Histogram colors
     private final Color fBackgroundColor = Display.getCurrent().getSystemColor(SWT.COLOR_WHITE);
-    private final Color fCurrentEventColor = Display.getCurrent().getSystemColor(SWT.COLOR_RED);
+    private final Color fSelectionForegroundColor = Display.getCurrent().getSystemColor(SWT.COLOR_BLUE);
+    private final Color fSelectionBackgroundColor = Display.getCurrent().getSystemColor(SWT.COLOR_WIDGET_BACKGROUND);
     private final Color fLastEventColor = Display.getCurrent().getSystemColor(SWT.COLOR_DARK_RED);
     private final Color fHistoBarColor = new Color(Display.getDefault(), 74, 112, 139);
+    private final Color fLostEventColor = new Color(Display.getCurrent(), 208, 62, 120);
+    private final Color fFillColor = Display.getCurrent().getSystemColor(SWT.COLOR_WIDGET_BACKGROUND);
+    private final Color fTimeRangeColor = new Color(Display.getCurrent(), 255, 128, 0);
 
-    // Timestamp scale (nanosecond)
+    // Drag states
     /**
-     * The time scale of the histogram (nano seconds)
+     * No drag in progress
+     * @since 2.2
      */
-    public static final byte TIME_SCALE = -9;
-
+    protected final int DRAG_NONE = 0;
     /**
-     * The histogram bar width (number of pixels).
+     * Drag the selection
+     * @since 2.2
      */
-    public static final int HISTOGRAM_BAR_WIDTH = 1;
+    protected final int DRAG_SELECTION = 1;
+    /**
+     * Drag the time range
+     * @since 2.2
+     */
+    protected final int DRAG_RANGE = 2;
+    /**
+     * Drag the zoom range
+     * @since 2.2
+     */
+    protected final int DRAG_ZOOM = 3;
 
     // ------------------------------------------------------------------------
     // Attributes
     // ------------------------------------------------------------------------
 
-    // Owner view
     /**
      * The parent TMF view.
      */
     protected TmfView fParentView;
 
+    private Composite fComposite;
+    private Font fFont;
+
     // Histogram text fields
     private Text fMaxNbEventsText;
     private Text fMinNbEventsText;
@@ -115,26 +147,62 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
     private Text fTimeRangeEndText;
 
     /**
-     *  Histogram drawing area
+     * Histogram drawing area
      */
     protected Canvas fCanvas;
+
     /**
-     *  The histogram data model.
+     * The histogram data model.
      */
     protected final HistogramDataModel fDataModel;
+
     /**
      * The histogram data model scaled to current resolution and screen width.
      */
     protected HistogramScaledData fScaledData;
 
-    protected long fCurrentEventTime = 0;
+    /**
+     * The current event value
+     */
+    protected long fCurrentEventTime = 0L;
+
+    /**
+     * The current selection begin time
+     */
+    private long fSelectionBegin = 0L;
+
+    /**
+     * The current selection end time
+     */
+    private long fSelectionEnd = 0L;
+
+    /**
+     * The drag state
+     * @see #DRAG_NONE
+     * @see #DRAG_SELECTION
+     * @see #DRAG_RANGE
+     * @see #DRAG_ZOOM
+     * @since 2.2
+     */
+    protected int fDragState = DRAG_NONE;
+
+    /**
+     * The button that started a mouse drag, or 0 if no drag in progress
+     * @since 2.2
+     */
+    protected int fDragButton = 0;
+
+    /**
+     * The bucket display offset
+     */
+    private int fOffset = 0;
 
     // ------------------------------------------------------------------------
     // Construction
     // ------------------------------------------------------------------------
 
     /**
-     * Standard constructor.
+     * Full constructor.
      *
      * @param view A reference to the parent TMF view.
      * @param parent A parent composite
@@ -142,7 +210,7 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
     public Histogram(final TmfView view, final Composite parent) {
         fParentView = view;
 
-        createWidget(parent);
+        fComposite = createWidget(parent);
         fDataModel = new HistogramDataModel();
         fDataModel.addHistogramListener(this);
         clear();
@@ -152,20 +220,27 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         fCanvas.addKeyListener(this);
         fCanvas.addMouseListener(this);
         fCanvas.addMouseTrackListener(this);
+        fCanvas.addMouseMoveListener(this);
+
+        TmfSignalManager.register(this);
     }
 
     /**
-     * Dispose resources and deregisters listeners.
+     * Dispose resources and unregisters listeners.
      */
     public void dispose() {
+        TmfSignalManager.deregister(this);
+
         fHistoBarColor.dispose();
+        fLastEventColor.dispose();
+        fTimeRangeColor.dispose();
         fDataModel.removeHistogramListener(this);
     }
 
-    private void createWidget(final Composite parent) {
+    private Composite createWidget(final Composite parent) {
 
         final Color labelColor = parent.getBackground();
-        final Font fFont = adjustFont(parent);
+        fFont = adjustFont(parent);
 
         final int initalWidth = 10;
 
@@ -190,6 +265,7 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         gridData.horizontalAlignment = SWT.FILL;
         gridData.verticalAlignment = SWT.FILL;
         gridData.grabExcessHorizontalSpace = true;
+        gridData.grabExcessVerticalSpace = true;
         composite.setLayoutData(gridData);
 
         // Y-axis max event
@@ -210,7 +286,10 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         gridData.verticalSpan = 2;
         gridData.horizontalAlignment = SWT.FILL;
         gridData.verticalAlignment = SWT.FILL;
+        gridData.heightHint = 0;
+        gridData.widthHint = 0;
         gridData.grabExcessHorizontalSpace = true;
+        gridData.grabExcessVerticalSpace = true;
         canvasComposite.setLayoutData(gridData);
         canvasComposite.setLayout(new FillLayout());
         fCanvas = new Canvas(canvasComposite, SWT.DOUBLE_BUFFERED);
@@ -230,12 +309,8 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         gridData = new GridData(initalWidth, SWT.DEFAULT);
         gridData.horizontalAlignment = SWT.RIGHT;
         gridData.verticalAlignment = SWT.BOTTOM;
-        final Text dummyText = new Text(composite, SWT.READ_ONLY);
-        dummyText.setFont(fFont);
-        dummyText.setBackground(labelColor);
-        dummyText.setEditable(false);
-        dummyText.setText(""); //$NON-NLS-1$
-        dummyText.setLayoutData(gridData);
+        final Label dummyLabel = new Label(composite, SWT.NONE);
+        dummyLabel.setLayoutData(gridData);
 
         // Window range start time
         gridData = new GridData();
@@ -244,7 +319,6 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         fTimeRangeStartText = new Text(composite, SWT.READ_ONLY);
         fTimeRangeStartText.setFont(fFont);
         fTimeRangeStartText.setBackground(labelColor);
-        fTimeRangeStartText.setText(HistogramUtils.nanosecondsToString(0));
         fTimeRangeStartText.setLayoutData(gridData);
 
         // Window range end time
@@ -254,8 +328,20 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         fTimeRangeEndText = new Text(composite, SWT.READ_ONLY);
         fTimeRangeEndText.setFont(fFont);
         fTimeRangeEndText.setBackground(labelColor);
-        fTimeRangeEndText.setText(HistogramUtils.nanosecondsToString(0));
         fTimeRangeEndText.setLayoutData(gridData);
+
+        FocusListener listener = new FocusAdapter() {
+            @Override
+            public void focusGained(FocusEvent e) {
+                fCanvas.setFocus();
+            }
+        };
+        fMaxNbEventsText.addFocusListener(listener);
+        fMinNbEventsText.addFocusListener(listener);
+        fTimeRangeStartText.addFocusListener(listener);
+        fTimeRangeEndText.addFocusListener(listener);
+
+        return composite;
     }
 
     private static Font adjustFont(final Composite composite) {
@@ -271,7 +357,7 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
     // ------------------------------------------------------------------------
 
     /**
-     * Returns the start time (equal first bucket time).
+     * Returns the start time (equal first bucket time)
      * @return the start time.
      */
     public long getStartTime() {
@@ -302,6 +388,16 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         return fDataModel;
     }
 
+    /**
+     * Returns the text control for the maximum of events in one bar
+     *
+     * @return the text control
+     * @since 2.2
+     */
+    public Text getMaxNbEventsText() {
+        return fMaxNbEventsText;
+    }
+
     // ------------------------------------------------------------------------
     // Operations
     // ------------------------------------------------------------------------
@@ -310,23 +406,32 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
      * @param startTime A start time
      * @param endTime A end time.
      */
-    public abstract void updateTimeRange(long startTime, long endTime);
+    public void updateTimeRange(long startTime, long endTime) {
+        if (fDragState == DRAG_NONE) {
+            ((HistogramView) fParentView).updateTimeRange(startTime, endTime);
+        }
+    }
 
     /**
      * Clear the histogram and reset the data
      */
     public void clear() {
         fDataModel.clear();
-        fScaledData = null;
+        if (fDragState == DRAG_SELECTION) {
+            updateSelectionTime();
+        }
+        fDragState = DRAG_NONE;
+        fDragButton = 0;
+        synchronized (fDataModel) {
+            fScaledData = null;
+        }
     }
 
     /**
      * Increase the histogram bucket corresponding to [timestamp]
      *
-     * @param eventCount
-     *            The new event count
-     * @param timestamp
-     *            The latest timestamp
+     * @param eventCount The new event count
+     * @param timestamp The latest timestamp
      */
     public void countEvent(final long eventCount, final long timestamp) {
         fDataModel.countEvent(eventCount, timestamp);
@@ -335,12 +440,27 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
     /**
      * Sets the current event time and refresh the display
      *
-     * @param timestamp
-     *            The time of the current event
+     * @param timestamp The time of the current event
+     * @deprecated As of 2.1, use {@link #setSelection(long, long)}
      */
+    @Deprecated
     public void setCurrentEvent(final long timestamp) {
-        fCurrentEventTime = (timestamp > 0) ? timestamp : 0;
-        fDataModel.setCurrentEventNotifyListeners(timestamp);
+        fSelectionBegin = (timestamp > 0) ? timestamp : 0;
+        fSelectionEnd = (timestamp > 0) ? timestamp : 0;
+        fDataModel.setSelectionNotifyListeners(timestamp, timestamp);
+    }
+
+    /**
+     * Sets the current selection time range and refresh the display
+     *
+     * @param beginTime The begin time of the current selection
+     * @param endTime The end time of the current selection
+     * @since 2.1
+     */
+    public void setSelection(final long beginTime, final long endTime) {
+        fSelectionBegin = (beginTime > 0) ? beginTime : 0;
+        fSelectionEnd = (endTime > 0) ? endTime : 0;
+        fDataModel.setSelectionNotifyListeners(beginTime, endTime);
     }
 
     /**
@@ -352,7 +472,7 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
     public synchronized long getTimestamp(final int offset) {
         assert offset > 0 && offset < fScaledData.fWidth;
         try {
-            return fDataModel.getFirstBucketTime() + fScaledData.fBucketDuration * offset;
+            return fScaledData.fFirstBucketTime + fScaledData.fBucketDuration * offset;
         } catch (final Exception e) {
             return 0; // TODO: Fix that racing condition (NPE)
         }
@@ -371,6 +491,17 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         return (int) ((timestamp - fDataModel.getFirstBucketTime()) / fScaledData.fBucketDuration);
     }
 
+    /**
+     * Set the bucket display offset
+     *
+     * @param offset
+     *            the bucket display offset
+     * @since 2.2
+     */
+    protected void setOffset(final int offset) {
+        fOffset = offset;
+    }
+
     /**
      * Move the currently selected bar cursor to a non-empty bucket.
      *
@@ -378,58 +509,57 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
      */
     protected void moveCursor(final int keyCode) {
 
-        if (fScaledData.fCurrentBucket == HistogramScaledData.OUT_OF_RANGE_BUCKET) {
-            return;
-        }
-
         int index;
         switch (keyCode) {
 
-            case SWT.HOME:
-                index = 0;
-                while (index < fScaledData.fLastBucket && fScaledData.fData[index] == 0) {
-                    index++;
-                }
-                if (index < fScaledData.fLastBucket) {
-                    fScaledData.fCurrentBucket = index;
-                }
-                break;
+        case SWT.HOME:
+            index = 0;
+            while (index < fScaledData.fLastBucket && fScaledData.fData[index] == 0) {
+                index++;
+            }
+            if (index < fScaledData.fLastBucket) {
+                fScaledData.fSelectionBeginBucket = index;
+            }
+            break;
 
-            case SWT.ARROW_RIGHT:
-                index = fScaledData.fCurrentBucket + 1;
-                while (index < fScaledData.fWidth && fScaledData.fData[index] == 0) {
-                    index++;
-                }
-                if (index < fScaledData.fLastBucket) {
-                    fScaledData.fCurrentBucket = index;
-                }
-                break;
+        case SWT.ARROW_RIGHT:
+            index = Math.max(0, fScaledData.fSelectionBeginBucket + 1);
+            while (index < fScaledData.fWidth && fScaledData.fData[index] == 0) {
+                index++;
+            }
+            if (index < fScaledData.fLastBucket) {
+                fScaledData.fSelectionBeginBucket = index;
+            }
+            break;
 
-            case SWT.END:
-                index = fScaledData.fLastBucket;
-                while (index >= 0 && fScaledData.fData[index] == 0) {
-                    index--;
-                }
-                if (index >= 0) {
-                    fScaledData.fCurrentBucket = index;
-                }
-                break;
+        case SWT.END:
+            index = fScaledData.fLastBucket;
+            while (index >= 0 && fScaledData.fData[index] == 0) {
+                index--;
+            }
+            if (index >= 0) {
+                fScaledData.fSelectionBeginBucket = index;
+            }
+            break;
 
-            case SWT.ARROW_LEFT:
-                index = fScaledData.fCurrentBucket - 1;
-                while (index >= 0 && fScaledData.fData[index] == 0) {
-                    index--;
-                }
-                if (index >= 0) {
-                    fScaledData.fCurrentBucket = index;
-                }
-                break;
+        case SWT.ARROW_LEFT:
+            index = Math.min(fScaledData.fLastBucket - 1, fScaledData.fSelectionBeginBucket - 1);
+            while (index >= 0 && fScaledData.fData[index] == 0) {
+                index--;
+            }
+            if (index >= 0) {
+                fScaledData.fSelectionBeginBucket = index;
+            }
+            break;
 
-            default:
-                return;
+        default:
+            return;
         }
 
-        updateCurrentEventTime();
+        fScaledData.fSelectionEndBucket = fScaledData.fSelectionBeginBucket;
+        fSelectionBegin = getTimestamp(fScaledData.fSelectionBeginBucket);
+        fSelectionEnd = fSelectionBegin;
+        updateSelectionTime();
     }
 
     /**
@@ -448,16 +578,18 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
                         if (canvasWidth <= 0 || canvasHeight <= 0) {
                             return;
                         }
-                        fDataModel.setCurrentEvent(fCurrentEventTime);
-                        fScaledData = fDataModel.scaleTo(canvasWidth, canvasHeight, HISTOGRAM_BAR_WIDTH);
-                        synchronized(fScaledData) {
+                        fDataModel.setSelection(fSelectionBegin, fSelectionEnd);
+                        fScaledData = fDataModel.scaleTo(canvasWidth, canvasHeight, 1);
+                        synchronized (fDataModel) {
                             if (fScaledData != null) {
                                 fCanvas.redraw();
                                 // Display histogram and update X-,Y-axis labels
-                                fTimeRangeStartText.setText(HistogramUtils.nanosecondsToString(fDataModel.getFirstBucketTime()));
-                                fTimeRangeEndText.setText(HistogramUtils.nanosecondsToString(fDataModel.getEndTime()));
-                                fMaxNbEventsText.setText(Long.toString(fScaledData.fMaxValue));
+                                updateRangeTextControls();
+                                long maxNbEvents = HistogramScaledData.hideLostEvents ? fScaledData.fMaxValue : fScaledData.fMaxCombinedValue;
+                                fMaxNbEventsText.setText(Long.toString(maxNbEvents));
                                 // The Y-axis area might need to be re-sized
+                                GridData gd = (GridData) fMaxNbEventsText.getLayoutData();
+                                gd.widthHint = Math.max(gd.widthHint, fMaxNbEventsText.computeSize(SWT.DEFAULT, SWT.DEFAULT).x);
                                 fMaxNbEventsText.getParent().layout();
                             }
                         }
@@ -467,13 +599,48 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         }
     }
 
+    /**
+     * Add a mouse wheel listener to the histogram
+     * @param listener the mouse wheel listener
+     * @since 2.0
+     */
+    public void addMouseWheelListener(MouseWheelListener listener) {
+        fCanvas.addMouseWheelListener(listener);
+    }
+
+    /**
+     * Remove a mouse wheel listener from the histogram
+     * @param listener the mouse wheel listener
+     * @since 2.0
+     */
+    public void removeMouseWheelListener(MouseWheelListener listener) {
+        fCanvas.removeMouseWheelListener(listener);
+    }
+
     // ------------------------------------------------------------------------
     // Helper functions
     // ------------------------------------------------------------------------
 
-    private void updateCurrentEventTime() {
-        final long bucketStartTime = getTimestamp(fScaledData.fCurrentBucket);
-        ((HistogramView) fParentView).updateCurrentEventTime(bucketStartTime);
+    private void updateSelectionTime() {
+        if (fSelectionBegin > fSelectionEnd) {
+            long end = fSelectionBegin;
+            fSelectionBegin = fSelectionEnd;
+            fSelectionEnd = end;
+        }
+        ((HistogramView) fParentView).updateSelectionTime(fSelectionBegin, fSelectionEnd);
+    }
+
+    /**
+     * Update the range text controls
+     */
+    private void updateRangeTextControls() {
+        if (fDataModel.getStartTime() < fDataModel.getEndTime()) {
+            fTimeRangeStartText.setText(TmfTimestampFormat.getDefaulTimeFormat().format(fDataModel.getStartTime()));
+            fTimeRangeEndText.setText(TmfTimestampFormat.getDefaulTimeFormat().format(fDataModel.getEndTime()));
+        } else {
+            fTimeRangeStartText.setText(""); //$NON-NLS-1$
+            fTimeRangeEndText.setText(""); //$NON-NLS-1$
+        }
     }
 
     // ------------------------------------------------------------------------
@@ -528,26 +695,59 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
             imageGC.fillRectangle(0, 0, image.getBounds().width + 1, image.getBounds().height + 1);
 
             // Draw the histogram bars
-            imageGC.setBackground(fHistoBarColor);
             final int limit = width < scaledData.fWidth ? width : scaledData.fWidth;
-            for (int i = 1; i < limit; i++) {
-                final int value = (int) Math.ceil(scaledData.fData[i] * scaledData.fScalingFactor);
-                imageGC.fillRectangle(i, height - value, 1, value);
+            double factor = HistogramScaledData.hideLostEvents ? scaledData.fScalingFactor : scaledData.fScalingFactorCombined;
+            for (int i = 0; i < limit; i++) {
+                final int value = (int) Math.ceil(scaledData.fData[i] * factor);
+                int x = i + fOffset;
+
+                // in Linux, the last pixel in a line is not drawn,
+                // so draw lost events first, one pixel too far
+                if (!HistogramScaledData.hideLostEvents) {
+                    imageGC.setForeground(fLostEventColor);
+                    final int lostEventValue = (int) Math.ceil(scaledData.fLostEventsData[i] * factor);
+                    if (lostEventValue != 0) {
+                        // drawing a line is inclusive, so we should remove 1 from y2
+                        // but we don't because Linux
+                        imageGC.drawLine(x, height - value - lostEventValue, x, height - value);
+                    }
+                }
+
+                // then draw normal events second, to overwrite that extra pixel
+                imageGC.setForeground(fHistoBarColor);
+                imageGC.drawLine(x, height - value, x, height);
             }
 
-            // Draw the current event bar
-            final int currentBucket = scaledData.fCurrentBucket;
-            if (currentBucket >= 0 && currentBucket < limit) {
-                drawDelimiter(imageGC, fCurrentEventColor, height, currentBucket);
+            // Draw the selection bars
+            int alpha = imageGC.getAlpha();
+            imageGC.setAlpha(100);
+            imageGC.setForeground(fSelectionForegroundColor);
+            imageGC.setBackground(fSelectionBackgroundColor);
+            final int beginBucket = scaledData.fSelectionBeginBucket + fOffset;
+            if (beginBucket >= 0 && beginBucket < limit) {
+                imageGC.drawLine(beginBucket, 0, beginBucket, height);
             }
+            final int endBucket = scaledData.fSelectionEndBucket + fOffset;
+            if (endBucket >= 0 && endBucket < limit && endBucket != beginBucket) {
+                imageGC.drawLine(endBucket, 0, endBucket, height);
+            }
+            if (Math.abs(endBucket - beginBucket) > 1) {
+                if (endBucket > beginBucket) {
+                    imageGC.fillRectangle(beginBucket + 1, 0, endBucket - beginBucket - 1, height);
+                } else {
+                    imageGC.fillRectangle(endBucket + 1, 0, beginBucket - endBucket - 1, height);
+                }
+            }
+            imageGC.setAlpha(alpha);
+
+            // Add a dashed line as a delimiter
+            int delimiterIndex = (int) ((getDataModel().getEndTime() - scaledData.getFirstBucketTime()) / scaledData.fBucketDuration) + 1;
+            drawDelimiter(imageGC, fLastEventColor, height, delimiterIndex);
+
+            // Fill the area to the right of delimiter with background color
+            imageGC.setBackground(fFillColor);
+            imageGC.fillRectangle(delimiterIndex + 1, 0, width - (delimiterIndex + 1), height);
 
-            // Add a dashed line as a delimiter (at the right of the last bar)
-            int lastEventIndex = limit - 1;
-            while (lastEventIndex >= 0 && scaledData.fData[lastEventIndex] == 0) {
-                lastEventIndex--;
-            }
-            lastEventIndex += (lastEventIndex < limit - 1) ? 1 : 0;
-            drawDelimiter(imageGC, fLastEventColor, height, lastEventIndex);
         } catch (final Exception e) {
             // Do nothing
         }
@@ -563,6 +763,56 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         imageGC.fillRectangle(index, 3 * dash, 1, height - 3 * dash);
     }
 
+    /**
+     * Draw a time range window
+     *
+     * @param imageGC
+     *            the GC
+     * @param rangeStartTime
+     *            the range start time
+     * @param rangeDuration
+     *            the range duration
+     * @since 2.2
+     */
+    protected void drawTimeRangeWindow(GC imageGC, long rangeStartTime, long rangeDuration) {
+
+        if (fScaledData == null) {
+            return;
+        }
+
+        // Map times to histogram coordinates
+        long bucketSpan = Math.max(fScaledData.fBucketDuration, 1);
+        long startTime = Math.min(rangeStartTime, rangeStartTime + rangeDuration);
+        int rangeWidth = (int) (Math.abs(rangeDuration) / bucketSpan);
+
+        int left = (int) ((startTime - fDataModel.getFirstBucketTime()) / bucketSpan);
+        int right = left + rangeWidth;
+        int center = (left + right) / 2;
+        int height = fCanvas.getSize().y;
+        int arc = Math.min(15, rangeWidth);
+
+        // Draw the selection window
+        imageGC.setForeground(fTimeRangeColor);
+        imageGC.setLineWidth(1);
+        imageGC.setLineStyle(SWT.LINE_SOLID);
+        imageGC.drawRoundRectangle(left, 0, rangeWidth, height - 1, arc, arc);
+
+        // Fill the selection window
+        imageGC.setBackground(fTimeRangeColor);
+        imageGC.setAlpha(35);
+        imageGC.fillRoundRectangle(left + 1, 1, rangeWidth - 1, height - 2, arc, arc);
+        imageGC.setAlpha(255);
+
+        // Draw the cross hair
+        imageGC.setForeground(fTimeRangeColor);
+        imageGC.setLineWidth(1);
+        imageGC.setLineStyle(SWT.LINE_SOLID);
+
+        int chHalfWidth = ((rangeWidth < 60) ? (rangeWidth * 2) / 3 : 40) / 2;
+        imageGC.drawLine(center - chHalfWidth, height / 2, center + chHalfWidth, height / 2);
+        imageGC.drawLine(center, (height / 2) - chHalfWidth, center, (height / 2) + chHalfWidth);
+    }
+
     // ------------------------------------------------------------------------
     // KeyListener
     // ------------------------------------------------------------------------
@@ -586,14 +836,49 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
 
     @Override
     public void mouseDown(final MouseEvent event) {
-        if (fDataModel.getNbEvents() > 0 && fScaledData.fLastBucket >= event.x) {
-            fScaledData.fCurrentBucket = event.x;
-            updateCurrentEventTime();
+        if (fScaledData != null && event.button == 1 && fDragState == DRAG_NONE && fDataModel.getStartTime() < fDataModel.getEndTime()) {
+            fDragState = DRAG_SELECTION;
+            fDragButton = event.button;
+            if ((event.stateMask & SWT.MODIFIER_MASK) == SWT.SHIFT) {
+                if (Math.abs(event.x - fScaledData.fSelectionBeginBucket) < Math.abs(event.x - fScaledData.fSelectionEndBucket)) {
+                    fScaledData.fSelectionBeginBucket = fScaledData.fSelectionEndBucket;
+                    fSelectionBegin = fSelectionEnd;
+                }
+                fSelectionEnd = Math.min(getTimestamp(event.x), getEndTime());
+                fScaledData.fSelectionEndBucket = (int) ((fSelectionEnd - fScaledData.fFirstBucketTime) / fScaledData.fBucketDuration);
+            } else {
+                fSelectionBegin = Math.min(getTimestamp(event.x), getEndTime());
+                fScaledData.fSelectionBeginBucket = (int) ((fSelectionBegin - fScaledData.fFirstBucketTime) / fScaledData.fBucketDuration);
+                fSelectionEnd = fSelectionBegin;
+                fScaledData.fSelectionEndBucket = fScaledData.fSelectionBeginBucket;
+            }
+            fCanvas.redraw();
         }
     }
 
     @Override
     public void mouseUp(final MouseEvent event) {
+        if (fDragState == DRAG_SELECTION && event.button == fDragButton) {
+            fDragState = DRAG_NONE;
+            fDragButton = 0;
+            updateSelectionTime();
+        }
+    }
+
+    // ------------------------------------------------------------------------
+    // MouseMoveListener
+    // ------------------------------------------------------------------------
+
+    /**
+     * @since 2.2
+     */
+    @Override
+    public void mouseMove(MouseEvent event) {
+        if (fDragState == DRAG_SELECTION && fDataModel.getStartTime() < fDataModel.getEndTime()) {
+            fSelectionEnd = Math.max(getStartTime(), Math.min(getEndTime(), getTimestamp(event.x)));
+            fScaledData.fSelectionEndBucket = (int) ((fSelectionEnd - fScaledData.fFirstBucketTime) / fScaledData.fBucketDuration);
+            fCanvas.redraw();
+        }
     }
 
     // ------------------------------------------------------------------------
@@ -610,10 +895,15 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
 
     @Override
     public void mouseHover(final MouseEvent event) {
-        if (fDataModel.getNbEvents() > 0 && fScaledData != null && fScaledData.fLastBucket >= event.x) {
-            final String tooltip = formatToolTipLabel(event.x);
-            fCanvas.setToolTipText(tooltip);
+        if (fDataModel.getStartTime() < fDataModel.getEndTime() && fScaledData != null) {
+            int delimiterIndex = (int) ((fDataModel.getEndTime() - fScaledData.getFirstBucketTime()) / fScaledData.fBucketDuration) + 1;
+            if (event.x < delimiterIndex) {
+                final String tooltip = formatToolTipLabel(event.x - fOffset);
+                fCanvas.setToolTipText(tooltip);
+                return;
+            }
         }
+        fCanvas.setToolTipText(null);
     }
 
     private String formatToolTipLabel(final int index) {
@@ -624,15 +914,25 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
         }
         final long endTime = fScaledData.getBucketEndTime(index);
         final int nbEvents = (index >= 0) ? fScaledData.fData[index] : 0;
-
+        final String newLine = System.getProperty("line.separator"); //$NON-NLS-1$
         final StringBuffer buffer = new StringBuffer();
-        buffer.append("Range = ["); //$NON-NLS-1$
-        buffer.append(HistogramUtils.nanosecondsToString(startTime));
-        buffer.append(","); //$NON-NLS-1$
-        buffer.append(HistogramUtils.nanosecondsToString(endTime));
-        buffer.append(")\n"); //$NON-NLS-1$
-        buffer.append("Event count = "); //$NON-NLS-1$
-        buffer.append(nbEvents);
+        int selectionBeginBucket = Math.min(fScaledData.fSelectionBeginBucket, fScaledData.fSelectionEndBucket);
+        int selectionEndBucket = Math.max(fScaledData.fSelectionBeginBucket, fScaledData.fSelectionEndBucket);
+        if (selectionBeginBucket <= index && index <= selectionEndBucket && fSelectionBegin != fSelectionEnd) {
+            TmfTimestampDelta delta = new TmfTimestampDelta(Math.abs(fSelectionEnd - fSelectionBegin), ITmfTimestamp.NANOSECOND_SCALE);
+            buffer.append(NLS.bind(Messages.Histogram_selectionSpanToolTip, delta.toString()));
+            buffer.append(newLine);
+        }
+        buffer.append(NLS.bind(Messages.Histogram_bucketRangeToolTip,
+                new TmfTimestamp(startTime, ITmfTimestamp.NANOSECOND_SCALE).toString(),
+                new TmfTimestamp(endTime, ITmfTimestamp.NANOSECOND_SCALE).toString()));
+        buffer.append(newLine);
+        buffer.append(NLS.bind(Messages.Histogram_eventCountToolTip, nbEvents));
+        if (!HistogramScaledData.hideLostEvents) {
+            final int nbLostEvents = (index >= 0) ? fScaledData.fLostEventsData[index] : 0;
+            buffer.append(newLine);
+            buffer.append(NLS.bind(Messages.Histogram_lostEventCountToolTip, nbLostEvents));
+        }
         return buffer.toString();
     }
 
@@ -649,4 +949,23 @@ public abstract class Histogram implements ControlListener, PaintListener, KeyLi
     public void controlResized(final ControlEvent event) {
         fDataModel.complete();
     }
+
+    // ------------------------------------------------------------------------
+    // Signal Handlers
+    // ------------------------------------------------------------------------
+
+    /**
+     * Format the timestamp and update the display
+     *
+     * @param signal
+     *            the incoming signal
+     * @since 2.0
+     */
+    @TmfSignalHandler
+    public void timestampFormatUpdated(TmfTimestampFormatUpdateSignal signal) {
+        updateRangeTextControls();
+
+        fComposite.layout();
+    }
+
 }
