@@ -1,16 +1,15 @@
 /**********************************************************************
- * Copyright (c) 2005, 2008 IBM Corporation and others.
- * Copyright (c) 2011, 2012 Ericsson.
- *
+ * Copyright (c) 2005, 2013 IBM Corporation, Ericsson
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- * IBM - Initial API and implementation
- * Bernd Hufmann - Updated for TMF
+ *     IBM - Initial API and implementation
+ *     Bernd Hufmann - Updated for TMF
  **********************************************************************/
+
 package org.eclipse.linuxtools.tmf.ui.views.uml2sd.dialogs;
 
 import java.util.ArrayList;
@@ -22,7 +21,7 @@ import org.eclipse.jface.dialogs.DialogSettings;
 import org.eclipse.linuxtools.internal.tmf.ui.Activator;
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDView;
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDFilterProvider;
-import org.eclipse.linuxtools.tmf.ui.views.uml2sd.util.SDMessages;
+import org.eclipse.linuxtools.tmf.ui.views.uml2sd.util.Messages;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
@@ -64,31 +63,31 @@ public class FilterListDialog extends Dialog {
     /**
      * The viewer and provided are kept here as attributes
      */
-    protected IViewPart fViewer = null;
+    private final IViewPart fViewer;
     /**
      * The filter provider implementation
      */
-    protected ISDFilterProvider fProvider = null;
+    private final ISDFilterProvider fProvider;
     /**
      * The filters are the result of editing this list
      */
-    protected List<FilterCriteria> fFilters;
+    private List<FilterCriteria> fFilters;
     /**
      * The add button.
      */
-    protected Button fAdd;
+    private Button fAdd;
     /**
      * The remove button.
      */
-    protected Button fRemove;
+    private Button fRemove;
     /**
      * The edit button.
      */
-    protected Button fEdit;
+    private Button fEdit;
     /**
      * The table with list of filters.
      */
-    protected Table fTable;
+    private Table fTable;
 
     // ------------------------------------------------------------------------
     // Constructor
@@ -105,7 +104,6 @@ public class FilterListDialog extends Dialog {
         fViewer = view;
         fProvider = loader;
         fFilters = null;
-        // filters = provider.getCurrentFilters();
         setShellStyle(SWT.DIALOG_TRIM | SWT.APPLICATION_MODAL);
     }
 
@@ -144,15 +142,11 @@ public class FilterListDialog extends Dialog {
         fRemove.setEnabled(count > 0);
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.jface.dialogs.Dialog#createDialogArea(org.eclipse.swt.widgets.Composite)
-     */
     @Override
     public Control createDialogArea(Composite parent) {
 
         Group ret = new Group(parent, SWT.NONE);
-        ret.setText(SDMessages._57);
+        ret.setText(Messages.SequenceDiagram_ListOfHideDisplayPatterns);
         RowLayout rowLayout = new RowLayout();
         rowLayout.wrap = false;
         rowLayout.pack = true;
@@ -169,25 +163,18 @@ public class FilterListDialog extends Dialog {
         fTable.setLayoutData(new RowData(220, 84));
         fTable.setHeaderVisible(false);
         fTable.addSelectionListener(new SelectionListener() {
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
-             */
+
             @Override
             public void widgetDefaultSelected(SelectionEvent e) {
                 int count = fTable.getSelectionCount();
                 if (count == 1) {
-                    Criteria criteria = openFilterDialog(((CriteriaTableItem) fTable.getSelection()[0].getData()).getCriteria(), SDMessages._63);
+                    Criteria criteria = openFilterDialog(((CriteriaTableItem) fTable.getSelection()[0].getData()).getCriteria(), Messages.SequenceDiagram_Update);
                     if (criteria != null) {
                         replaceSelectedCriteria(criteria);
                     }
                 }
             }
 
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
-             */
             @Override
             public void widgetSelected(SelectionEvent e) {
                 handleTableSelectionCount();
@@ -213,25 +200,18 @@ public class FilterListDialog extends Dialog {
         rowLayoutCommands.spacing = 8;
         commands.setLayout(rowLayoutCommands);
         fAdd = new Button(commands, SWT.NONE);
-        fAdd.setText(SDMessages._61);
+        fAdd.setText(Messages.SequenceDiagram_Add);
         fAdd.addSelectionListener(new SelectionListener() {
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
-             */
+
             @Override
             public void widgetDefaultSelected(SelectionEvent e) {
                 // Nothing to do
             }
 
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
-             */
             @Override
             public void widgetSelected(SelectionEvent e) {
                 Criteria init = new Criteria();
-                Criteria c = openFilterDialog(init, SDMessages._62);
+                Criteria c = openFilterDialog(init, Messages.SequenceDiagram_Create);
                 if (c != null) {
                     addCriteria(c, true, false, null);
                 }
@@ -239,24 +219,17 @@ public class FilterListDialog extends Dialog {
         });
 
         fEdit = new Button(commands, SWT.NONE);
-        fEdit.setText(SDMessages._60);
+        fEdit.setText(Messages.SequenceDiagram_EditIt);
         fEdit.addSelectionListener(new SelectionListener() {
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
-             */
+
             @Override
             public void widgetDefaultSelected(SelectionEvent e) {
                 // Nothing to do
             }
 
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
-             */
             @Override
             public void widgetSelected(SelectionEvent e) {
-                Criteria c = openFilterDialog(((CriteriaTableItem) fTable.getSelection()[0].getData()).getCriteria(), SDMessages._63);
+                Criteria c = openFilterDialog(((CriteriaTableItem) fTable.getSelection()[0].getData()).getCriteria(), Messages.SequenceDiagram_Update);
                 if (c != null) {
                     replaceSelectedCriteria(c);
                 }
@@ -265,21 +238,14 @@ public class FilterListDialog extends Dialog {
         fEdit.setEnabled(false);
 
         fRemove = new Button(commands, SWT.NONE);
-        fRemove.setText(SDMessages._64);
+        fRemove.setText(Messages.SequenceDiagram_Remove);
         fRemove.addSelectionListener(new SelectionListener() {
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
-             */
+
             @Override
             public void widgetDefaultSelected(SelectionEvent e) {
                 // Nothing to do
             }
 
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
-             */
             @Override
             public void widgetSelected(SelectionEvent e) {
                 fTable.remove(fTable.getSelectionIndices());
@@ -288,7 +254,7 @@ public class FilterListDialog extends Dialog {
         });
         fRemove.setEnabled(false);
 
-        getShell().setText(SDMessages._65);
+        getShell().setText(Messages.SequenceDiagram_SequenceDiagramHidePatterns);
         /*
          * for (int i=0;i<filters.size();i++) { if (filters.get(i) instanceof FilterCriteria)
          * addCriteria(((FilterCriteria)filters.get(i)).getCriteria(),true); }
@@ -307,15 +273,11 @@ public class FilterListDialog extends Dialog {
         SearchFilterDialog filter = new SearchFilterDialog((SDView) fViewer, fProvider, true, SWT.APPLICATION_MODAL);
         filter.setCriteria(criteria);
         filter.setOkText(action);
-        filter.setTitle(SDMessages._66);
+        filter.setTitle(Messages.SequenceDiagram_DefinitionOfHidePattern);
         filter.open();
         return filter.getCriteria();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.jface.window.Window#open()
-     */
     @Override
     public int open() {
         create();
@@ -325,10 +287,6 @@ public class FilterListDialog extends Dialog {
         return super.open();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.jface.dialogs.Dialog#okPressed()
-     */
     @Override
     public void okPressed() {
         if (fTable.getItemCount() > 0) {
@@ -527,7 +485,7 @@ public class FilterListDialog extends Dialog {
          */
         public void setCriteria(Criteria criteria) {
             fCriteria = criteria;
-            fTableItem.setText((fIsPositive ? SDMessages._59 : SDMessages._58) + " " + fCriteria.getExpression() + " " + fCriteria.getGraphNodeSummary(fProvider, fLoaderClassName)); //$NON-NLS-1$ //$NON-NLS-2$
+            fTableItem.setText((fIsPositive ? Messages.SequenceDiagram_display : Messages.SequenceDiagram_hide) + " " + fCriteria.getExpression() + " " + fCriteria.getGraphNodeSummary(fProvider, fLoaderClassName)); //$NON-NLS-1$ //$NON-NLS-2$
         }
 
         /**
