@@ -1,5 +1,5 @@
 /**********************************************************************
- * Copyright (c) 2011, 2012 Ericsson
+ * Copyright (c) 2011, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -9,6 +9,7 @@
  * Contributors:
  *   Bernd Hufmann - Initial API and implementation
  **********************************************************************/
+
 package org.eclipse.linuxtools.tmf.ui.views.uml2sd.loader;
 
 import java.util.ArrayList;
@@ -28,22 +29,25 @@ import org.eclipse.linuxtools.internal.tmf.ui.Activator;
 import org.eclipse.linuxtools.tmf.core.component.TmfComponent;
 import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
 import org.eclipse.linuxtools.tmf.core.event.ITmfEventField;
-import org.eclipse.linuxtools.tmf.core.event.ITmfTimestamp;
-import org.eclipse.linuxtools.tmf.core.event.TmfTimeRange;
-import org.eclipse.linuxtools.tmf.core.event.TmfTimestamp;
 import org.eclipse.linuxtools.tmf.core.request.ITmfDataRequest;
 import org.eclipse.linuxtools.tmf.core.request.ITmfEventRequest;
 import org.eclipse.linuxtools.tmf.core.request.TmfDataRequest;
 import org.eclipse.linuxtools.tmf.core.request.TmfEventRequest;
-import org.eclipse.linuxtools.tmf.core.signal.TmfExperimentDisposedSignal;
-import org.eclipse.linuxtools.tmf.core.signal.TmfExperimentSelectedSignal;
 import org.eclipse.linuxtools.tmf.core.signal.TmfRangeSynchSignal;
 import org.eclipse.linuxtools.tmf.core.signal.TmfSignal;
 import org.eclipse.linuxtools.tmf.core.signal.TmfSignalHandler;
 import org.eclipse.linuxtools.tmf.core.signal.TmfTimeSynchSignal;
-import org.eclipse.linuxtools.tmf.core.trace.TmfExperiment;
+import org.eclipse.linuxtools.tmf.core.signal.TmfTraceClosedSignal;
+import org.eclipse.linuxtools.tmf.core.signal.TmfTraceOpenedSignal;
+import org.eclipse.linuxtools.tmf.core.signal.TmfTraceSelectedSignal;
+import org.eclipse.linuxtools.tmf.core.timestamp.ITmfTimestamp;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimeRange;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimestamp;
+import org.eclipse.linuxtools.tmf.core.trace.ITmfTrace;
+import org.eclipse.linuxtools.tmf.core.trace.TmfTraceManager;
 import org.eclipse.linuxtools.tmf.core.uml2sd.ITmfSyncSequenceDiagramEvent;
 import org.eclipse.linuxtools.tmf.core.uml2sd.TmfSyncSequenceDiagramEvent;
+import org.eclipse.linuxtools.tmf.ui.editors.ITmfTraceEditor;
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDView;
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.core.Frame;
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.core.GraphNode;
@@ -57,6 +61,7 @@ import org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDFindProvi
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDGraphNodeSupporter;
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.load.IUml2SDLoader;
 import org.eclipse.swt.widgets.Display;
+import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.ISelectionListener;
 import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.IWorkbenchWindow;
@@ -104,19 +109,17 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
     /**
      * Default title name.
      */
-    protected final static String TITLE = Messages.TmfUml2SDSyncLoader_ViewName;
+    protected static final String TITLE = Messages.TmfUml2SDSyncLoader_ViewName;
     /**
      * Default block size for background request.
      */
-    protected final static int DEFAULT_BLOCK_SIZE = 50000;
+    protected static final int DEFAULT_BLOCK_SIZE = 50000;
     /**
      * Maximum number of messages per page.
      */
-    protected final static int MAX_NUM_OF_MSG = 10000;
-    /**
-     * Initial time range window.
-     */
-    protected final static long INITIAL_WINDOW_OFFSET = (1L * 100  * 1000 * 1000); // .1sec
+    protected static final int MAX_NUM_OF_MSG = 10000;
+
+    private static final int INDEXING_THREAD_SLEEP_VALUE = 100;
 
     // ------------------------------------------------------------------------
     // Attributes
@@ -124,25 +127,22 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
 
     // Experiment attributes
     /**
-     * The TMF experiment reference.
+     * The TMF trace reference.
+     * @since 2.0
      */
-    protected TmfExperiment<ITmfEvent> fExperiment = null;
+    protected ITmfTrace fTrace = null;
     /**
      * The current indexing event request.
      */
-    protected ITmfEventRequest<ITmfEvent> fIndexRequest = null;
+    protected ITmfEventRequest fIndexRequest = null;
     /**
      * The current request to fill a page.
      */
-    protected ITmfEventRequest<ITmfEvent> fPageRequest = null;
+    protected ITmfEventRequest fPageRequest = null;
     /**
      * Flag whether the time range signal was sent by this loader class or not
      */
-    volatile protected boolean fIsSignalSent = false;
-    /**
-     * The initial request window size.
-     */
-    volatile protected long fInitialWindow = INITIAL_WINDOW_OFFSET;
+    protected volatile boolean fIsSignalSent = false;
 
     // The view and event attributes
     /**
@@ -166,7 +166,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
     /**
      * The current page displayed.
      */
-    volatile protected int fCurrentPage = 0;
+    protected volatile int fCurrentPage = 0;
     /**
      * The current time selected.
      */
@@ -174,7 +174,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
     /**
      * Flag to specify that selection of message is done by selection or by signal.
      */
-    volatile protected boolean fIsSelect = false;
+    protected volatile boolean fIsSelect = false;
 
     // Search attributes
     /**
@@ -192,7 +192,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
     /**
      * The current find index within the list of found nodes (<code>fFindeResults</code> within a page.
      */
-    volatile protected int fCurrentFindIndex = 0;
+    protected volatile int fCurrentFindIndex = 0;
 
     // Filter attributes
     /**
@@ -228,16 +228,18 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
     // ------------------------------------------------------------------------
     // Operations
     // ------------------------------------------------------------------------
+
     /**
      * Returns the current time if available else null.
      *
      * @return the current time if available else null
+     * @since 2.0
      */
     public ITmfTimestamp getCurrentTime() {
         fLock.lock();
         try {
             if (fCurrentTime != null) {
-                return fCurrentTime.clone();
+                return fCurrentTime;
             }
             return null;
         } finally {
@@ -250,7 +252,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
      */
     public void waitForCompletion() {
         fLock.lock();
-        ITmfEventRequest<ITmfEvent> request = fPageRequest;
+        ITmfEventRequest request = fPageRequest;
         fLock.unlock();
         if (request != null) {
             try {
@@ -262,55 +264,77 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
     }
 
     /**
-     * Signal handler for the experiment selected signal.
-     *
-     * Spawns a request to index the experiment (checkpoints creation) as well as it fills
-     * the first page.
-     *
-     * @param signal The experiment selected signal
+     * Handler for the trace opened signal.
+     * @param signal The trace opened signal
+     * @since 2.0
      */
     @TmfSignalHandler
-    public void experimentSelected(TmfExperimentSelectedSignal<ITmfEvent> signal) {
+    public void traceOpened(TmfTraceOpenedSignal signal) {
+        fTrace = signal.getTrace();
+        loadTrace();
+    }
 
-        final Job job = new IndexingJob("Indexing " + getName() + "..."); //$NON-NLS-1$ //$NON-NLS-2$
-        job.setUser(false);
-        job.schedule();
 
+    /**
+     * Signal handler for the trace selected signal.
+     *
+     * Spawns a request to index the trace (checkpoints creation) as well as it fills
+     * the first page.
+     *
+     * @param signal The trace selected signal
+     * @since 2.0
+     */
+    @TmfSignalHandler
+    public void traceSelected(TmfTraceSelectedSignal signal) {
+        // Update the trace reference
+        ITmfTrace trace = signal.getTrace();
+        if (!trace.equals(fTrace)) {
+            fTrace = trace;
+        }
+        loadTrace();
+    }
+
+    /**
+     * Method for loading the current selected trace into the view.
+     * Sub-class need to override this method to add the view specific implementation.
+     * @since 2.0
+     */
+    protected void loadTrace() {
+        ITmfEventRequest indexRequest = null;
         fLock.lock();
+
         try {
-            // Update the trace reference
-            TmfExperiment<ITmfEvent> exp = (TmfExperiment<ITmfEvent>) signal.getExperiment();
-            if (!exp.equals(fExperiment)) {
-                fExperiment = exp;
-            }
+            final Job job = new IndexingJob("Indexing " + getName() + "..."); //$NON-NLS-1$ //$NON-NLS-2$
+            job.setUser(false);
+            job.schedule();
+
+            indexRequest = fIndexRequest;
+
+            cancelOngoingRequests();
 
             TmfTimeRange window = TmfTimeRange.ETERNITY;
 
-            fIndexRequest = new TmfEventRequest<ITmfEvent>(ITmfEvent.class, window, TmfDataRequest.ALL_DATA, DEFAULT_BLOCK_SIZE, ITmfDataRequest.ExecutionType.BACKGROUND) {
+            fIndexRequest = new TmfEventRequest(ITmfEvent.class, window, TmfDataRequest.ALL_DATA, DEFAULT_BLOCK_SIZE, ITmfDataRequest.ExecutionType.BACKGROUND) {
 
                 private ITmfTimestamp fFirstTime = null;
                 private ITmfTimestamp fLastTime = null;
                 private int fNbSeqEvents = 0;
                 private final List<ITmfSyncSequenceDiagramEvent> fSdEvents = new ArrayList<ITmfSyncSequenceDiagramEvent>(MAX_NUM_OF_MSG);
 
-                /*
-                 * (non-Javadoc)
-                 * @see org.eclipse.linuxtools.tmf.core.request.TmfDataRequest#handleData(org.eclipse.linuxtools.tmf.core.event.ITmfEvent)
-                 */
                 @Override
                 public void handleData(ITmfEvent event) {
                     super.handleData(event);
 
-                    ITmfSyncSequenceDiagramEvent sdEvent = getSequnceDiagramEvent(event);
+                    ITmfSyncSequenceDiagramEvent sdEvent = getSequenceDiagramEvent(event);
 
                     if (sdEvent != null) {
                         ++fNbSeqEvents;
 
                         if (fFirstTime == null) {
-                            fFirstTime = event.getTimestamp().clone();
+                            fFirstTime = event.getTimestamp();
                         }
 
-                        fLastTime = event.getTimestamp().clone();
+                        fLastTime = event.getTimestamp();
 
                         if ((fNbSeqEvents % MAX_NUM_OF_MSG) == 0) {
                             fLock.lock();
@@ -339,10 +363,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
                     }
                 }
 
-                /*
-                 * (non-Javadoc)
-                 * @see org.eclipse.linuxtools.tmf.core.request.TmfDataRequest#handleSuccess()
-                 */
                 @Override
                 public void handleSuccess() {
                     if ((fFirstTime != null) && (fLastTime != null)) {
@@ -365,44 +385,53 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
                     super.handleSuccess();
                 }
 
-                /*
-                 * (non-Javadoc)
-                 * @see org.eclipse.linuxtools.tmf.core.request.TmfDataRequest#handleCompleted()
-                 */
                 @Override
                 public void handleCompleted() {
                     if (fEvents.isEmpty()) {
                         fFrame = new Frame();
-                        fView.setFrameSync(fFrame);
+                        // make sure that view is not null when setting frame
+                        SDView sdView;
+                        fLock.lock();
+                        try {
+                            sdView = fView;
+                        } finally {
+                            fLock.unlock();
+                        }
+                        if (sdView != null) {
+                            sdView.setFrameSync(fFrame);
+                        }
                     }
                     super.handleCompleted();
                     job.cancel();
                 }
             };
 
-            fExperiment.sendRequest(fIndexRequest);
         } finally {
             fLock.unlock();
         }
-
+        if (indexRequest != null && !indexRequest.isCompleted()) {
+            indexRequest.cancel();
+        }
+        resetLoader();
+        fTrace.sendRequest(fIndexRequest);
     }
 
     /**
-     * Signal handler for the experiment disposed signal.
+     * Signal handler for the trace closed signal.
      *
-     * @param signal The experiment disposed signal
+     * @param signal The trace closed signal
+     * @since 2.0
      */
     @TmfSignalHandler
-    public void experimentDisposed(TmfExperimentDisposedSignal<ITmfEvent> signal) {
-        if (signal.getExperiment() != TmfExperiment.getCurrentExperiment()) {
+    public void traceClosed(TmfTraceClosedSignal signal) {
+        if (signal.getTrace() != fTrace) {
             return;
         }
+        ITmfEventRequest indexRequest = null;
         fLock.lock();
         try {
-            if ((fIndexRequest != null) && !fIndexRequest.isCompleted()) {
-                fIndexRequest.cancel();
-                fIndexRequest = null;
-            }
+            indexRequest = fIndexRequest;
+            fIndexRequest = null;
 
             cancelOngoingRequests();
 
@@ -411,11 +440,15 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
             }
 
             FilterListDialog.deactivateSavedGlobalFilters();
-
-            resetLoader();
         } finally {
+            fTrace = null;
             fLock.unlock();
         }
+        if (indexRequest != null && !indexRequest.isCompleted()) {
+            indexRequest.cancel();
+        }
+
+        resetLoader();
     }
 
     /**
@@ -429,7 +462,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         fLock.lock();
         try {
             if ((signal.getSource() != this) && (fFrame != null) && (fCheckPoints.size() > 0)) {
-                fCurrentTime = signal.getCurrentTime();
+                fCurrentTime = signal.getBeginTime();
                 fIsSelect = true;
                 moveToMessage();
             }
@@ -451,8 +484,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         try {
             if ((signal.getSource() != this) && (fFrame != null) && !fIsSignalSent && (fCheckPoints.size() > 0)) {
                 TmfTimeRange newTimeRange = signal.getCurrentRange();
-                ITmfTimestamp delta = newTimeRange.getEndTime().getDelta(newTimeRange.getStartTime());
-                fInitialWindow = delta.getValue();
 
                 fIsSelect = false;
                 fCurrentTime = newTimeRange.getStartTime();
@@ -465,10 +496,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
 
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.load.IUml2SDLoader#setViewer(org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDView)
-     */
     @Override
     public void setViewer(SDView viewer) {
 
@@ -481,32 +508,27 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
             fView.setSDFilterProvider(this);
 
             resetLoader();
-
-            fExperiment = (TmfExperiment<ITmfEvent>) TmfExperiment.getCurrentExperiment();
-            if (fExperiment != null) {
-                experimentSelected(new TmfExperimentSelectedSignal<ITmfEvent>(this, fExperiment));
+            IEditorPart editor = fView.getSite().getPage().getActiveEditor();
+            if (editor instanceof ITmfTraceEditor) {
+                ITmfTrace trace = ((ITmfTraceEditor) editor).getTrace();
+                if (trace != null) {
+                    traceSelected(new TmfTraceSelectedSignal(this, trace));
+                }
             }
         } finally {
             fLock.unlock();
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.load.IUml2SDLoader#getTitleString()
-     */
     @Override
     public String getTitleString() {
         return getName();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.component.TmfComponent#dispose()
-     */
     @Override
     public void dispose() {
        super.dispose();
+       ITmfEventRequest indexRequest = null;
        fLock.lock();
        try {
            IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
@@ -514,6 +536,11 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
            if (window != null) {
                window.getSelectionService().removePostSelectionListener(this);
            }
+
+           indexRequest = fIndexRequest;
+           fIndexRequest = null;
+           cancelOngoingRequests();
+
            fView.setSDFindProvider(null);
            fView.setSDPagingProvider(null);
            fView.setSDFilterProvider(null);
@@ -521,12 +548,11 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
        } finally {
            fLock.unlock();
        }
+       if (indexRequest != null && !indexRequest.isCompleted()) {
+           indexRequest.cancel();
+       }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.hyades.uml2sd.ui.actions.provider.ISDGraphNodeSupporter#isNodeSupported(int)
-     */
     @Override
     public boolean isNodeSupported(int nodeType) {
         switch (nodeType) {
@@ -540,10 +566,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         return false;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDGraphNodeSupporter#getNodeName(int, java.lang.String)
-     */
     @Override
     public String getNodeName(int nodeType, String loaderClassName) {
         switch (nodeType) {
@@ -557,10 +579,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         return ""; //$NON-NLS-1$
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.ui.ISelectionListener#selectionChanged(org.eclipse.ui.IWorkbenchPart, org.eclipse.jface.viewers.ISelection)
-     */
     @Override
     public void selectionChanged(IWorkbenchPart part, ISelection selection) {
         ISelection sel = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getSelectionService().getSelection();
@@ -573,11 +591,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see
-     * org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFindProvider#find(org.eclipse.hyades.uml2sd.ui.actions.widgets.Criteria)
-     */
     @Override
     public boolean find(Criteria toSearch) {
         fLock.lock();
@@ -610,8 +623,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
                     fFindResults.addAll(msgs);
                 }
 
-                @SuppressWarnings("rawtypes")
-                List selection = fView.getSDWidget().getSelection();
+                List<GraphNode> selection = fView.getSDWidget().getSelection();
                 if ((selection != null) && (selection.size() == 1)) {
                     fCurrentFindIndex = fFindResults.indexOf(selection.get(0)) + 1;
                 } else {
@@ -634,22 +646,13 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDFindProvider#cancel()
-     */
     @Override
     public void cancel() {
         cancelOngoingRequests();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDFilterProvider#filter(java.util.List)
-     */
-    @SuppressWarnings("unchecked")
     @Override
-    public boolean filter(List<?> filters) {
+    public boolean filter(List<FilterCriteria> filters) {
         fLock.lock();
         try {
             cancelOngoingRequests();
@@ -657,7 +660,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
             if (filters == null) {
                 fFilterCriteria =  new ArrayList<FilterCriteria>();
             } else {
-                List<FilterCriteria> list = (List<FilterCriteria>)filters;
+                List<FilterCriteria> list = filters;
                 fFilterCriteria =  new ArrayList<FilterCriteria>(list);
             }
 
@@ -669,10 +672,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         return true;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDPagingProvider#hasNextPage()
-     */
     @Override
     public boolean hasNextPage() {
         fLock.lock();
@@ -687,10 +686,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         return false;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDPagingProvider#hasPrevPage()
-     */
     @Override
     public boolean hasPrevPage() {
         fLock.lock();
@@ -701,10 +696,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDPagingProvider#nextPage()
-     */
     @Override
     public void nextPage() {
         fLock.lock();
@@ -723,10 +714,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDPagingProvider#prevPage()
-     */
     @Override
     public void prevPage() {
         fLock.lock();
@@ -745,10 +732,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDPagingProvider#firstPage()
-     */
     @Override
     public void firstPage() {
         fLock.lock();
@@ -763,10 +746,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDPagingProvider#lastPage()
-     */
     @Override
     public void lastPage() {
         fLock.lock();
@@ -780,10 +759,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDAdvancedPagingProvider#currentPage()
-     */
     @Override
     public int currentPage() {
         fLock.lock();
@@ -794,10 +769,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDAdvancedPagingProvider#pagesCount()
-     */
     @Override
     public int pagesCount() {
         fLock.lock();
@@ -808,10 +779,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.handlers.provider.ISDAdvancedPagingProvider#pageNumberChanged(int)
-     */
     @Override
     public void pageNumberChanged(int pagenNumber) {
         int localPageNumber = pagenNumber;
@@ -834,10 +801,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.linuxtools.tmf.component.TmfComponent#broadcast(org.eclipse.linuxtools.tmf.signal.TmfSignal)
-     */
     @Override
     public void broadcast(TmfSignal signal) {
         fIsSignalSent = true;
@@ -850,6 +813,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
      */
     protected void cancelOngoingRequests() {
         fLock.lock();
+        ITmfEventRequest pageRequest = null;
         try {
             // Cancel the search thread
             if (fFindJob != null) {
@@ -860,13 +824,14 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
             fFindCriteria = null;
             fCurrentFindIndex = 0;
 
-            if ((fPageRequest != null) && !fPageRequest.isCompleted()) {
-                fPageRequest.cancel();
-                fPageRequest = null;
-            }
+            pageRequest = fPageRequest;
+            fPageRequest = null;
         } finally {
             fLock.unlock();
         }
+        if (pageRequest != null && !pageRequest.isCompleted()) {
+            pageRequest.cancel();
+        }
     }
 
     /**
@@ -882,7 +847,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
             fCurrentFindIndex = 0;
             fFindCriteria = null;
             fFindResults = null;
-            fInitialWindow = INITIAL_WINDOW_OFFSET;
             fView.setFrameSync(new Frame());
             fFrame = null;
         }
@@ -902,7 +866,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         fLock.lock();
         try {
             fEvents = new ArrayList<ITmfSyncSequenceDiagramEvent>(events);
-            if (fView != null) {
+            if (fView != null && !events.isEmpty()) {
                 fView.toggleWaitCursorAsync(true);
             }
         } finally {
@@ -1113,14 +1077,14 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
             window = TmfTimeRange.ETERNITY;
         }
 
-        fPageRequest = new TmfEventRequest<ITmfEvent>(ITmfEvent.class, window, TmfDataRequest.ALL_DATA, 1, ITmfDataRequest.ExecutionType.FOREGROUND) {
+        fPageRequest = new TmfEventRequest(ITmfEvent.class, window, TmfDataRequest.ALL_DATA, 1, ITmfDataRequest.ExecutionType.FOREGROUND) {
             private final List<ITmfSyncSequenceDiagramEvent> fSdEvent = new ArrayList<ITmfSyncSequenceDiagramEvent>();
 
             @Override
             public void handleData(ITmfEvent event) {
                 super.handleData(event);
 
-                ITmfSyncSequenceDiagramEvent sdEvent = getSequnceDiagramEvent(event);
+                ITmfSyncSequenceDiagramEvent sdEvent = getSequenceDiagramEvent(event);
 
                 if (sdEvent != null) {
                     fSdEvent.add(sdEvent);
@@ -1135,11 +1099,11 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
 
         };
 
-        fExperiment.sendRequest(fPageRequest);
+        fTrace.sendRequest(fPageRequest);
 
         if (notifyAll) {
             TmfTimeRange timeRange = getSignalTimeRange(window.getStartTime());
-            broadcast(new TmfRangeSynchSignal(this, timeRange, timeRange.getStartTime()));
+            broadcast(new TmfRangeSynchSignal(this, timeRange));
         }
     }
 
@@ -1148,6 +1112,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
      *
      * @param time The timestamp
      * @return page that contains the time
+     * @since 2.0
      */
     protected int getPage(ITmfTimestamp time) {
         int page;
@@ -1190,7 +1155,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
                 return false;
             }
 
-            TmfTimeRange window = new TmfTimeRange(fCheckPoints.get(nextPage).getStartTime().clone(), fCheckPoints.get(fCheckPoints.size()-1).getEndTime().clone());
+            TmfTimeRange window = new TmfTimeRange(fCheckPoints.get(nextPage).getStartTime(), fCheckPoints.get(fCheckPoints.size()-1).getEndTime());
             fFindJob = new SearchJob(findCriteria, window);
             fFindJob.schedule();
             fView.toggleWaitCursorAsync(true);
@@ -1205,11 +1170,14 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
      *
      * @param startTime The start time of time range.
      * @return the time range
+     * @since 2.0
      */
     protected TmfTimeRange getSignalTimeRange(ITmfTimestamp startTime) {
         fLock.lock();
         try {
-            TmfTimestamp initialEndOfWindow = new TmfTimestamp(startTime.getValue() + fInitialWindow, startTime.getScale(), startTime.getPrecision());
+            TmfTimeRange currentRange = TmfTraceManager.getInstance().getCurrentRange();
+            long offset = fTrace == null ? 0 : currentRange.getEndTime().getDelta(currentRange.getStartTime()).normalize(0, startTime.getScale()).getValue();
+            TmfTimestamp initialEndOfWindow = new TmfTimestamp(startTime.getValue() + offset, startTime.getScale(), startTime.getPrecision());
             return new TmfTimeRange(startTime, initialEndOfWindow);
         }
         finally {
@@ -1269,28 +1237,25 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         /**
          * The search event request.
          */
-        final protected SearchEventRequest fSearchRequest;
+        protected final SearchEventRequest fSearchRequest;
 
         /**
          * Constructor
          *
          * @param findCriteria The search criteria
          * @param window Time range to search in
+         * @since 2.0
          */
         public SearchJob(Criteria findCriteria, TmfTimeRange window) {
             super(Messages.TmfUml2SDSyncLoader_SearchJobDescrition);
             fSearchRequest = new SearchEventRequest(window, TmfDataRequest.ALL_DATA, 1, ITmfDataRequest.ExecutionType.FOREGROUND, findCriteria);
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.core.runtime.jobs.Job#run(org.eclipse.core.runtime.IProgressMonitor)
-         */
         @Override
         protected IStatus run(IProgressMonitor monitor) {
             fSearchRequest.setMonitor(monitor);
 
-            fExperiment.sendRequest(fSearchRequest);
+            fTrace.sendRequest(fSearchRequest);
 
             try {
                 fSearchRequest.waitForCompletion();
@@ -1338,10 +1303,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
             return status;
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.core.runtime.jobs.Job#canceling()
-         */
         @Override
         protected void canceling() {
             fSearchRequest.cancel();
@@ -1357,12 +1318,12 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
     /**
      *  TMF event request for searching within trace.
      */
-    protected class SearchEventRequest extends TmfEventRequest<ITmfEvent> {
+    protected class SearchEventRequest extends TmfEventRequest {
 
         /**
          * The find criteria.
          */
-        final private Criteria fCriteria;
+        private final Criteria fCriteria;
         /**
          * A progress monitor
          */
@@ -1403,10 +1364,6 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
             fMonitor = monitor;
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.request.TmfDataRequest#handleData(org.eclipse.linuxtools.tmf.event.TmfData)
-         */
         @Override
         public void handleData(ITmfEvent event) {
             super.handleData(event);
@@ -1416,26 +1373,26 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
                 return;
             }
 
-            ITmfSyncSequenceDiagramEvent sdEvent = getSequnceDiagramEvent(event);
+            ITmfSyncSequenceDiagramEvent sdEvent = getSequenceDiagramEvent(event);
 
             if (sdEvent != null) {
 
                 if (fCriteria.isLifeLineSelected()) {
                     if (fCriteria.matches(sdEvent.getSender())) {
-                        fFoundTime = event.getTimestamp().clone();
+                        fFoundTime = event.getTimestamp();
                         fIsFound = true;
                         super.cancel();
                     }
 
                     if (fCriteria.matches(sdEvent.getReceiver())) {
-                        fFoundTime = event.getTimestamp().clone();
+                        fFoundTime = event.getTimestamp();
                         fIsFound = true;
                         super.cancel();
                     }
                 }
 
                 if (fCriteria.isSyncMessageSelected() && fCriteria.matches(sdEvent.getName())) {
-                    fFoundTime = event.getTimestamp().clone();
+                    fFoundTime = event.getTimestamp();
                     fIsFound = true;
                     super.cancel();
                 }
@@ -1464,6 +1421,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
          * Returns timestamp of found time.
          *
          * @return timestamp of found time.
+         * @since 2.0
          */
         public ITmfTimestamp getFoundTime() {
             return fFoundTime;
@@ -1479,6 +1437,9 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
      */
     protected static class IndexingJob extends Job {
 
+        /**
+         * @param name The job name
+         */
         public IndexingJob(String name) {
             super(name);
         }
@@ -1487,7 +1448,7 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
         protected IStatus run(IProgressMonitor monitor) {
             while (!monitor.isCanceled()) {
                 try {
-                    Thread.sleep(100);
+                    Thread.sleep(INDEXING_THREAD_SLEEP_VALUE);
                 } catch (InterruptedException e) {
                     return Status.OK_STATUS;
                 }
@@ -1503,15 +1464,16 @@ public class TmfUml2SDSyncLoader extends TmfComponent implements IUml2SDLoader,
      *
      * @param tmfEvent Event to parse for sequence diagram event details
      * @return sequence diagram event if details are available else null
+     * @since 2.0
      */
-    protected ITmfSyncSequenceDiagramEvent getSequnceDiagramEvent(ITmfEvent tmfEvent){
+    protected ITmfSyncSequenceDiagramEvent getSequenceDiagramEvent(ITmfEvent tmfEvent){
         //type = .*RECEIVE.* or .*SEND.*
         //content = sender:<sender name>:receiver:<receiver name>,signal:<signal name>
         String eventType = tmfEvent.getType().toString();
-        if (eventType.contains(Messages.TmfUml2SDSyncCloader_EventTypeSend) || eventType.contains(Messages.TmfUml2SDSyncCloader_EventTypeReceive)) {
-            Object sender = tmfEvent.getContent().getField(Messages.TmfUml2SDSyncCloader_FieldSender);
-            Object receiver = tmfEvent.getContent().getField(Messages.TmfUml2SDSyncCloader_FieldReceiver);
-            Object name = tmfEvent.getContent().getField(Messages.TmfUml2SDSyncCloader_FieldSignal);
+        if (eventType.contains(Messages.TmfUml2SDSyncLoader_EventTypeSend) || eventType.contains(Messages.TmfUml2SDSyncLoader_EventTypeReceive)) {
+            Object sender = tmfEvent.getContent().getField(Messages.TmfUml2SDSyncLoader_FieldSender);
+            Object receiver = tmfEvent.getContent().getField(Messages.TmfUml2SDSyncLoader_FieldReceiver);
+            Object name = tmfEvent.getContent().getField(Messages.TmfUml2SDSyncLoader_FieldSignal);
             if ((sender instanceof ITmfEventField) && (receiver instanceof ITmfEventField) && (name instanceof ITmfEventField)) {
                 ITmfSyncSequenceDiagramEvent sdEvent = new TmfSyncSequenceDiagramEvent(tmfEvent,
                                 ((ITmfEventField) sender).getValue().toString(),
