@@ -1,16 +1,15 @@
 /**********************************************************************
- * Copyright (c) 2005, 2008 IBM Corporation and others.
- * Copyright (c) 2011, 2012 Ericsson.
- *
+ * Copyright (c) 2005, 2013 IBM Corporation, Ericsson
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- * IBM - Initial API and implementation
- * Bernd Hufmann - Updated for TMF
+ *     IBM - Initial API and implementation
+ *     Bernd Hufmann - Updated for TMF
  **********************************************************************/
+
 package org.eclipse.linuxtools.tmf.ui.views.uml2sd.preferences;
 
 import java.util.Iterator;
@@ -22,7 +21,7 @@ import org.eclipse.jface.preference.ColorFieldEditor;
 import org.eclipse.jface.preference.FontFieldEditor;
 import org.eclipse.jface.preference.IntegerFieldEditor;
 import org.eclipse.jface.preference.PreferencePage;
-import org.eclipse.linuxtools.tmf.ui.views.uml2sd.util.SDMessages;
+import org.eclipse.linuxtools.tmf.ui.views.uml2sd.util.Messages;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
@@ -49,7 +48,7 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
     /**
      * Temporary preferences tag
      */
-    protected static final String TEMP_TAG = SDViewPref.TEMP_TAG;
+    private static final String TEMP_TAG = SDViewPref.TEMP_TAG;
 
     // ------------------------------------------------------------------------
     // Attributes
@@ -57,60 +56,56 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
     /**
      * The preference handler used to access the PreferenceStore
      */
-    protected SDViewPref fPreferences = null;
+    private SDViewPref fPreferences = null;
     /**
      * BackGround color selector
      */
-    protected ColorFieldEditor fLineColor = null;
+    private ColorFieldEditor fLineColor = null;
     /**
      * Foreground color selector
      */
-    protected ColorFieldEditor fBackGroundColor = null;
+    private ColorFieldEditor fBackGroundColor = null;
     /**
      * Font color selector
      */
-    protected ColorFieldEditor fTextColor = null;
+    private ColorFieldEditor fTextColor = null;
     /**
      * List which display all modifiable sequence Diagram font
      */
-    protected List fClassItemList = null;
+    private List fClassItemList = null;
     /**
      * Font selector (The same is used for each modifiable font)
      */
-    protected FontFieldEditor fFont = null;
+    private FontFieldEditor fFont = null;
     /**
      * Link font when zooming selector
      */
-    protected BooleanFieldEditor fLink = null;
+    private BooleanFieldEditor fLink = null;
     /**
      * Enable tooltip selector
      */
-    protected BooleanFieldEditor fTooltip = null;
+    private BooleanFieldEditor fTooltip = null;
     /**
      * Do not take external time into account in the min max computation
      */
-    protected BooleanFieldEditor fNoExternalTime = null;
+    private BooleanFieldEditor fNoExternalTime = null;
     /**
      * Use gradient color selector
      */
-    protected BooleanFieldEditor fUseGrad = null;
+    private BooleanFieldEditor fUseGrad = null;
     /**
      * A button area.
      */
-    protected Composite fButtonArea;
+    private Composite fButtonArea;
     /**
      * SwimLane width selector
      */
-    protected IntegerFieldEditor fLifelineWidth = null;
+    private IntegerFieldEditor fLifelineWidth = null;
 
     // ------------------------------------------------------------------------
     // Methods
     // ------------------------------------------------------------------------
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.jface.preference.PreferencePage#createContents(org.eclipse.swt.widgets.Composite)
-     */
     @Override
     protected Control createContents(Composite parent) {
         parent.setLayout(new GridLayout());
@@ -121,21 +116,21 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         page.setLayoutData(pageLayoutdata);
         page.setLayout(pageLayout);
 
-        fTooltip = new BooleanFieldEditor(ISDPreferences.PREF_TOOLTIP, SDMessages._97, page);
+        fTooltip = new BooleanFieldEditor(ISDPreferences.PREF_TOOLTIP, Messages.SequenceDiagram_ShowTooltips, page);
         fTooltip.setPreferenceStore(fPreferences.getPreferenceStore());
         fTooltip.load();
 
         // link font with zoom pref
-        fLink = new BooleanFieldEditor(ISDPreferences.PREF_LINK_FONT, SDMessages._82, page);
+        fLink = new BooleanFieldEditor(ISDPreferences.PREF_LINK_FONT, Messages.SequenceDiagram_IncreaseFontSizeWhenZooming, page);
         fLink.setPreferenceStore(fPreferences.getPreferenceStore());
         fLink.load();
 
-        fNoExternalTime = new BooleanFieldEditor(ISDPreferences.PREF_EXCLUDE_EXTERNAL_TIME, SDMessages._83, page);
+        fNoExternalTime = new BooleanFieldEditor(ISDPreferences.PREF_EXCLUDE_EXTERNAL_TIME, Messages.SequenceDiagram_ExcludeExternalTime, page);
         fNoExternalTime.setPreferenceStore(fPreferences.getPreferenceStore());
         fNoExternalTime.load();
 
         // use gradient color pref
-        fUseGrad = new BooleanFieldEditor(ISDPreferences.PREF_USE_GRADIENT, SDMessages._84, page);
+        fUseGrad = new BooleanFieldEditor(ISDPreferences.PREF_USE_GRADIENT, Messages.SequenceDiagram_UseGradientColor, page);
         fUseGrad.setPreferenceStore(fPreferences.getPreferenceStore());
         fUseGrad.load();
 
@@ -150,7 +145,7 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         prefPage.setLayout(prefPageLayout);
 
         // swimLane width pref
-        fLifelineWidth = new IntegerFieldEditor(ISDPreferences.PREF_LIFELINE_WIDTH, SDMessages._80, prefPage);
+        fLifelineWidth = new IntegerFieldEditor(ISDPreferences.PREF_LIFELINE_WIDTH, Messages.SequenceDiagram_LifelineWidth, prefPage);
         fLifelineWidth.setPreferenceStore(fPreferences.getPreferenceStore());
         fLifelineWidth.setValidRange(119, 500);
         fLifelineWidth.load();
@@ -180,20 +175,20 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         // font selector initialise for the lifeline font pref
         String[] fontList = SDViewPref.getFontList();
         fFont = new FontFieldEditor(fontList[0], "",//$NON-NLS-1$
-                SDMessages._81, fButtonArea);
+                Messages.SequenceDiagram_AaBbYyZz, fButtonArea);
         fFont.getPreviewControl().setSize(500, 500);
         fFont.setPreferenceStore(fPreferences.getPreferenceStore());
         fFont.load();
 
-        fBackGroundColor = new ColorFieldEditor(fontList[0] + SDViewPref.BACK_COLOR_POSTFIX, SDMessages._85, fButtonArea);
+        fBackGroundColor = new ColorFieldEditor(fontList[0] + SDViewPref.BACK_COLOR_POSTFIX, Messages.SequenceDiagram_Background, fButtonArea);
         fBackGroundColor.setPreferenceStore(fPreferences.getPreferenceStore());
         fBackGroundColor.load();
 
-        fLineColor = new ColorFieldEditor(fontList[0] + SDViewPref.FORE_COLOR_POSTFIX, SDMessages._86, fButtonArea);
+        fLineColor = new ColorFieldEditor(fontList[0] + SDViewPref.FORE_COLOR_POSTFIX, Messages.SequenceDiagram_Lines, fButtonArea);
         fLineColor.setPreferenceStore(fPreferences.getPreferenceStore());
         fLineColor.load();
 
-        fTextColor = new ColorFieldEditor(fontList[0] + SDViewPref.TEXT_COLOR_POSTFIX, SDMessages._87, fButtonArea);
+        fTextColor = new ColorFieldEditor(fontList[0] + SDViewPref.TEXT_COLOR_POSTFIX, Messages.SequenceDiagram_Text, fButtonArea);
         fTextColor.setPreferenceStore(fPreferences.getPreferenceStore());
         fTextColor.load();
         swapPref(true);
@@ -202,19 +197,11 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         return page;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
-     */
     @Override
     public void init(IWorkbench workbench) {
         fPreferences = SDViewPref.getInstance();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.jface.preference.PreferencePage#performApply()
-     */
     @Override
     protected void performApply() {
         // Store the prefrences in the PreferenceStore
@@ -237,20 +224,12 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         swapPref(true);
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.jface.preference.PreferencePage#performOk()
-     */
     @Override
     public boolean performOk() {
         performApply();
         return true;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.jface.preference.PreferencePage#performDefaults()
-     */
     @Override
     protected void performDefaults() {
         fLink.loadDefault();
@@ -262,7 +241,7 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         // and all the fonts and colors
         // fonts and colors are stored for each time because
         // we are using only one FontFieldEditor
-        Set<String> keySet = SDViewPref.getInstance().fFontPref.keySet();
+        Set<String> keySet = SDViewPref.getInstance().getFontPref().keySet();
         Iterator<String> it = keySet.iterator();
         while (it.hasNext()) {
             Object prefName = it.next();
@@ -274,7 +253,7 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
             }
         }
 
-        keySet = SDViewPref.getInstance().fBackColorPref.keySet();
+        keySet = SDViewPref.getInstance().getBackColorPref().keySet();
         it = keySet.iterator();
         while (it.hasNext()) {
             Object prefName = it.next();
@@ -291,7 +270,7 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         fBackGroundColor.setPreferenceName(fontList[fClassItemList.getSelectionIndex()] + SDViewPref.BACK_COLOR_POSTFIX + TEMP_TAG);
         fBackGroundColor.load();
 
-        keySet = SDViewPref.getInstance().fForeColorPref.keySet();
+        keySet = SDViewPref.getInstance().getForeColorPref().keySet();
         it = keySet.iterator();
         while (it.hasNext()) {
             Object prefName = it.next();
@@ -306,7 +285,7 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         fLineColor.setPreferenceName(fontList[fClassItemList.getSelectionIndex()] + SDViewPref.FORE_COLOR_POSTFIX + TEMP_TAG);
         fLineColor.load();
 
-        keySet = SDViewPref.getInstance().fTextColorPref.keySet();
+        keySet = SDViewPref.getInstance().getTextColorPref().keySet();
         it = keySet.iterator();
         while (it.hasNext()) {
             Object prefName = it.next();
@@ -321,10 +300,6 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         fTextColor.load();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
-     */
     @Override
     public void widgetSelected(SelectionEvent e) {
         // Store the past set font preference or else the
@@ -371,57 +346,62 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         }
     }
 
+    /**
+     * Swap viewer preferences.
+     *
+     * @param toTemp Switch to the temporary preferences
+     */
     protected void swapPref(boolean toTemp) {
-        String TAG1 = "";//$NON-NLS-1$
-        String TAG2 = TEMP_TAG;
+        String tag1 = "";//$NON-NLS-1$
+        String tag2 = TEMP_TAG;
         if (!toTemp) {
-            TAG1 = TEMP_TAG;
-            TAG2 = "";//$NON-NLS-1$
+            tag1 = TEMP_TAG;
+            tag2 = "";//$NON-NLS-1$
         }
-        Set<String> keySet = SDViewPref.getInstance().fFontPref.keySet();
+        Set<String> keySet = SDViewPref.getInstance().getFontPref().keySet();
         Iterator<String> it = keySet.iterator();
         while (it.hasNext()) {
             Object prefName = it.next();
             if (prefName instanceof String) {
-                fFont.setPreferenceName((String) prefName + TAG1);
+                fFont.setPreferenceName((String) prefName + tag1);
                 fFont.load();
-                fFont.setPreferenceName((String) prefName + TAG2);
+                fFont.setPreferenceName((String) prefName + tag2);
                 fFont.store();
             }
         }
 
-        keySet = SDViewPref.getInstance().fBackColorPref.keySet();
+        keySet = SDViewPref.getInstance().getBackColorPref().keySet();
         it = keySet.iterator();
         while (it.hasNext()) {
             Object prefName = it.next();
             if (prefName instanceof String) {
-                fBackGroundColor.setPreferenceName((String) prefName + TAG1);
+                fBackGroundColor.setPreferenceName((String) prefName + tag1);
                 fBackGroundColor.load();
-                fBackGroundColor.setPreferenceName((String) prefName + TAG2);
+                fBackGroundColor.setPreferenceName((String) prefName + tag2);
                 fBackGroundColor.store();
             }
         }
 
-        keySet = SDViewPref.getInstance().fForeColorPref.keySet();
+        keySet = SDViewPref.getInstance().getForeColorPref().keySet();
         it = keySet.iterator();
         while (it.hasNext()) {
             Object prefName = it.next();
             if (prefName instanceof String) {
-                fLineColor.setPreferenceName((String) prefName + TAG1);
+                fLineColor.setPreferenceName((String) prefName + tag1);
                 fLineColor.load();
-                fLineColor.setPreferenceName((String) prefName + TAG2);
+                fLineColor.setPreferenceName((String) prefName + tag2);
                 fLineColor.store();
             }
         }
 
-        keySet = SDViewPref.getInstance().fTextColorPref.keySet();
+        keySet = SDViewPref.getInstance().getTextColorPref().keySet();
         it = keySet.iterator();
         while (it.hasNext()) {
             Object prefName = it.next();
             if (prefName instanceof String) {
-                fTextColor.setPreferenceName((String) prefName + TAG1);
+                fTextColor.setPreferenceName((String) prefName + tag1);
                 fTextColor.load();
-                fTextColor.setPreferenceName((String) prefName + TAG2);
+                fTextColor.setPreferenceName((String) prefName + tag2);
                 fTextColor.store();
             }
         }
@@ -442,10 +422,6 @@ public class SDViewerPage extends PreferencePage implements IWorkbenchPreference
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
-     */
     @Override
     public void widgetDefaultSelected(SelectionEvent e) {
     }
