@@ -10,18 +10,24 @@
  *******************************************************************************/
 package org.eclipse.linuxtools.oprofile.ui.tests;
 
-import junit.framework.TestCase;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
 
 import org.eclipse.linuxtools.internal.oprofile.core.model.OpModelEvent;
+import org.eclipse.linuxtools.oprofile.ui.model.IUiModelElement;
+import org.eclipse.linuxtools.oprofile.ui.model.UiModelRoot;
+import org.eclipse.linuxtools.oprofile.ui.model.UiModelSample;
+import org.eclipse.linuxtools.oprofile.ui.model.UiModelSession;
+import org.eclipse.linuxtools.oprofile.ui.model.UiModelSymbol;
 import org.eclipse.linuxtools.oprofile.tests.TestPlugin;
 import org.eclipse.linuxtools.oprofile.tests.TestingOpModelRoot;
-import org.eclipse.linuxtools.internal.oprofile.ui.model.IUiModelElement;
-import org.eclipse.linuxtools.internal.oprofile.ui.model.UiModelRoot;
-import org.eclipse.linuxtools.internal.oprofile.ui.model.UiModelSample;
-import org.eclipse.linuxtools.internal.oprofile.ui.model.UiModelSession;
-import org.eclipse.linuxtools.internal.oprofile.ui.model.UiModelSymbol;
+import org.junit.Before;
+import org.junit.Test;
 
-public class TestUiDataModel extends TestCase {
+public class TestUiDataModel {
 
 	private static class TestingUiModelRoot extends UiModelRoot {
 		@Override
@@ -41,20 +47,18 @@ public class TestUiDataModel extends TestCase {
 
 	private TestingUiModelRoot _uiModelRoot;
 	private TestingUiModelRoot2 _uiModelRoot2;
-	
-	public TestUiDataModel() {
-		super("test ui data model classes"); //$NON-NLS-1$
-	}
-	
-	@Override
-	protected void setUp() {
+
+
+	@Before
+	public void setUp() {
 		_uiModelRoot = new TestingUiModelRoot();
 		_uiModelRoot.refreshModel();
-		
+
 		_uiModelRoot2 = new TestingUiModelRoot2();
 		_uiModelRoot2.refreshModel();
 	}
-	
+
+	@Test
 	public void testParse() {
 		/* test UiModelRoot */
 		assertNull(_uiModelRoot2.getLabelImage());
@@ -70,12 +74,12 @@ public class TestUiDataModel extends TestCase {
 		assertNull(r2_event1.getParent());
 		assertNotNull(r2_event1.getLabelImage());
 		assertNotNull(r2_event1.getLabelText());
-		
+
 		assertNull(_uiModelRoot.getLabelImage());
 		assertNull(_uiModelRoot.getParent());
 		assertNull(_uiModelRoot.getLabelText());
 		assertTrue(_uiModelRoot.hasChildren());
-		
+
 		/* test UiModelEvent */
 		IUiModelElement events[] = _uiModelRoot.getChildren();
 		assertNotNull(events);
@@ -89,19 +93,19 @@ public class TestUiDataModel extends TestCase {
 		assertTrue(events[0].hasChildren());
 		assertNull(events[0].getParent());		//events are top level tree elements
 		assertNotNull(events[0].getLabelImage());
-		
+
 		assertEquals(TestingOpModelRoot.NAME_E2, events[1].toString());
 		assertEquals(TestingOpModelRoot.NAME_E2, events[1].getLabelText());
 		assertTrue(events[1].hasChildren());
 		assertNull(events[1].getParent());		//events are top level tree elements
 		assertNotNull(events[1].getLabelImage());
-		
-		assertEquals("", events[2].toString()); //$NON-NLS-1$
-		assertEquals("", events[2].getLabelText()); //$NON-NLS-1$
+
+		assertTrue(events[2].toString().isEmpty());
+		assertTrue(events[2].getLabelText().isEmpty());
 		assertFalse(events[2].hasChildren());
 		assertNull(events[2].getParent());		//events are top level tree elements
 		assertNotNull(events[2].getLabelImage());
-		
+
 		/* test UiModelSession */
 		IUiModelElement[] e1_sessions = events[0].getChildren(), e2_sessions = events[1].getChildren();
 		assertNotNull(e1_sessions);
@@ -113,28 +117,28 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e2_sessions[1]);
 		assertNotNull(e2_sessions[2]);
 		assertNotNull(e2_sessions[3]);
-		
+
 		assertEquals(TestingOpModelRoot.NAME_E1_S1, e1_sessions[0].toString());
 		assertEquals(TestingOpModelRoot.NAME_E1_S1, e1_sessions[0].getLabelText());
 		assertFalse(((UiModelSession)e1_sessions[0]).isDefaultSession());
 		assertTrue(e1_sessions[0].hasChildren());
 		assertEquals(events[0], e1_sessions[0].getParent());
 		assertNotNull(e1_sessions[0].getLabelImage());
-		
+
 		assertEquals(TestingOpModelRoot.NAME_E2_S1, e2_sessions[0].toString());
 		assertEquals(TestingOpModelRoot.NAME_E2_S1, e2_sessions[0].getLabelText());
 		assertFalse(((UiModelSession)e2_sessions[0]).isDefaultSession());
 		assertTrue(e2_sessions[0].hasChildren());
 		assertEquals(events[1], e2_sessions[0].getParent());
 		assertNotNull(e2_sessions[0].getLabelImage());
-		
+
 		assertEquals(TestingOpModelRoot.NAME_E2_S2, e2_sessions[1].toString());
 		assertEquals(TestingOpModelRoot.NAME_E2_S2, e2_sessions[1].getLabelText());
 		assertFalse(((UiModelSession)e2_sessions[1]).isDefaultSession());
 		assertTrue(e2_sessions[1].hasChildren());
 		assertEquals(events[1], e2_sessions[1].getParent());
 		assertNotNull(e2_sessions[1].getLabelImage());
-		
+
 		assertEquals(TestingOpModelRoot.NAME_E2_S3, e2_sessions[2].toString());
 		assertEquals(TestingOpModelRoot.NAME_E2_S3, e2_sessions[2].getLabelText());
 		assertFalse(((UiModelSession)e2_sessions[2]).isDefaultSession());
@@ -150,12 +154,12 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e2_sessions[3].getLabelImage());
 
 		/* test UiModelImage and UiModelDependent */
-		IUiModelElement[] e1_s1_images = e1_sessions[0].getChildren(), 
+		IUiModelElement[] e1_s1_images = e1_sessions[0].getChildren(),
 							e2_s1_images = e2_sessions[0].getChildren(),
 							e2_s2_images = e2_sessions[1].getChildren(),
 							e2_s3_images = e2_sessions[2].getChildren(),
 							e2_s4_images = e2_sessions[3].getChildren();
-	
+
 		assertNotNull(e1_s1_images);
 		assertNotNull(e2_s1_images);
 		assertNotNull(e2_s2_images);
@@ -173,32 +177,32 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e2_s2_images[0]);
 		assertNotNull(e2_s3_images[0]);
 		assertNull(e2_s4_images[0]);
-		
-		//dont test string output -- strings are i18n'd and L10n'd 
+
+		//dont test string output -- strings are i18n'd and L10n'd
 		assertNotNull(e1_s1_images[0].toString());
 		assertNotNull(e1_s1_images[0].getLabelText());
 		assertTrue(e1_s1_images[0].hasChildren());
 		assertEquals(e1_sessions[0], e1_s1_images[0].getParent());
 		assertNotNull(e1_s1_images[0].getLabelImage());
-		
+
 		assertNotNull(e1_s1_images[1].toString());
 		assertNotNull(e1_s1_images[1].getLabelText());
 		assertTrue(e1_s1_images[1].hasChildren());
 		assertEquals(e1_sessions[0], e1_s1_images[1].getParent());
 		assertNotNull(e1_s1_images[1].getLabelImage());
-		
+
 		assertNotNull(e2_s1_images[0].toString());
 		assertNotNull(e2_s1_images[0].getLabelText());
 		assertTrue(e2_s1_images[0].hasChildren());
 		assertEquals(e2_sessions[0], e2_s1_images[0].getParent());
 		assertNotNull(e2_s1_images[0].getLabelImage());
-		
+
 		assertNotNull(e2_s1_images[1].toString());
 		assertNotNull(e2_s1_images[1].getLabelText());
 		assertTrue(e2_s1_images[1].hasChildren());
 		assertEquals(e2_sessions[0], e2_s1_images[1].getParent());
 		assertNotNull(e2_s1_images[1].getLabelImage());
-		
+
 		assertNotNull(e2_s2_images[0].toString());
 		assertNotNull(e2_s2_images[0].getLabelText());
 		assertTrue(e2_s2_images[0].hasChildren());
@@ -210,14 +214,14 @@ public class TestUiDataModel extends TestCase {
 		assertFalse(e2_s3_images[0].hasChildren());
 		assertEquals(e2_sessions[2], e2_s3_images[0].getParent());
 		assertNotNull(e2_s3_images[0].getLabelImage());
-		
+
 		/* test UiModelSymbol */
 		IUiModelElement[] e1_s1_i1_symbols = e1_s1_images[0].getChildren(),
 							e1_s1_i2_depimages = e1_s1_images[1].getChildren(),
 							e2_s1_i1_symbols = e2_s1_images[0].getChildren(),
 							e2_s1_i2_depimages = e2_s1_images[1].getChildren(),
 							e2_s2_i1_symbols = e2_s2_images[0].getChildren();
-		
+
 		assertNotNull(e1_s1_i1_symbols);
 		assertNotNull(e1_s1_i2_depimages);
 		assertNotNull(e2_s1_i1_symbols);
@@ -249,7 +253,7 @@ public class TestUiDataModel extends TestCase {
 		assertTrue(e1_s1_i1_symbols[0].hasChildren());
 		assertEquals(e1_s1_images[0], e1_s1_i1_symbols[0].getParent());
 		assertNotNull(e1_s1_i1_symbols[0].getLabelImage());
-		
+
 		assertNotNull(e1_s1_i1_symbols[1].toString());
 		assertNotNull(e1_s1_i1_symbols[1].getLabelText());
 		assertEquals(TestPlugin.SYMBOL2_FILENAME, ((UiModelSymbol)e1_s1_i1_symbols[1]).getFileName());
@@ -287,7 +291,7 @@ public class TestUiDataModel extends TestCase {
 		assertTrue(e2_s1_i1_symbols[0].hasChildren());
 		assertEquals(e2_s1_images[0], e2_s1_i1_symbols[0].getParent());
 		assertNotNull(e2_s1_i1_symbols[0].getLabelImage());
-		
+
 		assertNotNull(e2_s1_i1_symbols[1].toString());
 		assertNotNull(e2_s1_i1_symbols[1].getLabelText());
 		assertEquals(TestPlugin.SYMBOL2_FILENAME, ((UiModelSymbol)e2_s1_i1_symbols[1]).getFileName());
@@ -325,7 +329,7 @@ public class TestUiDataModel extends TestCase {
 		assertTrue(e2_s2_i1_symbols[0].hasChildren());
 		assertEquals(e2_s2_images[0], e2_s2_i1_symbols[0].getParent());
 		assertNotNull(e2_s2_i1_symbols[0].getLabelImage());
-		
+
 		assertNotNull(e2_s2_i1_symbols[1].toString());
 		assertNotNull(e2_s2_i1_symbols[1].getLabelText());
 		assertEquals(TestPlugin.SYMBOL2_FILENAME, ((UiModelSymbol)e2_s2_i1_symbols[1]).getFileName());
@@ -363,14 +367,14 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e2_s1_i2_dep2_symbols[1]);
 		assertNotNull(e2_s1_i2_dep4_symbols[0]);
 		assertNotNull(e2_s1_i2_dep4_symbols[1]);
-		
+
 		assertNotNull(e1_s1_i2_dep2_symbols[0].toString());
 		assertNotNull(e1_s1_i2_dep2_symbols[0].getLabelText());
 		assertEquals(TestPlugin.DEP2_SYMBOL1_FILENAME, ((UiModelSymbol)e1_s1_i2_dep2_symbols[0]).getFileName());
 		assertFalse(e1_s1_i2_dep2_symbols[0].hasChildren());
 		assertEquals(e1_s1_i2_depimages[1], e1_s1_i2_dep2_symbols[0].getParent());
 		assertNotNull(e1_s1_i2_dep2_symbols[0].getLabelImage());
-		
+
 		assertNotNull(e1_s1_i2_dep2_symbols[1].toString());
 		assertNotNull(e1_s1_i2_dep2_symbols[1].getLabelText());
 		assertEquals(TestPlugin.DEP2_SYMBOL2_FILENAME, ((UiModelSymbol)e1_s1_i2_dep2_symbols[1]).getFileName());
@@ -384,21 +388,21 @@ public class TestUiDataModel extends TestCase {
 		assertFalse(e1_s1_i2_dep4_symbols[0].hasChildren());
 		assertEquals(e1_s1_i2_depimages[3], e1_s1_i2_dep4_symbols[0].getParent());
 		assertNotNull(e1_s1_i2_dep4_symbols[0].getLabelImage());
-		
+
 		assertNotNull(e1_s1_i2_dep4_symbols[1].toString());
 		assertNotNull(e1_s1_i2_dep4_symbols[1].getLabelText());
 		assertEquals(TestPlugin.DEP4_SYMBOL_FILENAME, ((UiModelSymbol)e1_s1_i2_dep4_symbols[1]).getFileName());
 		assertFalse(e1_s1_i2_dep4_symbols[1].hasChildren());
 		assertEquals(e1_s1_i2_depimages[3], e1_s1_i2_dep4_symbols[1].getParent());
 		assertNotNull(e1_s1_i2_dep4_symbols[1].getLabelImage());
-		
+
 		assertNotNull(e2_s1_i2_dep2_symbols[0].toString());
 		assertNotNull(e2_s1_i2_dep2_symbols[0].getLabelText());
 		assertEquals(TestPlugin.DEP2_SYMBOL1_FILENAME, ((UiModelSymbol)e2_s1_i2_dep2_symbols[0]).getFileName());
 		assertFalse(e2_s1_i2_dep2_symbols[0].hasChildren());
 		assertEquals(e2_s1_i2_depimages[1], e2_s1_i2_dep2_symbols[0].getParent());
 		assertNotNull(e2_s1_i2_dep2_symbols[0].getLabelImage());
-		
+
 		assertNotNull(e2_s1_i2_dep2_symbols[1].toString());
 		assertNotNull(e2_s1_i2_dep2_symbols[1].getLabelText());
 		assertEquals(TestPlugin.DEP2_SYMBOL2_FILENAME, ((UiModelSymbol)e2_s1_i2_dep2_symbols[1]).getFileName());
@@ -412,7 +416,7 @@ public class TestUiDataModel extends TestCase {
 		assertFalse(e2_s1_i2_dep4_symbols[0].hasChildren());
 		assertEquals(e2_s1_i2_depimages[3], e2_s1_i2_dep4_symbols[0].getParent());
 		assertNotNull(e2_s1_i2_dep4_symbols[0].getLabelImage());
-		
+
 		assertNotNull(e2_s1_i2_dep4_symbols[1].toString());
 		assertNotNull(e2_s1_i2_dep4_symbols[1].getLabelText());
 		assertEquals(TestPlugin.DEP4_SYMBOL_FILENAME, ((UiModelSymbol)e2_s1_i2_dep4_symbols[1]).getFileName());
@@ -453,7 +457,7 @@ public class TestUiDataModel extends TestCase {
 		assertEquals(4, e1_s1_i1_s1_samples.length);
 		assertEquals(3, e1_s1_i1_s2_samples.length);
 		//0 but not null for dep images due to samples with no line #
-		assertEquals(0, e1_s1_d2_s1_samples.length);	
+		assertEquals(0, e1_s1_d2_s1_samples.length);
 		assertEquals(0, e1_s1_d2_s2_samples.length);
 		assertEquals(0, e1_s1_d4_s1_samples.length);
 		assertEquals(0, e1_s1_d4_s2_samples.length);
@@ -472,7 +476,7 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e1_s1_i1_s2_samples[0]);
 		assertNotNull(e1_s1_i1_s2_samples[1]);
 		assertNotNull(e1_s1_i1_s2_samples[2]);
-//
+
 		assertNotNull(e2_s1_i1_s1_samples[0]);
 		assertNotNull(e2_s1_i1_s1_samples[1]);
 		assertNotNull(e2_s1_i1_s1_samples[2]);
@@ -487,11 +491,11 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e2_s2_i1_s2_samples[0]);
 		assertNotNull(e2_s2_i1_s2_samples[1]);
 		assertNotNull(e2_s2_i1_s2_samples[2]);
-//
+
 		assertNotNull(e1_s1_i1_s1_samples[0].toString());
 		assertNotNull(e1_s1_i1_s1_samples[0].getLabelText());
 		assertEquals(42, ((UiModelSample)e1_s1_i1_s1_samples[0]).getLine());
-		assertEquals(0.6341, ((UiModelSample)e1_s1_i1_s1_samples[0]).getCountPercentage(), 0.0001);
+		assertEquals(0.6190, ((UiModelSample)e1_s1_i1_s1_samples[0]).getCountPercentage(), 0.0001);
 		assertNull(e1_s1_i1_s1_samples[0].getChildren());
 		assertFalse(e1_s1_i1_s1_samples[0].hasChildren());
 		assertEquals(e1_s1_i1_symbols[0], e1_s1_i1_s1_samples[0].getParent());
@@ -500,7 +504,7 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e1_s1_i1_s1_samples[1].toString());
 		assertNotNull(e1_s1_i1_s1_samples[1].getLabelText());
 		assertEquals(36, ((UiModelSample)e1_s1_i1_s1_samples[1]).getLine());
-		assertEquals(0.1951, ((UiModelSample)e1_s1_i1_s1_samples[1]).getCountPercentage(), 0.0001);
+		assertEquals(0.1904, ((UiModelSample)e1_s1_i1_s1_samples[1]).getCountPercentage(), 0.0001);
 		assertNull(e1_s1_i1_s1_samples[1].getChildren());
 		assertFalse(e1_s1_i1_s1_samples[1].hasChildren());
 		assertEquals(e1_s1_i1_symbols[0], e1_s1_i1_s1_samples[1].getParent());
@@ -509,7 +513,7 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e1_s1_i1_s1_samples[2].toString());
 		assertNotNull(e1_s1_i1_s1_samples[2].getLabelText());
 		assertEquals(31, ((UiModelSample)e1_s1_i1_s1_samples[2]).getLine());
-		assertEquals(0.0488, ((UiModelSample)e1_s1_i1_s1_samples[2]).getCountPercentage(), 0.0001);
+		assertEquals(0.0476, ((UiModelSample)e1_s1_i1_s1_samples[2]).getCountPercentage(), 0.0001);
 		assertNull(e1_s1_i1_s1_samples[2].getChildren());
 		assertFalse(e1_s1_i1_s1_samples[2].hasChildren());
 		assertEquals(e1_s1_i1_symbols[0], e1_s1_i1_s1_samples[2].getParent());
@@ -527,7 +531,7 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e1_s1_i1_s2_samples[0].toString());
 		assertNotNull(e1_s1_i1_s2_samples[0].getLabelText());
 		assertEquals(94, ((UiModelSample)e1_s1_i1_s2_samples[0]).getLine());
-		assertEquals(0.0976, ((UiModelSample)e1_s1_i1_s2_samples[0]).getCountPercentage(), 0.0001);
+		assertEquals(0.0952, ((UiModelSample)e1_s1_i1_s2_samples[0]).getCountPercentage(), 0.0001);
 		assertNull(e1_s1_i1_s2_samples[0].getChildren());
 		assertFalse(e1_s1_i1_s2_samples[0].hasChildren());
 		assertEquals(e1_s1_i1_symbols[1], e1_s1_i1_s2_samples[0].getParent());
@@ -554,7 +558,7 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e2_s1_i1_s1_samples[0].toString());
 		assertNotNull(e2_s1_i1_s1_samples[0].getLabelText());
 		assertEquals(42, ((UiModelSample)e2_s1_i1_s1_samples[0]).getLine());
-		assertEquals(0.6341, ((UiModelSample)e2_s1_i1_s1_samples[0]).getCountPercentage(), 0.0001);
+		assertEquals(0.6190, ((UiModelSample)e2_s1_i1_s1_samples[0]).getCountPercentage(), 0.0001);
 		assertNull(e2_s1_i1_s1_samples[0].getChildren());
 		assertFalse(e2_s1_i1_s1_samples[0].hasChildren());
 		assertEquals(e2_s1_i1_symbols[0], e2_s1_i1_s1_samples[0].getParent());
@@ -563,7 +567,7 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e2_s1_i1_s1_samples[1].toString());
 		assertNotNull(e2_s1_i1_s1_samples[1].getLabelText());
 		assertEquals(36, ((UiModelSample)e2_s1_i1_s1_samples[1]).getLine());
-		assertEquals(0.1951, ((UiModelSample)e2_s1_i1_s1_samples[1]).getCountPercentage(), 0.0001);
+		assertEquals(0.1904, ((UiModelSample)e2_s1_i1_s1_samples[1]).getCountPercentage(), 0.0001);
 		assertNull(e2_s1_i1_s1_samples[1].getChildren());
 		assertFalse(e2_s1_i1_s1_samples[1].hasChildren());
 		assertEquals(e2_s1_i1_symbols[0], e2_s1_i1_s1_samples[1].getParent());
@@ -572,7 +576,7 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e2_s1_i1_s1_samples[2].toString());
 		assertNotNull(e2_s1_i1_s1_samples[2].getLabelText());
 		assertEquals(31, ((UiModelSample)e2_s1_i1_s1_samples[2]).getLine());
-		assertEquals(0.0488, ((UiModelSample)e2_s1_i1_s1_samples[2]).getCountPercentage(), 0.0001);
+		assertEquals(0.0476, ((UiModelSample)e2_s1_i1_s1_samples[2]).getCountPercentage(), 0.0001);
 		assertNull(e2_s1_i1_s1_samples[2].getChildren());
 		assertFalse(e2_s1_i1_s1_samples[2].hasChildren());
 		assertEquals(e2_s1_i1_symbols[0], e2_s1_i1_s1_samples[2].getParent());
@@ -590,7 +594,7 @@ public class TestUiDataModel extends TestCase {
 		assertNotNull(e2_s1_i1_s2_samples[0].toString());
 		assertNotNull(e2_s1_i1_s2_samples[0].getLabelText());
 		assertEquals(94, ((UiModelSample)e2_s1_i1_s2_samples[0]).getLine());
-		assertEquals(0.0976, ((UiModelSample)e2_s1_i1_s2_samples[0]).getCountPercentage(), 0.0001);
+		assertEquals(0.0952, ((UiModelSample)e2_s1_i1_s2_samples[0]).getCountPercentage(), 0.0001);
 		assertNull(e2_s1_i1_s2_samples[0].getChildren());
 		assertFalse(e2_s1_i1_s2_samples[0].hasChildren());
 		assertEquals(e2_s1_i1_symbols[1], e2_s1_i1_s2_samples[0].getParent());
