@@ -14,22 +14,20 @@ import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
 import java.io.PrintStream;
-import java.net.URI;
-import java.net.URISyntaxException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 
-import org.eclipse.cdt.core.parser.util.ArrayUtil;
 import org.eclipse.cdt.debug.core.ICDTLaunchConfigurationConstants;
-import org.eclipse.core.filesystem.IFileStore;
 import org.eclipse.core.resources.IProject;
-import org.eclipse.core.resources.IWorkspaceRoot;
 import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Path;
+import org.eclipse.core.runtime.Status;
 import org.eclipse.debug.core.ILaunchConfiguration;
 import org.eclipse.linuxtools.internal.perf.model.PMCommand;
 import org.eclipse.linuxtools.internal.perf.model.PMDso;
@@ -37,40 +35,37 @@ import org.eclipse.linuxtools.internal.perf.model.PMEvent;
 import org.eclipse.linuxtools.internal.perf.model.PMFile;
 import org.eclipse.linuxtools.internal.perf.model.PMSymbol;
 import org.eclipse.linuxtools.internal.perf.model.TreeParent;
+import org.eclipse.linuxtools.internal.perf.ui.PerfProfileView;
 import org.eclipse.linuxtools.profiling.launch.ConfigUtils;
-import org.eclipse.linuxtools.profiling.launch.IRemoteFileProxy;
-import org.eclipse.linuxtools.profiling.launch.RemoteProxyManager;
 import org.eclipse.linuxtools.tools.launch.core.factory.RuntimeProcessFactory;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.ui.PartInitException;
 import org.eclipse.ui.PlatformUI;
+import org.osgi.framework.Version;
 
 public class PerfCore {
+
 	public static String spitStream(BufferedReader br, String blockTitle, PrintStream print) {
 
 		StringBuffer strBuf = new StringBuffer();
 		String line = null;
 		try {
 			while (( line = br.readLine()) != null){
-				strBuf.append(line + "\n");
+				strBuf.append(line);
+				strBuf.append("\n"); //$NON-NLS-1$
 			}
 		} catch (IOException e) {
-			e.printStackTrace();
+			logException(e);
 		}
 		String str = strBuf.toString();
-		if (!str.trim().equals("")) {
-			if (print != null) {
-				print.println(blockTitle + ": \n" +str + "\n END OF " + blockTitle);
-			}
+		if (!str.trim().isEmpty() && print != null) {
+			print.println(blockTitle + ": \n" +str + "\n END OF " + blockTitle); //$NON-NLS-1$ //$NON-NLS-2$
 		}
 		return str;
 	}
 	// Maps event lists to host names for caching
 	private static HashMap<String,HashMap<String, ArrayList<String>>> eventsHostMap = null;
 	private static HashMap<String,ArrayList<String>> eventList = null;
-	public static HashMap<String,ArrayList<String>> getEventList() { 
-		return getEventList(null);
-	}
 
 	/**
 	 * Gets the list of events for a given launch configuration. Uses a cache for each host
@@ -86,7 +81,7 @@ public class PerfCore {
 
 		// local projects have null hosts
 		if(projectHost == null){
-			projectHost = "local";
+			projectHost = "local"; //$NON-NLS-1$
 		}
 
 		eventList = eventsHostMap.get(projectHost);
@@ -107,11 +102,11 @@ public class PerfCore {
 	private static String getHostName(ILaunchConfiguration config){
 		String projectName = null;
 		try {
-			projectName = config.getAttribute(ICDTLaunchConfigurationConstants.ATTR_PROJECT_NAME, "");
+			projectName = config.getAttribute(ICDTLaunchConfigurationConstants.ATTR_PROJECT_NAME, ""); //$NON-NLS-1$
 		} catch (CoreException e) {
 			return null;
 		}
-		if (projectName.equals("")) {
+		if (projectName.isEmpty()) {
 			return null;
 		}
 		IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(projectName);
@@ -122,34 +117,39 @@ public class PerfCore {
 
 	}
 
-	public static HashMap<String,ArrayList<String>> loadEventList(ILaunchConfiguration config) {
-		HashMap<String,ArrayList<String>> events = new HashMap<String,ArrayList<String>>();
-		IProject project = null;
-		if (config==null) {
-			if (!PerfCore.checkPerfInPath()) {
-				return events;
-			}
+	private static IProject getProject(ILaunchConfiguration config){
+		if(config == null){
+			return null;
 		} else {
 			ConfigUtils configUtils = new ConfigUtils(config);
 			try {
 				String projectName = configUtils.getProjectName();
 				// an empty string is not a legal path to file argument for ConfigUtils.getProject
-				if(projectName != null && !projectName.equals("")){
-					project = ConfigUtils.getProject(projectName);
+				if (projectName != null && !projectName.isEmpty()) {
+					return ConfigUtils.getProject(projectName);
 				}
-
 			} catch (CoreException e1) {
-				e1.printStackTrace();
-			}
-			if (!PerfCore.checkRemotePerfInPath(project)) {
-				return events;
+				logException(e1);
 			}
 		}
+
+		return null;
+	}
+
+	private static HashMap<String,ArrayList<String>> loadEventList(ILaunchConfiguration config){
+		HashMap<String,ArrayList<String>> events = new HashMap<String,ArrayList<String>>();
+		IProject project = getProject(config);
+
+		if (!PerfCore.checkPerfInPath(project)) {
+			return events;
+		}
+
 		Process p = null;
 		BufferedReader input = null;
 		try {
-			// Alternatively can try with -i flag
-			p = RuntimeProcessFactory.getFactory().exec(new String[] {PerfPlugin.PERF_COMMAND, "list"}, project); //(char 1 as -t is a custom field seperator
+			// Execute "perf list" to get list of all symbolic event types.
+			// Alternatively can try with -i flag.
+			p = RuntimeProcessFactory.getFactory().exec(new String[] {PerfPlugin.PERF_COMMAND, "list"}, project); //(char 1 as -t is a custom field seperator //$NON-NLS-1$
 
 			/*
 			 * Old versions of Perf will send events list to stderr instead of stdout
@@ -158,38 +158,43 @@ public class PerfCore {
 			input = new BufferedReader(new InputStreamReader(p.getInputStream()));
 
 		} catch( IOException e ) {
-			e.printStackTrace();
-		} 
+			logException(e);
+		}
+		return parseEventList(input);
+	}
+
+	public static HashMap<String,ArrayList<String>> parseEventList (BufferedReader input){
+		HashMap<String,ArrayList<String>> events = new HashMap<String,ArrayList<String>>();
 		String line;
 		try {
+			// Process list of events. Each line is of the form <event>\s+<category>.
 			while (( line = input.readLine()) != null){
-				if (line.contains("[")) {
+				if (line.contains("[")) { //$NON-NLS-1$
 					String event;
-					String cat;
+					String category;
 					if (line.contains(PerfPlugin.STRINGS_HWBREAKPOINTS)) {
-						cat = PerfPlugin.STRINGS_HWBREAKPOINTS;
-						event = line.substring(1,line.indexOf("[", 0)).trim();
+						category = PerfPlugin.STRINGS_HWBREAKPOINTS;
+						event = line.substring(1,line.indexOf('[', 0)).trim();
 					} else if (line.contains(PerfPlugin.STRINGS_RAWHWEvents)) {
-						cat = PerfPlugin.STRINGS_RAWHWEvents;
-						event = line.substring(1,line.indexOf("[", 0)).trim();
+						category = PerfPlugin.STRINGS_RAWHWEvents;
+						event = line.substring(1,line.indexOf('[', 0)).trim();
 					} else {
-						event = line.substring(1,line.indexOf("[", 0)).trim();
-						if (event.contains("OR")) {
-							event = event.split("OR")[0]; //filter out the abbreviations.
+						event = line.substring(1,line.indexOf('[', 0)).trim();
+						if (event.contains("OR")) { //$NON-NLS-1$
+							event = event.split("OR")[0]; //filter out the abbreviations. //$NON-NLS-1$
 						}
-						cat = line.replaceFirst(".*\\[(.+)\\]", "$1").trim();
+						category = line.replaceFirst(".*\\[(.+)\\]", "$1").trim(); //$NON-NLS-1$ //$NON-NLS-2$
 					}
-					ArrayList<String> catevs = events.get(cat);
-					if (catevs == null) {
-						catevs = new ArrayList<String>();
-						events.put(cat, catevs);
+					ArrayList<String> categoryEvents = events.get(category);
+					if (categoryEvents == null) {
+						categoryEvents = new ArrayList<String>();
+						events.put(category, categoryEvents);
 					}
-					catevs.add(event.trim());
+					categoryEvents.add(event.trim());
 				}
 			}
 		} catch (IOException e) {
-			// TODO Auto-generated catch block
-			e.printStackTrace();
+			logException(e);
 		} finally {
 			if (null != input) {
 				try {
@@ -201,122 +206,94 @@ public class PerfCore {
 		return events;
 	}
 
-
 	//Gets the current version of perf
-	public static String getPerfVersion(ILaunchConfiguration config, String[] environ, IPath workingDir) {
-		ConfigUtils configUtils = new ConfigUtils(config);
-		IProject project = null;
-		try {
-			project = ConfigUtils.getProject(configUtils.getProjectName());
-		} catch (CoreException e1) {
-			e1.printStackTrace();
-		}
+	public static Version getPerfVersion(ILaunchConfiguration config) {
+		IProject project = getProject(config);
 		Process p = null;
-		IRemoteFileProxy proxy = null;
-		IFileStore workingDirFileStore = null;
 
-		if (workingDir == null) {
-			try {
-				p = RuntimeProcessFactory.getFactory().exec(new String [] {PerfPlugin.PERF_COMMAND, "--version"}, project);
-			} catch (IOException e) {
-				e.printStackTrace();
-			}
-		} else {
-			try {
-				proxy = RemoteProxyManager.getInstance().getFileProxy(new URI(workingDir.toOSString()));
-				workingDirFileStore = proxy.getResource(workingDir.toOSString());
-				p = RuntimeProcessFactory.getFactory().exec(new String [] {PerfPlugin.PERF_COMMAND, "--version"}, environ, workingDirFileStore, project);
-			} catch (IOException e) {
-				e.printStackTrace();
-			} catch (CoreException e) {
-				e.printStackTrace();
-			} catch (URISyntaxException e) {
-				e.printStackTrace();
-			}
-		}			
+		try {
+			p = RuntimeProcessFactory.getFactory().exec(new String [] {PerfPlugin.PERF_COMMAND, "--version"}, project); //$NON-NLS-1$
+		} catch (IOException e) {
+			logException(e);
+		}
+		if (p == null) {
+			return null;
+		}
 
-		//p.waitFor();
 		BufferedReader input = new BufferedReader(new InputStreamReader(p.getInputStream()));
-		return spitStream(input, "Perf --version", null);
+
+		String perfVersion = spitStream(input, "Perf --version", null); //$NON-NLS-1$
+		int index = perfVersion.indexOf('-');
+		if (index > 0) {
+			perfVersion = perfVersion.substring(0, index);
+		}
+		perfVersion = perfVersion.replace("perf version", "").trim(); //$NON-NLS-1$ //$NON-NLS-2$
+		return new Version(perfVersion);
 	}
 
-	public static boolean checkPerfInPath()
+
+	public static boolean checkPerfInPath(IProject project)
 	{
-		try 
+		try
 		{
-			Runtime.getRuntime().exec(new String [] {PerfPlugin.PERF_COMMAND, "--version"});			
-		} 
-		catch (IOException e) 
+			Process p = RuntimeProcessFactory.getFactory().exec(new String [] {PerfPlugin.PERF_COMMAND, "--version"}, project); //$NON-NLS-1$
+			return (p != null);
+		}
+		catch (IOException e)
 		{
 			return false;
 		}
-		return true;
-	}
-
-	public static boolean checkRemotePerfInPath(IProject project) {
-		try 
-		{
-			RuntimeProcessFactory.getFactory().exec(new String [] {PerfPlugin.PERF_COMMAND, "--version"}, project);			
-		} 
-		catch (IOException e) 
-		{
-			e.printStackTrace();
-			return false;
-		}
-		return true;
-	}
-
-	public String getRemoteProjectPath(String projectName) {
-		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
-		IProject project = root.getProject(projectName);
-		return project.getName();
 	}
 
 	//Generates a perf record command string with the options set in the given config. (If null uses default).
-	public static String [] getRecordString(ILaunchConfiguration config) {
-		String [] base = new String [] {PerfPlugin.PERF_COMMAND, "record", "-f"};
+	public static String [] getRecordString(ILaunchConfiguration config, Version perfVersion) {
+		String [] base = new String [] {PerfPlugin.PERF_COMMAND, "record"}; //$NON-NLS-1$
 		if (config == null) {
 			return base;
 		} else {
 			ArrayList<String> newCommand = new ArrayList<String>();
 			newCommand.addAll(Arrays.asList(base));
 			try {
+				if (new Version(3, 11, 0).compareTo(perfVersion) > 0) {
+					// Removed as of 4a4d371a4dfbd3b84a7eab8d535d4c7c3647b09e from perf upstream (kernel)
+					newCommand.add("-f"); //$NON-NLS-1$
+				}
 				if (config.getAttribute(PerfPlugin.ATTR_Record_Realtime, PerfPlugin.ATTR_Record_Realtime_default))
-					newCommand.add("-r");
+					newCommand.add("-r"); //$NON-NLS-1$
 				if (config.getAttribute(PerfPlugin.ATTR_Record_Verbose, PerfPlugin.ATTR_Record_Verbose_default))
-					newCommand.add("-v");
+					newCommand.add("-v"); //$NON-NLS-1$
 				if (config.getAttribute(PerfPlugin.ATTR_Multiplex, PerfPlugin.ATTR_Multiplex_default))
-					newCommand.add("-M");
+					newCommand.add("-M"); //$NON-NLS-1$
 				List<?> selE = config.getAttribute(PerfPlugin.ATTR_SelectedEvents, PerfPlugin.ATTR_SelectedEvents_default);
-				if (!config.getAttribute(PerfPlugin.ATTR_DefaultEvent, PerfPlugin.ATTR_DefaultEvent_default) 
-						&& selE != null) {					
+				if (!config.getAttribute(PerfPlugin.ATTR_DefaultEvent, PerfPlugin.ATTR_DefaultEvent_default)
+						&& selE != null) {
 					for(Object e : selE) {
-						newCommand.add("-e");
+						newCommand.add("-e"); //$NON-NLS-1$
 						newCommand.add((String)e);
 					}
 				}
-			} catch (CoreException e) { }			
+			} catch (CoreException e) { }
 			return newCommand.toArray(new String[] {});
 		}
 	}
 
 	public static String[] getReportString(ILaunchConfiguration config, String perfDataLoc) {
 		ArrayList<String> base = new ArrayList<String>();
-		base.addAll(Arrays.asList(new String [] {PerfPlugin.PERF_COMMAND, "report", "--sort", "comm,dso,sym", "-n", "-t", "" + (char)1 }));//(char 1 as -t is a custom field seperator)
+		base.addAll(Arrays.asList(new String [] {PerfPlugin.PERF_COMMAND, "report", "--sort", "comm,dso,sym", "-n", "-t", "" + (char)1 }));//(char 1 as -t is a custom field seperator) //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$ //$NON-NLS-6$
 		if (config != null) {
 			try {
 				String kernelLoc = config.getAttribute(PerfPlugin.ATTR_Kernel_Location, PerfPlugin.ATTR_Kernel_Location_default);
 				if (kernelLoc != PerfPlugin.ATTR_Kernel_Location_default) {
-					base.add("--vmlinux");
+					base.add("--vmlinux"); //$NON-NLS-1$
 					base.add(kernelLoc);
 				}
 				if (config.getAttribute(PerfPlugin.ATTR_ModuleSymbols, PerfPlugin.ATTR_ModuleSymbols_default))
-					base.add("-m");
+					base.add("-m"); //$NON-NLS-1$
 
 				/*
 				 * danielhb, 12/14/2011 - some systems, like ubuntu and sles, does not have
 				 * the -U option. The binary fails to execute in those systems when this
-				 * option is enabled. 
+				 * option is enabled.
 				 * I'm disabling it to make the plug-in runnable for them. This
 				 * will probably need to be revisited in the future, probably when this
 				 * flag is implemented by the Perf binary of those systems.
@@ -326,10 +303,10 @@ public class PerfCore {
 					base.add("-U");
 				 */
 				if (perfDataLoc != null) {
-					base.add("-i");
+					base.add("-i"); //$NON-NLS-1$
 					base.add(perfDataLoc);
 				}
-			} catch (CoreException e) { }			
+			} catch (CoreException e) { }
 		}
 		return base.toArray( new String[base.size()] );
 	}
@@ -337,80 +314,41 @@ public class PerfCore {
 	public static String[] getAnnotateString(ILaunchConfiguration config, String dso, String symbol, String perfDataLoc, boolean OldPerfVersion) {
 		ArrayList<String> base = new ArrayList<String>();
 		if (OldPerfVersion) {
-			base.addAll( Arrays.asList( new String[]{PerfPlugin.PERF_COMMAND, "annotate", "-s", symbol, "-l", "-P"} ) );
+			base.addAll( Arrays.asList( new String[]{PerfPlugin.PERF_COMMAND, "annotate", "-s", symbol, "-l", "-P"} ) ); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
 		} else {
-			base.addAll( Arrays.asList( new String[]{PerfPlugin.PERF_COMMAND, "annotate", "-d", dso, "-s", symbol, "-l", "-P"} ) );
+			base.addAll( Arrays.asList( new String[]{PerfPlugin.PERF_COMMAND, "annotate", "-d", dso, "-s", symbol, "-l", "-P"} ) ); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$
 		}
 		if (config != null) {
 			try {
 				String kernelLoc = config.getAttribute(PerfPlugin.ATTR_Kernel_Location, PerfPlugin.ATTR_Kernel_Location_default);
 				if (kernelLoc != PerfPlugin.ATTR_Kernel_Location_default) {
-					base.add("--vmlinux");
+					base.add("--vmlinux"); //$NON-NLS-1$
 					base.add(kernelLoc);
 				}
 				if (config.getAttribute(PerfPlugin.ATTR_ModuleSymbols, PerfPlugin.ATTR_ModuleSymbols_default))
-					base.add("-m");
+					base.add("-m"); //$NON-NLS-1$
 				if (perfDataLoc != null) {
-					base.add("-i");
+					base.add("-i"); //$NON-NLS-1$
 					base.add(perfDataLoc);
 				}
-			} catch (CoreException e) { }			
+			} catch (CoreException e) { }
 		}
 
 		//(Annotate string per symbol)
 		return base.toArray( new String[base.size()] );
 	}
-	//Runs Perf Record on the given binary and records into perf.data before calling Report() to feed in the results. 
-	public static void Record(ILaunchConfiguration config, String binaryPath) {
-		ConfigUtils configUtils = new ConfigUtils(config);
-		IProject project = null;
-		try {
-			project = ConfigUtils.getProject(configUtils.getProjectName());
-		} catch (CoreException e1) {
-			e1.printStackTrace();
-		}
-		BufferedReader error = null;
-		Process perfRecord = null;
-		try {
-			if (project==null) {
-				perfRecord = Runtime.getRuntime().exec(ArrayUtil.addAll(getRecordString(null), new String [] {binaryPath}));
-			} else {
-				perfRecord = RuntimeProcessFactory.getFactory().exec(ArrayUtil.addAll(getRecordString(null), new String [] {binaryPath}), project);
-			}
-			error = new BufferedReader(new InputStreamReader(perfRecord.getErrorStream()));
-			perfRecord.waitFor();			
-			spitStream(error,"Perf Record", null);
-		} catch( IOException e ) {
-			e.printStackTrace();
-		} catch (InterruptedException e) {
-			e.printStackTrace();
-		}
-		//Report();
-	}
-	public static void Report() {
-		Report(null,null,null,null,null,null);
-	}
+
 	// Runs assuming perf.data has already been recorded, environ and workingDir can be set to null to use default
 	//perfDataLoc is optional - it is used to provide a pre-existing data file instead of something recorded from
 	//whatever project is being profiled. It is only used for junit tests atm.
 	public static void Report(ILaunchConfiguration config, String[] environ, IPath workingDir, IProgressMonitor monitor, String perfDataLoc, PrintStream print) {
-		ConfigUtils configUtils = new ConfigUtils(config);
-		IProject project = null;
-		try {
-			project = ConfigUtils.getProject(configUtils.getProjectName());
-		} catch (CoreException e1) {
-			e1.printStackTrace();
-		}
-		TreeParent invisibleRoot = PerfPlugin.getDefault().getModelRoot();  
-		if (invisibleRoot == null) {
-			invisibleRoot = new TreeParent("");
-			PerfPlugin.getDefault().setModelRoot(invisibleRoot);
-		} else {
-			invisibleRoot.clear();
-		}
+		IProject project = getProject(config);
 
+		TreeParent invisibleRoot = PerfPlugin.getDefault().clearModelRoot();
+
+		Version perfVersion = getPerfVersion(config);
 		boolean OldPerfVersion = false;
-		if (getPerfVersion(config, environ, workingDir).contains("perf version 0.0.2.PERF")) {
+		if (new Version(0, 0, 2).compareTo(perfVersion) > 0) {
 			OldPerfVersion = true;
 			if (print != null) { print.println("WARNING: You are running an older version of Perf, please update if you can. The plugin may produce unpredictable results."); }
 		}
@@ -420,30 +358,31 @@ public class PerfCore {
 		BufferedReader error = null;
 		Process p = null;
 
-		if (monitor != null && monitor.isCanceled()) { RefreshView(); return; }
+		if (monitor != null && monitor.isCanceled()) {
+			return;
+		}
 
 		try {
 			if (workingDir==null) {
 				p = RuntimeProcessFactory.getFactory().exec(getReportString(config, perfDataLoc), project);
+				PerfPlugin.getDefault().setPerfProfileData(new Path(perfDataLoc));
+				PerfPlugin.getDefault().setWorkingDir(project.getLocation());
 			} else {
-				p = RuntimeProcessFactory.getFactory().exec(getReportString(config, workingDir.toOSString() + PerfPlugin.PERF_DEFAULT_DATA), project);
+				String defaultPerfDataLoc = workingDir.toOSString() + PerfPlugin.PERF_DEFAULT_DATA;
+				p = RuntimeProcessFactory.getFactory().exec(getReportString(config, defaultPerfDataLoc), project);
+				PerfPlugin.getDefault().setPerfProfileData(new Path(defaultPerfDataLoc));
+				PerfPlugin.getDefault().setWorkingDir(workingDir);
 			}
 
-			//			p.waitFor();
 			input = new BufferedReader(new InputStreamReader(p.getInputStream()));
 			error = new BufferedReader(new InputStreamReader(p.getErrorStream()));
 			//spitting error stream moved to end of while loop, due to commenting of p.waitFor()
 		} catch( IOException e ) {
-			e.printStackTrace();
-			/*} catch (InterruptedException e) {
-			e.printStackTrace();*/
-		} 
-
+			logException(e);
+		}
 
 		PerfCore.parseRemoteReport(config, workingDir, monitor, perfDataLoc, print,
 				invisibleRoot, OldPerfVersion, input, error, project);
-
-		RefreshView();
 	}
 
 	/**
@@ -470,7 +409,10 @@ public class PerfCore {
 			IPath workingDir, IProgressMonitor monitor, String perfDataLoc,
 			PrintStream print, TreeParent invisibleRoot,
 			boolean OldPerfVersion, BufferedReader input, BufferedReader error, IProject project) {
-		if (monitor != null && monitor.isCanceled()) { RefreshView(); return; }
+
+		if (monitor != null && monitor.isCanceled()) {
+			return;
+		}
 		String line = null;
 		String items[];
 		float percent;
@@ -486,27 +428,29 @@ public class PerfCore {
 		PMSymbol currentSym = null;
 		try {
 			while (( line = input.readLine()) != null){
-				if (monitor != null && monitor.isCanceled()) { RefreshView(); return; }
+				if (monitor != null && monitor.isCanceled()) {
+					return;
+				}
 				// line containing report information
-				if ((line.startsWith("#"))) {
-					if (line.contains("Events:") || line.contains("Samples:")) {
-						String[] tmp = line.trim().split(" ");
+				if ((line.startsWith("#"))) { //$NON-NLS-1$
+					if (line.contains("Events:") || line.contains("Samples:")) { //$NON-NLS-1$ //$NON-NLS-2$
+						String[] tmp = line.trim().split(" "); //$NON-NLS-1$
 						String event = tmp[tmp.length - 1];
 						// In this case, the event name is single quoted
-						if (line.contains("Samples:")){
+						if (line.contains("Samples:")){ //$NON-NLS-1$
 							event = event.substring(1, event.length() -1);
 						}
 						currentEvent = new PMEvent(event);
 						invisibleRoot.addChild(currentEvent);
 						currentCommand = null;
 						currentDso = null;
-					} else if (line.contains("Samples:")) { //"samples" was used instead of events in an older version, some incompatibilities may arise.
+					} else if (line.contains("Samples:")) { //"samples" was used instead of events in an older version, some incompatibilities may arise. //$NON-NLS-1$
 						if (print != null) { print.println("WARNING: You are running an older version of Perf, please update if you can. The plugin may produce unpredictable results."); }
 						invisibleRoot.addChild(new PMEvent("WARNING: You are running an older version of Perf, the plugin may produce unpredictable results."));
 					}
 					// contains profiled information
 				} else {
-					items = line.trim().split(""+(char)1); // using custom field separator. for default whitespace use " +"
+					items = line.trim().split(""+(char)1); // using custom field separator. for default whitespace use " +" //$NON-NLS-1$
 					if (items.length != 5) {
 						continue;
 					}
@@ -514,8 +458,8 @@ public class PerfCore {
 					samples = Double.parseDouble(items[1].trim()); //samples column
 					comm = items[2].trim(); //command column
 					dso = items[3].trim(); //dso column
-					symbol = items[4].trim(); //symbol column 
-					kernelFlag = (""+symbol.charAt(1)).equals("k");			
+					symbol = items[4].trim(); //symbol column
+					kernelFlag = (""+symbol.charAt(1)).equals("k"); //$NON-NLS-1$ //$NON-NLS-2$
 
 					// initialize current command if it doesn't exist
 					if ((currentCommand == null) || (!currentCommand.getName().equals(comm))) {
@@ -543,12 +487,12 @@ public class PerfCore {
 					 *  attach all symbols as children of 'Unfiled Symbols'.
 					 */
 					currentFile = currentDso.getFile(PerfPlugin.STRINGS_UnfiledSymbols);
-					currentSym = new PMSymbol(symbol, samples, percent);
+					currentSym = new PMSymbol(symbol, percent, samples);
 					currentFile.addChild(currentSym);
 				}
 			}
 		} catch (IOException e) {
-			e.printStackTrace();
+			logException(e);
 		}
 		spitStream(error,"Perf Report", print);
 
@@ -562,7 +506,9 @@ public class PerfCore {
 			SourceLineNumbers = false;
 		}
 
-		if (monitor != null && monitor.isCanceled()) { RefreshView(); return; }
+		if (monitor != null && monitor.isCanceled()) {
+			return;
+		}
 
 		boolean hasProfileData = invisibleRoot.getChildren().length != 0;
 
@@ -572,15 +518,15 @@ public class PerfCore {
 				for (TreeParent cmd : ev.getChildren()) {
 					if (!(cmd instanceof PMCommand)) continue;
 					for (TreeParent d : cmd.getChildren()) {
-						if (!(d instanceof PMDso)) continue;					
+						if (!(d instanceof PMDso)) continue;
 						currentDso = (PMDso)d;
 						if ((!Kernel_SourceLineNumbers) && currentDso.isKernelDso()) continue;
 						for (TreeParent s : currentDso.getFile(PerfPlugin.STRINGS_UnfiledSymbols).getChildren()) {
 							if (!(s instanceof PMSymbol)) continue;
 
-							if (monitor != null && monitor.isCanceled()) { RefreshView(); return; }
-
-
+							if (monitor != null && monitor.isCanceled()) {
+								return;
+							}
 							currentSym = (PMSymbol)s;
 							String[] annotateCmd;
 							if (workingDir == null) {
@@ -596,11 +542,10 @@ public class PerfCore {
 								input = new BufferedReader(new InputStreamReader(p.getInputStream()));
 								error = new BufferedReader(new InputStreamReader(p.getErrorStream()));
 							} catch (IOException e) {
-								e.printStackTrace();
+								logException(e);
 							}
 
-							PerfCore.parseAnnotation(monitor, input,
-									workingDir, currentDso, currentSym);
+							PerfCore.parseAnnotation(monitor, input, workingDir, currentDso, currentSym);
 						}
 
 						if (currentDso.getFile(PerfPlugin.STRINGS_UnfiledSymbols).getChildren().length == 0) {
@@ -632,7 +577,10 @@ public class PerfCore {
 	public static void parseAnnotation(IProgressMonitor monitor,
 			BufferedReader input, IPath workingDir, PMDso currentDso,
 			PMSymbol currentSym) {
-		if (monitor != null && monitor.isCanceled()) { RefreshView(); return; }
+
+		if (monitor != null && monitor.isCanceled()) {
+			return;
+		}
 
 		boolean grabBlock = false;
 		boolean blockStarted = false;
@@ -643,19 +591,19 @@ public class PerfCore {
 
 		try {
 			while (( line = input.readLine()) != null){
-				if (line.startsWith("Sorted summary for file")) {
+				if (line.startsWith("Sorted summary for file")) { //$NON-NLS-1$
 					grabBlock = true;
-					dsoName = line.replace("Sorted summary for file ","");
+					dsoName = line.replace("Sorted summary for file ",""); //$NON-NLS-1$ //$NON-NLS-2$
 					blockStarted = false;
-					if ((workingDir != null) && (dsoName.startsWith("./"))) {
-						if (workingDir.toOSString().endsWith("/")) {
+					if ((workingDir != null) && (dsoName.startsWith("./"))) { //$NON-NLS-1$
+						if (workingDir.toOSString().endsWith("/")) { //$NON-NLS-1$
 							dsoName = workingDir.toOSString() + dsoName.substring(2); // path already ends with '/', so trim './'
 						} else {
 							dsoName = workingDir.toOSString() + dsoName.substring(1); // path doesn't have '/', so trim just the '.'
 						}
 					}
 					currentDso.setPath(dsoName);
-				} else if (line.startsWith("---")) {
+				} else if (line.startsWith("---")) { //$NON-NLS-1$
 					if (blockStarted) {
 						blockStarted = false;
 						grabBlock = false;
@@ -664,18 +612,24 @@ public class PerfCore {
 					}
 				} else if (grabBlock && blockStarted) {
 					//process the line.
-					items = line.trim().split(" +");
+					items = line.trim().split(" +"); //$NON-NLS-1$
 					if (items.length != 2) {
 						continue;
 					}
 					percent = Float.parseFloat(items[0]);
 					lineRef = items[1];
-					items = lineRef.split(":");
+					items = lineRef.split(":"); //$NON-NLS-1$
 					if (currentDso == null) {
 						//if (PerfPlugin.DEBUG_ON) System.err.println("Parsed line ref without being in valid block, shouldn't happen.");
 						break;
 					} else {
-						currentSym.addPercent(Integer.parseInt(items[1]), percent);
+						int lineNum = -1;
+						try {
+							lineNum = Integer.parseInt(items[1]);
+						} catch (NumberFormatException e) {
+							// leave line number as -1
+						}
+						currentSym.addPercent(lineNum, percent);
 						// Symbol currently in 'Unfiled Symbols' but we now know the actual parent
 						if (currentSym.getParent().getName().equals(PerfPlugin.STRINGS_UnfiledSymbols)) {
 							currentSym.getParent().removeChild(currentSym);
@@ -690,25 +644,35 @@ public class PerfCore {
 				}
 			}
 		} catch (IOException e) {
-			e.printStackTrace();
+			logException(e);
 		}
 	}
 
-	public static void RefreshView()
-	{
+	public static void RefreshView (final String title) {
 		Display.getDefault().syncExec(new Runnable() {
+
 			@Override
 			public void run() {
-				//Try to switch the active view to Perf.
 				try {
-					PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().showView(PerfPlugin.VIEW_ID);
-					PerfPlugin.getDefault().getProfileView().refreshModel();
-				} catch (NullPointerException e) {
-					e.printStackTrace();					
+					PerfProfileView view = (PerfProfileView) PlatformUI
+							.getWorkbench().getActiveWorkbenchWindow()
+							.getActivePage().showView(PerfPlugin.VIEW_ID);
+					view.setContentDescription(title);
+					view.refreshModel();
 				} catch (PartInitException e) {
-					e.printStackTrace();
+					logException(e);
 				}
 			}
 		});
 	}
+
+	/**
+	 * Log specified exception.
+	 * @param e Exception to log.
+	 */
+	public static void logException(Exception e) {
+		Status status = new Status(IStatus.ERROR, PerfPlugin.PLUGIN_ID,
+				e.getMessage());
+		PerfPlugin.getDefault().getLog().log(status);
+	}
 }
\ No newline at end of file
