@@ -10,7 +10,6 @@
  *******************************************************************************/
 package org.eclipse.linuxtools.profiling.provider.tests.stubby;
 
-import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.debug.core.ILaunch;
 import org.eclipse.debug.core.ILaunchConfiguration;
@@ -19,14 +18,9 @@ import org.eclipse.linuxtools.profiling.launch.ProfileLaunchConfigurationDelegat
 public class StubbyLaunchConfigurationDelegate extends
 		ProfileLaunchConfigurationDelegate {
 
-	@Override
-	public String generateCommand(ILaunchConfiguration config) {
-		return null;
-	}
-
 	@Override
 	public void launch(ILaunchConfiguration configuration, String mode,
-			ILaunch launch, IProgressMonitor monitor) throws CoreException {
+			ILaunch launch, IProgressMonitor monitor) {
 	}
 
 	@Override
