@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007 Alphonse Van Assche.
+ * Copyright (c) 2007 Alphonse Van Assche and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *    Alphonse Van Assche - initial API and implementation
+ *    Red Hat Inc. - ongoing maintenance
  *******************************************************************************/
 package org.eclipse.linuxtools.internal.rpmstubby;
 
@@ -29,6 +30,7 @@ public class FeatureVisitor implements IResourceVisitor {
 	/**
 	 * @see org.eclipse.core.resources.IResourceVisitor#visit(org.eclipse.core.resources.IResource)
 	 */
+	@Override
 	public boolean visit(IResource resource) {
 		if (resource instanceof IFile
 				&& resource.getName().equals(FEATURE_XML)) {
@@ -36,7 +38,7 @@ public class FeatureVisitor implements IResourceVisitor {
 		}
 		return true;
 	}
-	
+
 	/**
 	 * @return All the feature.xml files found.
 	 */
