@@ -4,41 +4,33 @@
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
- * 
+ *
  * Contributors:
  *     Red Hat - initial API and implementation
  *******************************************************************************/
 
 package org.eclipse.linuxtools.callgraph.tests;
 
-import junit.framework.TestCase;
+import static org.junit.Assert.assertEquals;
 
 import org.eclipse.linuxtools.internal.callgraph.core.SystemTapTextView;
 import org.eclipse.linuxtools.internal.callgraph.core.ViewFactory;
+import org.junit.Test;
 
-public class SystemTapGraphViewTest extends TestCase {
+public class SystemTapGraphViewTest {
 	private SystemTapTextView stapView = new SystemTapTextView();
 	private String testText = "blah";
-	
-	//TODO: write some better tests here
-	public void test() {
-		System.out.println("\n\nLaunching RunSystemTapActionTest\n");
 
-		
+	//TODO: write some better tests here
+	@Test
+	public void test() {
 		stapView = (SystemTapTextView)  ViewFactory.createView("org.eclipse.linuxtools.callgraph.core.staptextview");
-		if (stapView == null)
-			try {
-				throw new Exception("The SystemTapView is null");
-			} catch (Exception e) {
-				e.printStackTrace();
-				return;
-			}
-		
+
 		stapView.println(testText);
 		assertEquals(stapView.getText(), testText);
-		
+
 		stapView.clearAll();
 		assertEquals(stapView.getText(), "");
 	}
-	
+
 }
