@@ -11,8 +11,7 @@
 
 package org.eclipse.linuxtools.systemtap.ui.consolelog.internal;
 
-import org.eclipse.ui.plugin.*;
-import org.eclipse.jface.resource.ImageDescriptor;
+import org.eclipse.ui.plugin.AbstractUIPlugin;
 import org.osgi.framework.BundleContext;
 
 /**
@@ -20,9 +19,14 @@ import org.osgi.framework.BundleContext;
  */
 public class ConsoleLogPlugin extends AbstractUIPlugin {
 
+	/**
+	 * @since 2.0
+	 */
+	public static final String PLUGIN_ID = "org.eclipse.linuxtools.systemtap.ui.consolelog"; //$NON-NLS-1$
+
 	//The shared instance.
 	private static ConsoleLogPlugin plugin;
-	
+
 	/**
 	 * The constructor.
 	 */
@@ -30,14 +34,6 @@ public class ConsoleLogPlugin extends AbstractUIPlugin {
 		plugin = this;
 	}
 
-	/**
-	 * This method is called upon plug-in activation
-	 */
-	@Override
-	public void start(BundleContext context) throws Exception {
-		super.start(context);
-	}
-
 	/**
 	 * This method is called when the plug-in is stopped
 	 */
@@ -54,14 +50,4 @@ public class ConsoleLogPlugin extends AbstractUIPlugin {
 		return plugin;
 	}
 
-	/**
-	 * Returns an image descriptor for the image file at the given
-	 * plug-in relative path.
-	 *
-	 * @param path the path
-	 * @return the image descriptor
-	 */
-	public static ImageDescriptor getImageDescriptor(String path) {
-		return AbstractUIPlugin.imageDescriptorFromPlugin("org.eclipse.linuxtools.systemtap.ui.consolelog", path);
-	}
 }
