@@ -8,7 +8,7 @@
  * Contributors:
  *    Elliott Baron <ebaron@redhat.com> - initial API and implementation
  * Martin Oberhuber (Wind River) - [360085] Fix valgrind problem marker lifecycle
- *******************************************************************************/ 
+ *******************************************************************************/
 package org.eclipse.linuxtools.internal.valgrind.launch;
 
 import java.io.File;
@@ -27,6 +27,7 @@ import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IMarker;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IResource;
+import org.eclipse.core.resources.IResourceChangeEvent;
 import org.eclipse.core.resources.IWorkspaceRoot;
 import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
@@ -44,8 +45,6 @@ import org.eclipse.debug.core.model.ISourceLocator;
 import org.eclipse.debug.core.sourcelookup.containers.LocalFileStorage;
 import org.eclipse.debug.ui.DebugUITools;
 import org.eclipse.debug.ui.sourcelookup.ISourceLookupResult;
-import org.eclipse.linuxtools.internal.valgrind.core.CommandLineConstants;
-import org.eclipse.linuxtools.internal.valgrind.core.LaunchConfigurationConstants;
 import org.eclipse.linuxtools.internal.valgrind.core.ValgrindCommand;
 import org.eclipse.linuxtools.internal.valgrind.core.ValgrindCoreParser;
 import org.eclipse.linuxtools.internal.valgrind.core.ValgrindError;
@@ -54,6 +53,7 @@ import org.eclipse.linuxtools.internal.valgrind.core.ValgrindStackFrame;
 import org.eclipse.linuxtools.internal.valgrind.ui.ValgrindUIPlugin;
 import org.eclipse.linuxtools.internal.valgrind.ui.ValgrindViewPart;
 import org.eclipse.linuxtools.profiling.launch.ProfileLaunchConfigurationDelegate;
+import org.eclipse.linuxtools.valgrind.core.CommandLineConstants;
 import org.eclipse.linuxtools.valgrind.core.IValgrindMessage;
 import org.eclipse.linuxtools.valgrind.launch.IValgrindLaunchDelegate;
 import org.eclipse.linuxtools.valgrind.launch.IValgrindOutputDirectoryProvider;
@@ -69,9 +69,10 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 
 	protected static final String LOG_FILE = CommandLineConstants.LOG_PREFIX + "%p.txt"; //$NON-NLS-1$
 	protected static final FileFilter LOG_FILTER = new FileFilter() {
+		@Override
 		public boolean accept(File pathname) {
 			return pathname.getName().startsWith(CommandLineConstants.LOG_PREFIX);
-		}		
+		}
 	};
 
 	protected String toolID;
@@ -145,7 +146,7 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 			String[] commandArray = cmdLine.toArray(new String[cmdLine.size()]);
 			boolean usePty = config.getAttribute(ICDTLaunchConfigurationConstants.ATTR_USE_TERMINAL, ICDTLaunchConfigurationConstants.USE_TERMINAL_DEFAULT);
 			monitor.worked(1);
-			
+
 			// check for cancellation
 			if (monitor.isCanceled()) {
 				return;
@@ -160,7 +161,7 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 			while (!process.isTerminated()) {
 				Thread.sleep(100);
 			}
-			
+
 			// store these for use by other classes
 			getPlugin().setCurrentLaunchConfiguration(config);
 			getPlugin().setCurrentLaunch(launch);
@@ -180,7 +181,7 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 
 			// pass off control to extender
 			dynamicDelegate.handleLaunch(config, launch, outputPath, monitor.newChild(2));
-			
+
 			// initialize tool-specific part of view
 			dynamicDelegate.initializeView(view.getDynamicView(), launchStr, monitor.newChild(1));
 
@@ -189,7 +190,12 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 
 			// show view
 			ValgrindUIPlugin.getDefault().showView();
-			monitor.worked(1);				
+
+			// set up resource listener for post-build events.
+			ResourcesPlugin.getWorkspace().addResourceChangeListener(
+					new ProjectBuildListener(project), IResourceChangeEvent.POST_BUILD);
+
+			monitor.worked(1);
 		} catch (IOException e) {
 			abort(Messages.getString("ValgrindLaunchConfigurationDelegate.Error_starting_process"), e, ICDTLaunchConfigurationConstants.ERR_INTERNAL_ERROR); //$NON-NLS-1$
 			e.printStackTrace();
@@ -202,22 +208,22 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 
 	protected IValgrindMessage[] parseLogs(IPath outputPath) throws IOException, CoreException {
 		List<IValgrindMessage> messages = new ArrayList<IValgrindMessage>();
-		
+
 		for (File log : outputPath.toFile().listFiles(LOG_FILTER)) {
 			ValgrindCoreParser parser = new ValgrindCoreParser(log, launch);
 			IValgrindMessage[] results = parser.getMessages();
-			
+
 			if (results.length == 0){
 				results = new IValgrindMessage[1];
-				results[0] = new ValgrindInfo(null, Messages.getString("ValgrindOutputView.No_output"), launch);
+				results[0] = new ValgrindInfo(null, Messages.getString("ValgrindOutputView.No_output"), launch); //$NON-NLS-1$
 			}
 			messages.addAll(Arrays.asList(results));
 			createMarkers(results);
 		}
-		
+
 		return messages.toArray(new IValgrindMessage[messages.size()]);
 	}
-	
+
 	protected void createMarkers(IValgrindMessage[] messages) throws CoreException {
 		// find the topmost stack frame within the workspace to annotate with marker
 		// traverse nested errors as well
@@ -232,10 +238,10 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 				if (children[i] instanceof ValgrindStackFrame && marker == null) {
 					ValgrindStackFrame frame = (ValgrindStackFrame) children[i];
 					if (frame.getLine() > 0) {
-						ISourceLocator locator = frame.getLaunch().getSourceLocator();					
+						ISourceLocator locator = frame.getLaunch().getSourceLocator();
 						ISourceLookupResult result = DebugUITools.lookupSource(frame.getFile(), locator);
 						Object sourceElement = result.getSourceElement();
-						
+
 						if (sourceElement != null) {
 							// Resolve IResource in case we get a LocalFileStorage object
 							if (sourceElement instanceof LocalFileStorage) {
@@ -276,11 +282,6 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 		return getPlugin().getValgrindCommand();
 	}
 
-	@Override
-	public String generateCommand(ILaunchConfiguration config) {
-		return getValgrindCommand().getCommandLine();
-	}
-	
 	protected ValgrindLaunchPlugin getPlugin() {
 		return ValgrindLaunchPlugin.getDefault();
 	}
@@ -293,7 +294,7 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 		IPath result = null;
 		String strPath = config.getAttribute(LaunchConfigurationConstants.ATTR_INTERNAL_OUTPUT_DIR, (String) null);
 		if (strPath != null) {
-			result = Path.fromPortableString(strPath);			
+			result = Path.fromPortableString(strPath);
 		}
 		if (result == null) {
 			abort(Messages.getString("ValgrindLaunchConfigurationDelegate.Retrieving_location_failed"), null, ICDTLaunchConfigurationConstants.ERR_INTERNAL_ERROR); //$NON-NLS-1$
@@ -350,21 +351,21 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 				opts.add(CommandLineConstants.OPT_MAINSTACK + EQUALS + config.getAttribute(LaunchConfigurationConstants.ATTR_GENERAL_MAINSTACK, LaunchConfigurationConstants.DEFAULT_GENERAL_MAINSTACK));
 			}
 		}
-		
+
 		// 3.6.0 specific
 		if (valgrindVersion == null || valgrindVersion.compareTo(ValgrindLaunchPlugin.VER_3_6_0) >= 0) {
 			if (config.getAttribute(LaunchConfigurationConstants.ATTR_GENERAL_DSYMUTIL, LaunchConfigurationConstants.DEFAULT_GENERAL_DSYMUTIL) != LaunchConfigurationConstants.DEFAULT_GENERAL_DSYMUTIL)
 				opts.add(CommandLineConstants.OPT_DSYMUTIL + EQUALS + (config.getAttribute(LaunchConfigurationConstants.ATTR_GENERAL_DSYMUTIL, LaunchConfigurationConstants.DEFAULT_GENERAL_DSYMUTIL) ? YES : NO));
 		}
-		
-		List<?> suppFiles = config.getAttribute(LaunchConfigurationConstants.ATTR_GENERAL_SUPPFILES, LaunchConfigurationConstants.DEFAULT_GENERAL_SUPPFILES); 
+
+		List<?> suppFiles = config.getAttribute(LaunchConfigurationConstants.ATTR_GENERAL_SUPPFILES, LaunchConfigurationConstants.DEFAULT_GENERAL_SUPPFILES);
 		for (Object strpath : suppFiles) {
 			IPath suppfile = getPlugin().parseWSPath((String) strpath);
 			if (suppfile != null) {
 				opts.add(CommandLineConstants.OPT_SUPPFILE + EQUALS + suppfile.toOSString());
 			}
 		}
-		opts.addAll(Arrays.asList(dynamicDelegate.getCommandArray(config, valgrindVersion, outputPath)));		
+		opts.addAll(Arrays.asList(dynamicDelegate.getCommandArray(config, valgrindVersion, outputPath)));
 
 		String[] ret = new String[opts.size()];
 		return opts.toArray(ret);
@@ -384,8 +385,7 @@ public class ValgrindLaunchConfigurationDelegate extends ProfileLaunchConfigurat
 			String mode, IProgressMonitor monitor) throws CoreException {
 		//Delete our own problem markers
 		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
-		root.deleteMarkers(ValgrindLaunchPlugin.MARKER_TYPE, true, IResource.DEPTH_INFINITE); //$NON-NLS-1$
+		root.deleteMarkers(ValgrindLaunchPlugin.MARKER_TYPE, true, IResource.DEPTH_INFINITE);
 		return super.finalLaunchCheck(configuration, mode, monitor);
 	}
-
 }
