@@ -10,29 +10,42 @@
  *******************************************************************************/
 package org.eclipse.linuxtools.internal.valgrind.massif.tests;
 
+import static org.junit.Assert.assertEquals;
+
+import org.eclipse.core.runtime.CoreException;
 import org.eclipse.debug.core.ILaunchConfiguration;
+import org.eclipse.linuxtools.internal.valgrind.massif.MassifSnapshot;
 import org.eclipse.linuxtools.internal.valgrind.massif.MassifViewPart;
 import org.eclipse.linuxtools.internal.valgrind.ui.ValgrindUIPlugin;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 
 public class BasicMassifTest extends AbstractMassifTest {
-	
+
 	@Override
-	protected void setUp() throws Exception {
+	@Before
+	public void setUp() throws Exception {
 		super.setUp();
 		proj = createProjectAndBuild("alloctest"); //$NON-NLS-1$
 	}
-	
+
 	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws CoreException {
 		deleteProject(proj);
 		super.tearDown();
 	}
-	
+
+	@Test
 	public void testNumSnapshots() throws Exception {
 		ILaunchConfiguration config = createConfiguration(proj.getProject());
 		doLaunch(config, "testNumSnapshots"); //$NON-NLS-1$
-		
+
 		MassifViewPart view = (MassifViewPart) ValgrindUIPlugin.getDefault().getView().getDynamicView();
-		assertEquals(14, view.getSnapshots().length);
+		MassifSnapshot[] snapshots = view.getSnapshots();
+		assertEquals(14, snapshots.length);
+		checkSnapshots(snapshots , 40, 16);
 	}
 }
+
